#define _CFFI_
#include <Python.h>
#ifdef __cplusplus
extern "C" {
#endif
#include <stddef.h>

/* See doc/misc/parse_c_type.rst in the source of CFFI for more information */

typedef void *_cffi_opcode_t;

#define _CFFI_OP(opcode, arg)   (_cffi_opcode_t)(opcode | (((uintptr_t)(arg)) << 8))
#define _CFFI_GETOP(cffi_opcode)    ((unsigned char)(uintptr_t)cffi_opcode)
#define _CFFI_GETARG(cffi_opcode)   (((uintptr_t)cffi_opcode) >> 8)

#define _CFFI_OP_PRIMITIVE       1
#define _CFFI_OP_POINTER         3
#define _CFFI_OP_ARRAY           5
#define _CFFI_OP_OPEN_ARRAY      7
#define _CFFI_OP_STRUCT_UNION    9
#define _CFFI_OP_ENUM           11
#define _CFFI_OP_FUNCTION       13
#define _CFFI_OP_FUNCTION_END   15
#define _CFFI_OP_NOOP           17
#define _CFFI_OP_BITFIELD       19
#define _CFFI_OP_TYPENAME       21
#define _CFFI_OP_CPYTHON_BLTN_V 23   // varargs
#define _CFFI_OP_CPYTHON_BLTN_N 25   // noargs
#define _CFFI_OP_CPYTHON_BLTN_O 27   // O  (i.e. a single arg)
#define _CFFI_OP_CONSTANT       29
#define _CFFI_OP_CONSTANT_INT   31
#define _CFFI_OP_GLOBAL_VAR     33
#define _CFFI_OP_DLOPEN_FUNC    35
#define _CFFI_OP_DLOPEN_CONST   37
#define _CFFI_OP_GLOBAL_VAR_F   39

#define _CFFI_PRIM_VOID          0
#define _CFFI_PRIM_BOOL          1
#define _CFFI_PRIM_CHAR          2
#define _CFFI_PRIM_SCHAR         3
#define _CFFI_PRIM_UCHAR         4
#define _CFFI_PRIM_SHORT         5
#define _CFFI_PRIM_USHORT        6
#define _CFFI_PRIM_INT           7
#define _CFFI_PRIM_UINT          8
#define _CFFI_PRIM_LONG          9
#define _CFFI_PRIM_ULONG        10
#define _CFFI_PRIM_LONGLONG     11
#define _CFFI_PRIM_ULONGLONG    12
#define _CFFI_PRIM_FLOAT        13
#define _CFFI_PRIM_DOUBLE       14
#define _CFFI_PRIM_LONGDOUBLE   15

#define _CFFI_PRIM_WCHAR        16
#define _CFFI_PRIM_INT8         17
#define _CFFI_PRIM_UINT8        18
#define _CFFI_PRIM_INT16        19
#define _CFFI_PRIM_UINT16       20
#define _CFFI_PRIM_INT32        21
#define _CFFI_PRIM_UINT32       22
#define _CFFI_PRIM_INT64        23
#define _CFFI_PRIM_UINT64       24
#define _CFFI_PRIM_INTPTR       25
#define _CFFI_PRIM_UINTPTR      26
#define _CFFI_PRIM_PTRDIFF      27
#define _CFFI_PRIM_SIZE         28
#define _CFFI_PRIM_SSIZE        29
#define _CFFI_PRIM_INT_LEAST8   30
#define _CFFI_PRIM_UINT_LEAST8  31
#define _CFFI_PRIM_INT_LEAST16  32
#define _CFFI_PRIM_UINT_LEAST16 33
#define _CFFI_PRIM_INT_LEAST32  34
#define _CFFI_PRIM_UINT_LEAST32 35
#define _CFFI_PRIM_INT_LEAST64  36
#define _CFFI_PRIM_UINT_LEAST64 37
#define _CFFI_PRIM_INT_FAST8    38
#define _CFFI_PRIM_UINT_FAST8   39
#define _CFFI_PRIM_INT_FAST16   40
#define _CFFI_PRIM_UINT_FAST16  41
#define _CFFI_PRIM_INT_FAST32   42
#define _CFFI_PRIM_UINT_FAST32  43
#define _CFFI_PRIM_INT_FAST64   44
#define _CFFI_PRIM_UINT_FAST64  45
#define _CFFI_PRIM_INTMAX       46
#define _CFFI_PRIM_UINTMAX      47

#define _CFFI__NUM_PRIM         48
#define _CFFI__UNKNOWN_PRIM    (-1)


struct _cffi_global_s {
    const char *name;
    void *address;
    _cffi_opcode_t type_op;
    void *size_or_direct_fn;  // OP_GLOBAL_VAR: size, or 0 if unknown
                              // OP_CPYTHON_BLTN_*: addr of direct function
};

struct _cffi_getconst_s {
    unsigned long long value;
    const struct _cffi_type_context_s *ctx;
    int gindex;
};

struct _cffi_struct_union_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_STRUCT_UNION
    int flags;               // _CFFI_F_* flags below
    size_t size;
    int alignment;
    int first_field_index;   // -> _cffi_fields array
    int num_fields;
};
#define _CFFI_F_UNION         0x01   // is a union, not a struct
#define _CFFI_F_CHECK_FIELDS  0x02   // complain if fields are not in the
                                     // "standard layout" or if some are missing
#define _CFFI_F_PACKED        0x04   // for CHECK_FIELDS, assume a packed struct
#define _CFFI_F_EXTERNAL      0x08   // in some other ffi.include()
#define _CFFI_F_OPAQUE        0x10   // opaque

struct _cffi_field_s {
    const char *name;
    size_t field_offset;
    size_t field_size;
    _cffi_opcode_t field_type_op;
};

struct _cffi_enum_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_ENUM
    int type_prim;           // _CFFI_PRIM_xxx
    const char *enumerators; // comma-delimited string
};

struct _cffi_typename_s {
    const char *name;
    int type_index;   /* if opaque, points to a possibly artificial
                         OP_STRUCT which is itself opaque */
};

struct _cffi_type_context_s {
    _cffi_opcode_t *types;
    const struct _cffi_global_s *globals;
    const struct _cffi_field_s *fields;
    const struct _cffi_struct_union_s *struct_unions;
    const struct _cffi_enum_s *enums;
    const struct _cffi_typename_s *typenames;
    int num_globals;
    int num_struct_unions;
    int num_enums;
    int num_typenames;
    const char *const *includes;
    int num_types;
    int flags;      /* future extension */
};

struct _cffi_parse_info_s {
    const struct _cffi_type_context_s *ctx;
    _cffi_opcode_t *output;
    unsigned int output_size;
    size_t error_location;
    const char *error_message;
};

#ifdef _CFFI_INTERNAL
static int parse_c_type(struct _cffi_parse_info_s *info, const char *input);
static int search_in_globals(const struct _cffi_type_context_s *ctx,
                             const char *search, size_t search_len);
static int search_in_struct_unions(const struct _cffi_type_context_s *ctx,
                                   const char *search, size_t search_len);
#endif

/* this block of #ifs should be kept exactly identical between
   c/_cffi_backend.c, cffi/vengine_cpy.py, cffi/vengine_gen.py
   and cffi/_cffi_include.h */
#if defined(_MSC_VER)
# include <malloc.h>   /* for alloca() */
# if _MSC_VER < 1600   /* MSVC < 2010 */
   typedef __int8 int8_t;
   typedef __int16 int16_t;
   typedef __int32 int32_t;
   typedef __int64 int64_t;
   typedef unsigned __int8 uint8_t;
   typedef unsigned __int16 uint16_t;
   typedef unsigned __int32 uint32_t;
   typedef unsigned __int64 uint64_t;
   typedef __int8 int_least8_t;
   typedef __int16 int_least16_t;
   typedef __int32 int_least32_t;
   typedef __int64 int_least64_t;
   typedef unsigned __int8 uint_least8_t;
   typedef unsigned __int16 uint_least16_t;
   typedef unsigned __int32 uint_least32_t;
   typedef unsigned __int64 uint_least64_t;
   typedef __int8 int_fast8_t;
   typedef __int16 int_fast16_t;
   typedef __int32 int_fast32_t;
   typedef __int64 int_fast64_t;
   typedef unsigned __int8 uint_fast8_t;
   typedef unsigned __int16 uint_fast16_t;
   typedef unsigned __int32 uint_fast32_t;
   typedef unsigned __int64 uint_fast64_t;
   typedef __int64 intmax_t;
   typedef unsigned __int64 uintmax_t;
# else
#  include <stdint.h>
# endif
# if _MSC_VER < 1800   /* MSVC < 2013 */
   typedef unsigned char _Bool;
# endif
#else
# include <stdint.h>
# if (defined (__SVR4) && defined (__sun)) || defined(_AIX) || defined(__hpux)
#  include <alloca.h>
# endif
#endif

#ifdef __GNUC__
# define _CFFI_UNUSED_FN  __attribute__((unused))
#else
# define _CFFI_UNUSED_FN  /* nothing */
#endif

/**********  CPython-specific section  **********/
#ifndef PYPY_VERSION


#if PY_MAJOR_VERSION >= 3
# define PyInt_FromLong PyLong_FromLong
#endif

#define _cffi_from_c_double PyFloat_FromDouble
#define _cffi_from_c_float PyFloat_FromDouble
#define _cffi_from_c_long PyInt_FromLong
#define _cffi_from_c_ulong PyLong_FromUnsignedLong
#define _cffi_from_c_longlong PyLong_FromLongLong
#define _cffi_from_c_ulonglong PyLong_FromUnsignedLongLong

#define _cffi_to_c_double PyFloat_AsDouble
#define _cffi_to_c_float PyFloat_AsDouble

#define _cffi_from_c_int(x, type)                                        \
    (((type)-1) > 0 ? /* unsigned */                                     \
        (sizeof(type) < sizeof(long) ?                                   \
            PyInt_FromLong((long)x) :                                    \
         sizeof(type) == sizeof(long) ?                                  \
            PyLong_FromUnsignedLong((unsigned long)x) :                  \
            PyLong_FromUnsignedLongLong((unsigned long long)x)) :        \
        (sizeof(type) <= sizeof(long) ?                                  \
            PyInt_FromLong((long)x) :                                    \
            PyLong_FromLongLong((long long)x)))

#define _cffi_to_c_int(o, type)                                          \
    ((type)(                                                             \
     sizeof(type) == 1 ? (((type)-1) > 0 ? (type)_cffi_to_c_u8(o)        \
                                         : (type)_cffi_to_c_i8(o)) :     \
     sizeof(type) == 2 ? (((type)-1) > 0 ? (type)_cffi_to_c_u16(o)       \
                                         : (type)_cffi_to_c_i16(o)) :    \
     sizeof(type) == 4 ? (((type)-1) > 0 ? (type)_cffi_to_c_u32(o)       \
                                         : (type)_cffi_to_c_i32(o)) :    \
     sizeof(type) == 8 ? (((type)-1) > 0 ? (type)_cffi_to_c_u64(o)       \
                                         : (type)_cffi_to_c_i64(o)) :    \
     (Py_FatalError("unsupported size for type " #type), (type)0)))

#define _cffi_to_c_i8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[1])
#define _cffi_to_c_u8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[2])
#define _cffi_to_c_i16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[3])
#define _cffi_to_c_u16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[4])
#define _cffi_to_c_i32                                                   \
                 ((int(*)(PyObject *))_cffi_exports[5])
#define _cffi_to_c_u32                                                   \
                 ((unsigned int(*)(PyObject *))_cffi_exports[6])
#define _cffi_to_c_i64                                                   \
                 ((long long(*)(PyObject *))_cffi_exports[7])
#define _cffi_to_c_u64                                                   \
                 ((unsigned long long(*)(PyObject *))_cffi_exports[8])
#define _cffi_to_c_char                                                  \
                 ((int(*)(PyObject *))_cffi_exports[9])
#define _cffi_from_c_pointer                                             \
    ((PyObject *(*)(char *, CTypeDescrObject *))_cffi_exports[10])
#define _cffi_to_c_pointer                                               \
    ((char *(*)(PyObject *, CTypeDescrObject *))_cffi_exports[11])
#define _cffi_get_struct_layout                                          \
    not used any more
#define _cffi_restore_errno                                              \
    ((void(*)(void))_cffi_exports[13])
#define _cffi_save_errno                                                 \
    ((void(*)(void))_cffi_exports[14])
#define _cffi_from_c_char                                                \
    ((PyObject *(*)(char))_cffi_exports[15])
#define _cffi_from_c_deref                                               \
    ((PyObject *(*)(char *, CTypeDescrObject *))_cffi_exports[16])
#define _cffi_to_c                                                       \
    ((int(*)(char *, CTypeDescrObject *, PyObject *))_cffi_exports[17])
#define _cffi_from_c_struct                                              \
    ((PyObject *(*)(char *, CTypeDescrObject *))_cffi_exports[18])
#define _cffi_to_c_wchar_t                                               \
    ((wchar_t(*)(PyObject *))_cffi_exports[19])
#define _cffi_from_c_wchar_t                                             \
    ((PyObject *(*)(wchar_t))_cffi_exports[20])
#define _cffi_to_c_long_double                                           \
    ((long double(*)(PyObject *))_cffi_exports[21])
#define _cffi_to_c__Bool                                                 \
    ((_Bool(*)(PyObject *))_cffi_exports[22])
#define _cffi_prepare_pointer_call_argument                              \
    ((Py_ssize_t(*)(CTypeDescrObject *, PyObject *, char **))_cffi_exports[23])
#define _cffi_convert_array_from_object                                  \
    ((int(*)(char *, CTypeDescrObject *, PyObject *))_cffi_exports[24])
#define _CFFI_NUM_EXPORTS 25

typedef struct _ctypedescr CTypeDescrObject;

static void *_cffi_exports[_CFFI_NUM_EXPORTS];

#define _cffi_type(index)   (                           \
    assert((((uintptr_t)_cffi_types[index]) & 1) == 0), \
    (CTypeDescrObject *)_cffi_types[index])

static PyObject *_cffi_init(const char *module_name, Py_ssize_t version,
                            const struct _cffi_type_context_s *ctx)
{
    PyObject *module, *o_arg, *new_module;
    void *raw[] = {
        (void *)module_name,
        (void *)version,
        (void *)_cffi_exports,
        (void *)ctx,
    };

    module = PyImport_ImportModule("_cffi_backend");
    if (module == NULL)
        goto failure;

    o_arg = PyLong_FromVoidPtr((void *)raw);
    if (o_arg == NULL)
        goto failure;

    new_module = PyObject_CallMethod(
        module, (char *)"_init_cffi_1_0_external_module", (char *)"O", o_arg);

    Py_DECREF(o_arg);
    Py_DECREF(module);
    return new_module;

  failure:
    Py_XDECREF(module);
    return NULL;
}

_CFFI_UNUSED_FN
static PyObject **_cffi_unpack_args(PyObject *args_tuple, Py_ssize_t expected,
                                    const char *fnname)
{
    if (PyTuple_GET_SIZE(args_tuple) != expected) {
        PyErr_Format(PyExc_TypeError,
                     "%.150s() takes exactly %zd arguments (%zd given)",
                     fnname, expected, PyTuple_GET_SIZE(args_tuple));
        return NULL;
    }
    return &PyTuple_GET_ITEM(args_tuple, 0);   /* pointer to the first item,
                                                  the others follow */
}

#endif
/**********  end CPython-specific section  **********/


#define _cffi_array_len(array)   (sizeof(array) / sizeof((array)[0]))

#define _cffi_prim_int(size, sign)                                      \
    ((size) == 1 ? ((sign) ? _CFFI_PRIM_INT8  : _CFFI_PRIM_UINT8)  :    \
     (size) == 2 ? ((sign) ? _CFFI_PRIM_INT16 : _CFFI_PRIM_UINT16) :    \
     (size) == 4 ? ((sign) ? _CFFI_PRIM_INT32 : _CFFI_PRIM_UINT32) :    \
     (size) == 8 ? ((sign) ? _CFFI_PRIM_INT64 : _CFFI_PRIM_UINT64) :    \
     _CFFI__UNKNOWN_PRIM)

#define _cffi_check_int(got, got_nonpos, expected)      \
    ((got_nonpos) == (expected <= 0) &&                 \
     (got) == (unsigned long long)expected)

#ifdef __cplusplus
}
#endif

/************************************************************/

#include <git2.h>

/************************************************************/

static void *_cffi_types[] = {
/*  0 */ _CFFI_OP(_CFFI_OP_FUNCTION, 10), // char const *()(git_refspec const *)
/*  1 */ _CFFI_OP(_CFFI_OP_POINTER, 634), // git_refspec const *
/*  2 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  3 */ _CFFI_OP(_CFFI_OP_FUNCTION, 10), // char const *()(git_remote const *)
/*  4 */ _CFFI_OP(_CFFI_OP_POINTER, 635), // git_remote const *
/*  5 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  6 */ _CFFI_OP(_CFFI_OP_FUNCTION, 10), // char const *()(git_submodule *)
/*  7 */ _CFFI_OP(_CFFI_OP_POINTER, 645), // git_submodule *
/*  8 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  9 */ _CFFI_OP(_CFFI_OP_FUNCTION, 582), // git_attr_t()(char const *)
/* 10 */ _CFFI_OP(_CFFI_OP_POINTER, 581), // char const *
/* 11 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 12 */ _CFFI_OP(_CFFI_OP_FUNCTION, 584), // git_blame_hunk const *()(git_blame *, uint32_t)
/* 13 */ _CFFI_OP(_CFFI_OP_POINTER, 583), // git_blame *
/* 14 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 22), // uint32_t
/* 15 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 16 */ _CFFI_OP(_CFFI_OP_FUNCTION, 612), // git_direction()(git_refspec const *)
/* 17 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 18 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 19 */ _CFFI_OP(_CFFI_OP_FUNCTION, 613), // git_error const *()(void)
/* 20 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 21 */ _CFFI_OP(_CFFI_OP_FUNCTION, 262), // git_index_entry const *()(git_index *, char const *, int)
/* 22 */ _CFFI_OP(_CFFI_OP_POINTER, 618), // git_index *
/* 23 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 24 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7), // int
/* 25 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 26 */ _CFFI_OP(_CFFI_OP_FUNCTION, 262), // git_index_entry const *()(git_index *, size_t)
/* 27 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 28 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28), // size_t
/* 29 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 30 */ _CFFI_OP(_CFFI_OP_FUNCTION, 1), // git_refspec const *()(git_remote *, size_t)
/* 31 */ _CFFI_OP(_CFFI_OP_POINTER, 635), // git_remote *
/* 32 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 33 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 34 */ _CFFI_OP(_CFFI_OP_FUNCTION, 460), // git_transfer_progress const *()(git_remote *)
/* 35 */ _CFFI_OP(_CFFI_OP_NOOP, 31),
/* 36 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 37 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(char const * *, char const * *, git_repository const *)
/* 38 */ _CFFI_OP(_CFFI_OP_POINTER, 10), // char const * *
/* 39 */ _CFFI_OP(_CFFI_OP_NOOP, 38),
/* 40 */ _CFFI_OP(_CFFI_OP_POINTER, 638), // git_repository const *
/* 41 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 42 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(char const * *, git_config const *, char const *)
/* 43 */ _CFFI_OP(_CFFI_OP_NOOP, 38),
/* 44 */ _CFFI_OP(_CFFI_OP_POINTER, 598), // git_config const *
/* 45 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 46 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 47 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(char const * *, git_repository *, uint32_t, char const *, char const *)
/* 48 */ _CFFI_OP(_CFFI_OP_NOOP, 38),
/* 49 */ _CFFI_OP(_CFFI_OP_POINTER, 638), // git_repository *
/* 50 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 22),
/* 51 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 52 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 53 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 54 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(char const *, char const *, void *)
/* 55 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 56 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 57 */ _CFFI_OP(_CFFI_OP_POINTER, 680), // void *
/* 58 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 59 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(char const *, git_oid const *, git_oid const *, void *)
/* 60 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 61 */ _CFFI_OP(_CFFI_OP_POINTER, 629), // git_oid const *
/* 62 */ _CFFI_OP(_CFFI_OP_NOOP, 61),
/* 63 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 64 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 65 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(char const *, int, void *)
/* 66 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 67 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 68 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 69 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 70 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_blame * *, git_repository *, char const *, git_blame_options *)
/* 71 */ _CFFI_OP(_CFFI_OP_POINTER, 13), // git_blame * *
/* 72 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 73 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 74 */ _CFFI_OP(_CFFI_OP_POINTER, 586), // git_blame_options *
/* 75 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 76 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_blame_options *, unsigned int)
/* 77 */ _CFFI_OP(_CFFI_OP_NOOP, 74),
/* 78 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8), // unsigned int
/* 79 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 80 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_buf *)
/* 81 */ _CFFI_OP(_CFFI_OP_POINTER, 587), // git_buf *
/* 82 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 83 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_buf *, git_refspec const *, char const *)
/* 84 */ _CFFI_OP(_CFFI_OP_NOOP, 81),
/* 85 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 86 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 87 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 88 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_cert *, int, char const *, void *)
/* 89 */ _CFFI_OP(_CFFI_OP_POINTER, 588), // git_cert *
/* 90 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 91 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 92 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 93 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 94 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_checkout_notify_t, char const *, git_diff_file const *, git_diff_file const *, git_diff_file const *, void *)
/* 95 */ _CFFI_OP(_CFFI_OP_ENUM, 2), // git_checkout_notify_t
/* 96 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 97 */ _CFFI_OP(_CFFI_OP_POINTER, 608), // git_diff_file const *
/* 98 */ _CFFI_OP(_CFFI_OP_NOOP, 97),
/* 99 */ _CFFI_OP(_CFFI_OP_NOOP, 97),
/* 100 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 101 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 102 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_checkout_options *, unsigned int)
/* 103 */ _CFFI_OP(_CFFI_OP_POINTER, 593), // git_checkout_options *
/* 104 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 105 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 106 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_clone_options *, unsigned int)
/* 107 */ _CFFI_OP(_CFFI_OP_POINTER, 596), // git_clone_options *
/* 108 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 109 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 110 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_config * *)
/* 111 */ _CFFI_OP(_CFFI_OP_POINTER, 119), // git_config * *
/* 112 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 113 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_config * *, char const *)
/* 114 */ _CFFI_OP(_CFFI_OP_NOOP, 111),
/* 115 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 116 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 117 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_config * *, git_config *)
/* 118 */ _CFFI_OP(_CFFI_OP_NOOP, 111),
/* 119 */ _CFFI_OP(_CFFI_OP_POINTER, 598), // git_config *
/* 120 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 121 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_config * *, git_repository *)
/* 122 */ _CFFI_OP(_CFFI_OP_NOOP, 111),
/* 123 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 124 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 125 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_config *, char const *)
/* 126 */ _CFFI_OP(_CFFI_OP_NOOP, 119),
/* 127 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 128 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 129 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_config *, char const *, char const *)
/* 130 */ _CFFI_OP(_CFFI_OP_NOOP, 119),
/* 131 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 132 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 133 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 134 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_config *, char const *, char const *, char const *)
/* 135 */ _CFFI_OP(_CFFI_OP_NOOP, 119),
/* 136 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 137 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 138 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 139 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 140 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_config *, char const *, git_config_level_t, int)
/* 141 */ _CFFI_OP(_CFFI_OP_NOOP, 119),
/* 142 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 143 */ _CFFI_OP(_CFFI_OP_ENUM, 4), // git_config_level_t
/* 144 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 145 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 146 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_config *, char const *, int)
/* 147 */ _CFFI_OP(_CFFI_OP_NOOP, 119),
/* 148 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 149 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 150 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 151 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_config *, char const *, int64_t)
/* 152 */ _CFFI_OP(_CFFI_OP_NOOP, 119),
/* 153 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 154 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 23), // int64_t
/* 155 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 156 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_config_entry * *, git_config const *, char const *)
/* 157 */ _CFFI_OP(_CFFI_OP_POINTER, 550), // git_config_entry * *
/* 158 */ _CFFI_OP(_CFFI_OP_NOOP, 44),
/* 159 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 160 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 161 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_config_entry * *, git_config_iterator *)
/* 162 */ _CFFI_OP(_CFFI_OP_NOOP, 157),
/* 163 */ _CFFI_OP(_CFFI_OP_POINTER, 600), // git_config_iterator *
/* 164 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 165 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_config_iterator * *, git_config const *)
/* 166 */ _CFFI_OP(_CFFI_OP_POINTER, 163), // git_config_iterator * *
/* 167 */ _CFFI_OP(_CFFI_OP_NOOP, 44),
/* 168 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 169 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_config_iterator * *, git_config const *, char const *, char const *)
/* 170 */ _CFFI_OP(_CFFI_OP_NOOP, 166),
/* 171 */ _CFFI_OP(_CFFI_OP_NOOP, 44),
/* 172 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 173 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 174 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 175 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_cred * *, char const *)
/* 176 */ _CFFI_OP(_CFFI_OP_POINTER, 601), // git_cred * *
/* 177 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 178 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 179 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_cred * *, char const *, char const *)
/* 180 */ _CFFI_OP(_CFFI_OP_NOOP, 176),
/* 181 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 182 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 183 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 184 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_cred * *, char const *, char const *, char const *, char const *)
/* 185 */ _CFFI_OP(_CFFI_OP_NOOP, 176),
/* 186 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 187 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 188 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 189 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 190 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 191 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_cred * *, char const *, char const *, unsigned int, void *)
/* 192 */ _CFFI_OP(_CFFI_OP_NOOP, 176),
/* 193 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 194 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 195 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 196 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 197 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 198 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_diff * *, git_repository *, git_index *, git_diff_options const *)
/* 199 */ _CFFI_OP(_CFFI_OP_POINTER, 605), // git_diff * *
/* 200 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 201 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 202 */ _CFFI_OP(_CFFI_OP_POINTER, 609), // git_diff_options const *
/* 203 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 204 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_diff * *, git_repository *, git_tree *, git_index *, git_diff_options const *)
/* 205 */ _CFFI_OP(_CFFI_OP_NOOP, 199),
/* 206 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 207 */ _CFFI_OP(_CFFI_OP_POINTER, 651), // git_tree *
/* 208 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 209 */ _CFFI_OP(_CFFI_OP_NOOP, 202),
/* 210 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 211 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_diff const *, git_diff_delta const *, char const *, void *)
/* 212 */ _CFFI_OP(_CFFI_OP_POINTER, 606), // git_diff const *
/* 213 */ _CFFI_OP(_CFFI_OP_POINTER, 607), // git_diff_delta const *
/* 214 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 215 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 216 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 217 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_diff_options *, unsigned int)
/* 218 */ _CFFI_OP(_CFFI_OP_POINTER, 609), // git_diff_options *
/* 219 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 220 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 221 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_fetch_options *, unsigned int)
/* 222 */ _CFFI_OP(_CFFI_OP_POINTER, 616), // git_fetch_options *
/* 223 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 224 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 225 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_index * *, char const *)
/* 226 */ _CFFI_OP(_CFFI_OP_POINTER, 22), // git_index * *
/* 227 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 228 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 229 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_index * *, git_repository *)
/* 230 */ _CFFI_OP(_CFFI_OP_NOOP, 226),
/* 231 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 232 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 233 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_index * *, git_repository *, git_commit const *, git_commit const *, git_merge_options const *)
/* 234 */ _CFFI_OP(_CFFI_OP_NOOP, 226),
/* 235 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 236 */ _CFFI_OP(_CFFI_OP_POINTER, 597), // git_commit const *
/* 237 */ _CFFI_OP(_CFFI_OP_NOOP, 236),
/* 238 */ _CFFI_OP(_CFFI_OP_POINTER, 626), // git_merge_options const *
/* 239 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 240 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_index * *, git_repository *, git_tree const *, git_tree const *, git_tree const *, git_merge_options const *)
/* 241 */ _CFFI_OP(_CFFI_OP_NOOP, 226),
/* 242 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 243 */ _CFFI_OP(_CFFI_OP_POINTER, 651), // git_tree const *
/* 244 */ _CFFI_OP(_CFFI_OP_NOOP, 243),
/* 245 */ _CFFI_OP(_CFFI_OP_NOOP, 243),
/* 246 */ _CFFI_OP(_CFFI_OP_NOOP, 238),
/* 247 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 248 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_index *)
/* 249 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 250 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 251 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_index *, char const *)
/* 252 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 253 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 254 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 255 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_index *, char const *, int)
/* 256 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 257 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 258 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 259 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 260 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_index *, git_index_entry const *)
/* 261 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 262 */ _CFFI_OP(_CFFI_OP_POINTER, 620), // git_index_entry const *
/* 263 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 264 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_index *, git_strarray const *, unsigned int, int(*)(char const *, char const *, void *), void *)
/* 265 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 266 */ _CFFI_OP(_CFFI_OP_POINTER, 644), // git_strarray const *
/* 267 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 268 */ _CFFI_OP(_CFFI_OP_POINTER, 54), // int(*)(char const *, char const *, void *)
/* 269 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 270 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 271 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_index *, git_tree const *)
/* 272 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 273 */ _CFFI_OP(_CFFI_OP_NOOP, 243),
/* 274 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 275 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_index *, int)
/* 276 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 277 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 278 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 279 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_index const *)
/* 280 */ _CFFI_OP(_CFFI_OP_POINTER, 618), // git_index const *
/* 281 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 282 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_index_conflict_iterator * *, git_index *)
/* 283 */ _CFFI_OP(_CFFI_OP_POINTER, 297), // git_index_conflict_iterator * *
/* 284 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 285 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 286 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_index_entry const * *, git_index_entry const * *, git_index_entry const * *, git_index *, char const *)
/* 287 */ _CFFI_OP(_CFFI_OP_POINTER, 262), // git_index_entry const * *
/* 288 */ _CFFI_OP(_CFFI_OP_NOOP, 287),
/* 289 */ _CFFI_OP(_CFFI_OP_NOOP, 287),
/* 290 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 291 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 292 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 293 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_index_entry const * *, git_index_entry const * *, git_index_entry const * *, git_index_conflict_iterator *)
/* 294 */ _CFFI_OP(_CFFI_OP_NOOP, 287),
/* 295 */ _CFFI_OP(_CFFI_OP_NOOP, 287),
/* 296 */ _CFFI_OP(_CFFI_OP_NOOP, 287),
/* 297 */ _CFFI_OP(_CFFI_OP_POINTER, 619), // git_index_conflict_iterator *
/* 298 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 299 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_merge_file_result *, git_repository *, git_index_entry const *, git_index_entry const *, git_index_entry const *, git_merge_file_options const *)
/* 300 */ _CFFI_OP(_CFFI_OP_POINTER, 625), // git_merge_file_result *
/* 301 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 302 */ _CFFI_OP(_CFFI_OP_NOOP, 262),
/* 303 */ _CFFI_OP(_CFFI_OP_NOOP, 262),
/* 304 */ _CFFI_OP(_CFFI_OP_NOOP, 262),
/* 305 */ _CFFI_OP(_CFFI_OP_POINTER, 624), // git_merge_file_options const *
/* 306 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 307 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_merge_options *, unsigned int)
/* 308 */ _CFFI_OP(_CFFI_OP_POINTER, 626), // git_merge_options *
/* 309 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 310 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 311 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_oid *, git_index *)
/* 312 */ _CFFI_OP(_CFFI_OP_POINTER, 629), // git_oid *
/* 313 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 314 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 315 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_oid *, git_index *, git_repository *)
/* 316 */ _CFFI_OP(_CFFI_OP_NOOP, 312),
/* 317 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 318 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 319 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 320 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_push_options *, unsigned int)
/* 321 */ _CFFI_OP(_CFFI_OP_POINTER, 630), // git_push_options *
/* 322 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 323 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 324 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_push_update const * *, size_t, void *)
/* 325 */ _CFFI_OP(_CFFI_OP_POINTER, 631), // git_push_update const * *
/* 326 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 327 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 328 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 329 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_refspec const *)
/* 330 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 331 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 332 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_refspec const *, char const *)
/* 333 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/* 334 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 335 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 336 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_remote * *, git_repository *, char const *)
/* 337 */ _CFFI_OP(_CFFI_OP_POINTER, 31), // git_remote * *
/* 338 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 339 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 340 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 341 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_remote * *, git_repository *, char const *, char const *)
/* 342 */ _CFFI_OP(_CFFI_OP_NOOP, 337),
/* 343 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 344 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 345 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 346 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 347 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_remote * *, git_repository *, char const *, char const *, char const *)
/* 348 */ _CFFI_OP(_CFFI_OP_NOOP, 337),
/* 349 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 350 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 351 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 352 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 353 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 354 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_remote * *, git_repository *, char const *, char const *, void *)
/* 355 */ _CFFI_OP(_CFFI_OP_NOOP, 337),
/* 356 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 357 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 358 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 359 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 360 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 361 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_remote *, git_strarray const *, git_fetch_options const *, char const *)
/* 362 */ _CFFI_OP(_CFFI_OP_NOOP, 31),
/* 363 */ _CFFI_OP(_CFFI_OP_NOOP, 266),
/* 364 */ _CFFI_OP(_CFFI_OP_POINTER, 616), // git_fetch_options const *
/* 365 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 366 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 367 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_remote *, git_strarray const *, git_push_options const *)
/* 368 */ _CFFI_OP(_CFFI_OP_NOOP, 31),
/* 369 */ _CFFI_OP(_CFFI_OP_NOOP, 266),
/* 370 */ _CFFI_OP(_CFFI_OP_POINTER, 630), // git_push_options const *
/* 371 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 372 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_remote_callbacks *, unsigned int)
/* 373 */ _CFFI_OP(_CFFI_OP_POINTER, 637), // git_remote_callbacks *
/* 374 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 375 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 376 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_remote_completion_type, void *)
/* 377 */ _CFFI_OP(_CFFI_OP_ENUM, 19), // git_remote_completion_type
/* 378 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 379 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 380 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_repository * *, char const *, char const *, git_clone_options const *)
/* 381 */ _CFFI_OP(_CFFI_OP_POINTER, 49), // git_repository * *
/* 382 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 383 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 384 */ _CFFI_OP(_CFFI_OP_POINTER, 596), // git_clone_options const *
/* 385 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 386 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_repository * *, char const *, git_repository_init_options *)
/* 387 */ _CFFI_OP(_CFFI_OP_NOOP, 381),
/* 388 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 389 */ _CFFI_OP(_CFFI_OP_POINTER, 641), // git_repository_init_options *
/* 390 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 391 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_repository * *, char const *, int, void *)
/* 392 */ _CFFI_OP(_CFFI_OP_NOOP, 381),
/* 393 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 394 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 395 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 396 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 397 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_repository * *, char const *, unsigned int)
/* 398 */ _CFFI_OP(_CFFI_OP_NOOP, 381),
/* 399 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 400 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 401 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 402 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_repository * *, git_submodule *)
/* 403 */ _CFFI_OP(_CFFI_OP_NOOP, 381),
/* 404 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 405 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 406 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_repository *)
/* 407 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 408 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 409 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_repository *, char const *)
/* 410 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 411 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 412 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 413 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_repository *, char const *, char const *)
/* 414 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 415 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 416 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 417 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 418 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_repository *, git_checkout_options const *)
/* 419 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 420 */ _CFFI_OP(_CFFI_OP_POINTER, 593), // git_checkout_options const *
/* 421 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 422 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_repository *, git_index *, git_checkout_options const *)
/* 423 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 424 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 425 */ _CFFI_OP(_CFFI_OP_NOOP, 420),
/* 426 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 427 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_repository *, git_object const *, git_checkout_options const *)
/* 428 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 429 */ _CFFI_OP(_CFFI_OP_POINTER, 628), // git_object const *
/* 430 */ _CFFI_OP(_CFFI_OP_NOOP, 420),
/* 431 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 432 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_repository *, git_oid const *)
/* 433 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 434 */ _CFFI_OP(_CFFI_OP_NOOP, 61),
/* 435 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 436 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_repository_init_options *, int)
/* 437 */ _CFFI_OP(_CFFI_OP_NOOP, 389),
/* 438 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 439 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 440 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_strarray *, git_remote *)
/* 441 */ _CFFI_OP(_CFFI_OP_POINTER, 644), // git_strarray *
/* 442 */ _CFFI_OP(_CFFI_OP_NOOP, 31),
/* 443 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 444 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_strarray *, git_repository *)
/* 445 */ _CFFI_OP(_CFFI_OP_NOOP, 441),
/* 446 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 447 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 448 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_strarray *, git_repository *, char const *, char const *)
/* 449 */ _CFFI_OP(_CFFI_OP_NOOP, 441),
/* 450 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 451 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 452 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 453 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 454 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_submodule * *, git_repository *, char *)
/* 455 */ _CFFI_OP(_CFFI_OP_POINTER, 7), // git_submodule * *
/* 456 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 457 */ _CFFI_OP(_CFFI_OP_POINTER, 581), // char *
/* 458 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 459 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_transfer_progress const *, void *)
/* 460 */ _CFFI_OP(_CFFI_OP_POINTER, 648), // git_transfer_progress const *
/* 461 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 462 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 463 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(git_transport * *, git_remote *, void *)
/* 464 */ _CFFI_OP(_CFFI_OP_POINTER, 649), // git_transport * *
/* 465 */ _CFFI_OP(_CFFI_OP_NOOP, 31),
/* 466 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 467 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 468 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(int *, char const *)
/* 469 */ _CFFI_OP(_CFFI_OP_POINTER, 24), // int *
/* 470 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 471 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 472 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(int *, void *, void *, void *)
/* 473 */ _CFFI_OP(_CFFI_OP_NOOP, 469),
/* 474 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 475 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 476 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 477 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 478 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(int, unsigned int, unsigned int, void *)
/* 479 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 480 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 481 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 482 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 483 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 484 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(int64_t *, char const *)
/* 485 */ _CFFI_OP(_CFFI_OP_POINTER, 154), // int64_t *
/* 486 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 487 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 488 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(size_t *, git_index *, char const *)
/* 489 */ _CFFI_OP(_CFFI_OP_POINTER, 28), // size_t *
/* 490 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 491 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 492 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 493 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(size_t *, size_t *, git_repository *, git_oid const *, git_oid const *)
/* 494 */ _CFFI_OP(_CFFI_OP_NOOP, 489),
/* 495 */ _CFFI_OP(_CFFI_OP_NOOP, 489),
/* 496 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 497 */ _CFFI_OP(_CFFI_OP_NOOP, 61),
/* 498 */ _CFFI_OP(_CFFI_OP_NOOP, 61),
/* 499 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 500 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(unsigned int, unsigned int, size_t, void *)
/* 501 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 502 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 503 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 504 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 505 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 506 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(void * *, git_diff_file const *, char const *, size_t, void *)
/* 507 */ _CFFI_OP(_CFFI_OP_POINTER, 57), // void * *
/* 508 */ _CFFI_OP(_CFFI_OP_NOOP, 97),
/* 509 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 510 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 511 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 512 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 513 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(void * *, git_diff_file const *, char const *, void *)
/* 514 */ _CFFI_OP(_CFFI_OP_NOOP, 507),
/* 515 */ _CFFI_OP(_CFFI_OP_NOOP, 97),
/* 516 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 517 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 518 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 519 */ _CFFI_OP(_CFFI_OP_FUNCTION, 24), // int()(void)
/* 520 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 521 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // size_t()(git_index const *)
/* 522 */ _CFFI_OP(_CFFI_OP_NOOP, 280),
/* 523 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 524 */ _CFFI_OP(_CFFI_OP_FUNCTION, 28), // size_t()(git_remote *)
/* 525 */ _CFFI_OP(_CFFI_OP_NOOP, 31),
/* 526 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 527 */ _CFFI_OP(_CFFI_OP_FUNCTION, 14), // uint32_t()(git_blame *)
/* 528 */ _CFFI_OP(_CFFI_OP_NOOP, 13),
/* 529 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 530 */ _CFFI_OP(_CFFI_OP_FUNCTION, 680), // void()(char const *, size_t, size_t, void *)
/* 531 */ _CFFI_OP(_CFFI_OP_NOOP, 10),
/* 532 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 533 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 28),
/* 534 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 535 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 536 */ _CFFI_OP(_CFFI_OP_FUNCTION, 680), // void()(git_blame *)
/* 537 */ _CFFI_OP(_CFFI_OP_NOOP, 13),
/* 538 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 539 */ _CFFI_OP(_CFFI_OP_FUNCTION, 680), // void()(git_buf *)
/* 540 */ _CFFI_OP(_CFFI_OP_NOOP, 81),
/* 541 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 542 */ _CFFI_OP(_CFFI_OP_FUNCTION, 680), // void()(git_checkout_perfdata const *, void *)
/* 543 */ _CFFI_OP(_CFFI_OP_POINTER, 594), // git_checkout_perfdata const *
/* 544 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 545 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 546 */ _CFFI_OP(_CFFI_OP_FUNCTION, 680), // void()(git_config *)
/* 547 */ _CFFI_OP(_CFFI_OP_NOOP, 119),
/* 548 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 549 */ _CFFI_OP(_CFFI_OP_FUNCTION, 680), // void()(git_config_entry *)
/* 550 */ _CFFI_OP(_CFFI_OP_POINTER, 599), // git_config_entry *
/* 551 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 552 */ _CFFI_OP(_CFFI_OP_FUNCTION, 680), // void()(git_config_iterator *)
/* 553 */ _CFFI_OP(_CFFI_OP_NOOP, 163),
/* 554 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 555 */ _CFFI_OP(_CFFI_OP_FUNCTION, 680), // void()(git_index *)
/* 556 */ _CFFI_OP(_CFFI_OP_NOOP, 22),
/* 557 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 558 */ _CFFI_OP(_CFFI_OP_FUNCTION, 680), // void()(git_index_conflict_iterator *)
/* 559 */ _CFFI_OP(_CFFI_OP_NOOP, 297),
/* 560 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 561 */ _CFFI_OP(_CFFI_OP_FUNCTION, 680), // void()(git_merge_file_result *)
/* 562 */ _CFFI_OP(_CFFI_OP_NOOP, 300),
/* 563 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 564 */ _CFFI_OP(_CFFI_OP_FUNCTION, 680), // void()(git_remote *)
/* 565 */ _CFFI_OP(_CFFI_OP_NOOP, 31),
/* 566 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 567 */ _CFFI_OP(_CFFI_OP_FUNCTION, 680), // void()(git_repository *)
/* 568 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 569 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 570 */ _CFFI_OP(_CFFI_OP_FUNCTION, 680), // void()(git_strarray *)
/* 571 */ _CFFI_OP(_CFFI_OP_NOOP, 441),
/* 572 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 573 */ _CFFI_OP(_CFFI_OP_FUNCTION, 680), // void()(git_submodule *)
/* 574 */ _CFFI_OP(_CFFI_OP_NOOP, 7),
/* 575 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 576 */ _CFFI_OP(_CFFI_OP_FUNCTION, 680), // void()(void *, void *)
/* 577 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 578 */ _CFFI_OP(_CFFI_OP_NOOP, 57),
/* 579 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 580 */ _CFFI_OP(_CFFI_OP_POINTER, 457), // char * *
/* 581 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 2), // char
/* 582 */ _CFFI_OP(_CFFI_OP_ENUM, 0), // git_attr_t
/* 583 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 0), // git_blame
/* 584 */ _CFFI_OP(_CFFI_OP_POINTER, 585), // git_blame_hunk const *
/* 585 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 33), // git_blame_hunk
/* 586 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 34), // git_blame_options
/* 587 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 1), // git_buf
/* 588 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 2), // git_cert
/* 589 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 3), // git_cert_hostkey
/* 590 */ _CFFI_OP(_CFFI_OP_ENUM, 1), // git_cert_ssh_t
/* 591 */ _CFFI_OP(_CFFI_OP_ENUM, 18), // git_cert_t
/* 592 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 4), // git_cert_x509
/* 593 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 35), // git_checkout_options
/* 594 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 5), // git_checkout_perfdata
/* 595 */ _CFFI_OP(_CFFI_OP_ENUM, 3), // git_clone_local_t
/* 596 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 36), // git_clone_options
/* 597 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 6), // git_commit
/* 598 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 7), // git_config
/* 599 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 37), // git_config_entry
/* 600 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 8), // git_config_iterator
/* 601 */ _CFFI_OP(_CFFI_OP_POINTER, 602), // git_cred *
/* 602 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 9), // git_cred
/* 603 */ _CFFI_OP(_CFFI_OP_ENUM, 5), // git_credtype_t
/* 604 */ _CFFI_OP(_CFFI_OP_ENUM, 6), // git_delta_t
/* 605 */ _CFFI_OP(_CFFI_OP_POINTER, 606), // git_diff *
/* 606 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 10), // git_diff
/* 607 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 11), // git_diff_delta
/* 608 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 12), // git_diff_file
/* 609 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 13), // git_diff_options
/* 610 */ _CFFI_OP(_CFFI_OP_POINTER, 611), // git_diff_similarity_metric *
/* 611 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 14), // git_diff_similarity_metric
/* 612 */ _CFFI_OP(_CFFI_OP_ENUM, 7), // git_direction
/* 613 */ _CFFI_OP(_CFFI_OP_POINTER, 614), // git_error const *
/* 614 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 15), // git_error
/* 615 */ _CFFI_OP(_CFFI_OP_ENUM, 8), // git_error_code
/* 616 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 16), // git_fetch_options
/* 617 */ _CFFI_OP(_CFFI_OP_ENUM, 9), // git_fetch_prune_t
/* 618 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 17), // git_index
/* 619 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 18), // git_index_conflict_iterator
/* 620 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 38), // git_index_entry
/* 621 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 19), // git_index_time
/* 622 */ _CFFI_OP(_CFFI_OP_ENUM, 10), // git_merge_file_favor_t
/* 623 */ _CFFI_OP(_CFFI_OP_ENUM, 11), // git_merge_file_flags_t
/* 624 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 20), // git_merge_file_options
/* 625 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 21), // git_merge_file_result
/* 626 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 22), // git_merge_options
/* 627 */ _CFFI_OP(_CFFI_OP_ENUM, 12), // git_merge_tree_flag_t
/* 628 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 23), // git_object
/* 629 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 39), // git_oid
/* 630 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 24), // git_push_options
/* 631 */ _CFFI_OP(_CFFI_OP_POINTER, 632), // git_push_update const *
/* 632 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 25), // git_push_update
/* 633 */ _CFFI_OP(_CFFI_OP_ENUM, 13), // git_ref_t
/* 634 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 26), // git_refspec
/* 635 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 27), // git_remote
/* 636 */ _CFFI_OP(_CFFI_OP_ENUM, 14), // git_remote_autotag_option_t
/* 637 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 40), // git_remote_callbacks
/* 638 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 28), // git_repository
/* 639 */ _CFFI_OP(_CFFI_OP_ENUM, 15), // git_repository_init_flag_t
/* 640 */ _CFFI_OP(_CFFI_OP_ENUM, 16), // git_repository_init_mode_t
/* 641 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 29), // git_repository_init_options
/* 642 */ _CFFI_OP(_CFFI_OP_POINTER, 643), // git_signature *
/* 643 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 41), // git_signature
/* 644 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 42), // git_strarray
/* 645 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 30), // git_submodule
/* 646 */ _CFFI_OP(_CFFI_OP_ENUM, 17), // git_submodule_ignore_t
/* 647 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 43), // git_time
/* 648 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 44), // git_transfer_progress
/* 649 */ _CFFI_OP(_CFFI_OP_POINTER, 650), // git_transport *
/* 650 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 31), // git_transport
/* 651 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 32), // git_tree
/* 652 */ _CFFI_OP(_CFFI_OP_POINTER, 59), // int(*)(char const *, git_oid const *, git_oid const *, void *)
/* 653 */ _CFFI_OP(_CFFI_OP_POINTER, 65), // int(*)(char const *, int, void *)
/* 654 */ _CFFI_OP(_CFFI_OP_POINTER, 88), // int(*)(git_cert *, int, char const *, void *)
/* 655 */ _CFFI_OP(_CFFI_OP_POINTER, 94), // int(*)(git_checkout_notify_t, char const *, git_diff_file const *, git_diff_file const *, git_diff_file const *, void *)
/* 656 */ _CFFI_OP(_CFFI_OP_POINTER, 191), // int(*)(git_cred * *, char const *, char const *, unsigned int, void *)
/* 657 */ _CFFI_OP(_CFFI_OP_POINTER, 211), // int(*)(git_diff const *, git_diff_delta const *, char const *, void *)
/* 658 */ _CFFI_OP(_CFFI_OP_POINTER, 324), // int(*)(git_push_update const * *, size_t, void *)
/* 659 */ _CFFI_OP(_CFFI_OP_POINTER, 354), // int(*)(git_remote * *, git_repository *, char const *, char const *, void *)
/* 660 */ _CFFI_OP(_CFFI_OP_POINTER, 376), // int(*)(git_remote_completion_type, void *)
/* 661 */ _CFFI_OP(_CFFI_OP_POINTER, 391), // int(*)(git_repository * *, char const *, int, void *)
/* 662 */ _CFFI_OP(_CFFI_OP_POINTER, 459), // int(*)(git_transfer_progress const *, void *)
/* 663 */ _CFFI_OP(_CFFI_OP_POINTER, 463), // int(*)(git_transport * *, git_remote *, void *)
/* 664 */ _CFFI_OP(_CFFI_OP_POINTER, 472), // int(*)(int *, void *, void *, void *)
/* 665 */ _CFFI_OP(_CFFI_OP_POINTER, 478), // int(*)(int, unsigned int, unsigned int, void *)
/* 666 */ _CFFI_OP(_CFFI_OP_POINTER, 500), // int(*)(unsigned int, unsigned int, size_t, void *)
/* 667 */ _CFFI_OP(_CFFI_OP_POINTER, 506), // int(*)(void * *, git_diff_file const *, char const *, size_t, void *)
/* 668 */ _CFFI_OP(_CFFI_OP_POINTER, 513), // int(*)(void * *, git_diff_file const *, char const *, void *)
/* 669 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 21), // int32_t
/* 670 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 20), // uint16_t
/* 671 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4), // unsigned char
/* 672 */ _CFFI_OP(_CFFI_OP_ARRAY, 671), // unsigned char[16]
/* 673 */ (_cffi_opcode_t)(16),
/* 674 */ _CFFI_OP(_CFFI_OP_ARRAY, 671), // unsigned char[20]
/* 675 */ (_cffi_opcode_t)(20),
/* 676 */ _CFFI_OP(_CFFI_OP_POINTER, 530), // void(*)(char const *, size_t, size_t, void *)
/* 677 */ _CFFI_OP(_CFFI_OP_POINTER, 542), // void(*)(git_checkout_perfdata const *, void *)
/* 678 */ _CFFI_OP(_CFFI_OP_POINTER, 549), // void(*)(git_config_entry *)
/* 679 */ _CFFI_OP(_CFFI_OP_POINTER, 576), // void(*)(void *, void *)
/* 680 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 0), // void
};

static int _cffi_const_GIT_ATTR_UNSPECIFIED_T(unsigned long long *o)
{
  int n = (GIT_ATTR_UNSPECIFIED_T) <= 0;
  *o = (unsigned long long)((GIT_ATTR_UNSPECIFIED_T) << 0);  /* check that GIT_ATTR_UNSPECIFIED_T is an integer */
  return n;
}

static int _cffi_const_GIT_ATTR_TRUE_T(unsigned long long *o)
{
  int n = (GIT_ATTR_TRUE_T) <= 0;
  *o = (unsigned long long)((GIT_ATTR_TRUE_T) << 0);  /* check that GIT_ATTR_TRUE_T is an integer */
  return n;
}

static int _cffi_const_GIT_ATTR_FALSE_T(unsigned long long *o)
{
  int n = (GIT_ATTR_FALSE_T) <= 0;
  *o = (unsigned long long)((GIT_ATTR_FALSE_T) << 0);  /* check that GIT_ATTR_FALSE_T is an integer */
  return n;
}

static int _cffi_const_GIT_ATTR_VALUE_T(unsigned long long *o)
{
  int n = (GIT_ATTR_VALUE_T) <= 0;
  *o = (unsigned long long)((GIT_ATTR_VALUE_T) << 0);  /* check that GIT_ATTR_VALUE_T is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_buf(git_buf *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char * *tmp = &p->ptr; (void)tmp; }
  (void)((p->asize) << 1);  /* check that 'git_buf.asize' is an integer */
  (void)((p->size) << 1);  /* check that 'git_buf.size' is an integer */
}
struct _cffi_align_typedef_git_buf { char x; git_buf y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_cert(git_cert *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { git_cert_t *tmp = &p->cert_type; (void)tmp; }
}
struct _cffi_align_typedef_git_cert { char x; git_cert y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_cert_hostkey(git_cert_hostkey *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { git_cert_t *tmp = &p->cert_type; (void)tmp; }
  { git_cert_ssh_t *tmp = &p->type; (void)tmp; }
  { unsigned char(*tmp)[16] = &p->hash_md5; (void)tmp; }
  { unsigned char(*tmp)[20] = &p->hash_sha1; (void)tmp; }
}
struct _cffi_align_typedef_git_cert_hostkey { char x; git_cert_hostkey y; };

static int _cffi_const_GIT_CERT_SSH_MD5(unsigned long long *o)
{
  int n = (GIT_CERT_SSH_MD5) <= 0;
  *o = (unsigned long long)((GIT_CERT_SSH_MD5) << 0);  /* check that GIT_CERT_SSH_MD5 is an integer */
  return n;
}

static int _cffi_const_GIT_CERT_SSH_SHA1(unsigned long long *o)
{
  int n = (GIT_CERT_SSH_SHA1) <= 0;
  *o = (unsigned long long)((GIT_CERT_SSH_SHA1) << 0);  /* check that GIT_CERT_SSH_SHA1 is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_cert_x509(git_cert_x509 *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { git_cert_t *tmp = &p->cert_type; (void)tmp; }
  { void * *tmp = &p->data; (void)tmp; }
  (void)((p->len) << 1);  /* check that 'git_cert_x509.len' is an integer */
}
struct _cffi_align_typedef_git_cert_x509 { char x; git_cert_x509 y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_checkout_perfdata(git_checkout_perfdata *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->mkdir_calls) << 1);  /* check that 'git_checkout_perfdata.mkdir_calls' is an integer */
  (void)((p->stat_calls) << 1);  /* check that 'git_checkout_perfdata.stat_calls' is an integer */
  (void)((p->chmod_calls) << 1);  /* check that 'git_checkout_perfdata.chmod_calls' is an integer */
}
struct _cffi_align_typedef_git_checkout_perfdata { char x; git_checkout_perfdata y; };

static int _cffi_const_GIT_CLONE_LOCAL_AUTO(unsigned long long *o)
{
  int n = (GIT_CLONE_LOCAL_AUTO) <= 0;
  *o = (unsigned long long)((GIT_CLONE_LOCAL_AUTO) << 0);  /* check that GIT_CLONE_LOCAL_AUTO is an integer */
  return n;
}

static int _cffi_const_GIT_CLONE_LOCAL(unsigned long long *o)
{
  int n = (GIT_CLONE_LOCAL) <= 0;
  *o = (unsigned long long)((GIT_CLONE_LOCAL) << 0);  /* check that GIT_CLONE_LOCAL is an integer */
  return n;
}

static int _cffi_const_GIT_CLONE_NO_LOCAL(unsigned long long *o)
{
  int n = (GIT_CLONE_NO_LOCAL) <= 0;
  *o = (unsigned long long)((GIT_CLONE_NO_LOCAL) << 0);  /* check that GIT_CLONE_NO_LOCAL is an integer */
  return n;
}

static int _cffi_const_GIT_CLONE_LOCAL_NO_LINKS(unsigned long long *o)
{
  int n = (GIT_CLONE_LOCAL_NO_LINKS) <= 0;
  *o = (unsigned long long)((GIT_CLONE_LOCAL_NO_LINKS) << 0);  /* check that GIT_CLONE_LOCAL_NO_LINKS is an integer */
  return n;
}

static int _cffi_const_GIT_CONFIG_LEVEL_SYSTEM(unsigned long long *o)
{
  int n = (GIT_CONFIG_LEVEL_SYSTEM) <= 0;
  *o = (unsigned long long)((GIT_CONFIG_LEVEL_SYSTEM) << 0);  /* check that GIT_CONFIG_LEVEL_SYSTEM is an integer */
  return n;
}

static int _cffi_const_GIT_CONFIG_LEVEL_XDG(unsigned long long *o)
{
  int n = (GIT_CONFIG_LEVEL_XDG) <= 0;
  *o = (unsigned long long)((GIT_CONFIG_LEVEL_XDG) << 0);  /* check that GIT_CONFIG_LEVEL_XDG is an integer */
  return n;
}

static int _cffi_const_GIT_CONFIG_LEVEL_GLOBAL(unsigned long long *o)
{
  int n = (GIT_CONFIG_LEVEL_GLOBAL) <= 0;
  *o = (unsigned long long)((GIT_CONFIG_LEVEL_GLOBAL) << 0);  /* check that GIT_CONFIG_LEVEL_GLOBAL is an integer */
  return n;
}

static int _cffi_const_GIT_CONFIG_LEVEL_LOCAL(unsigned long long *o)
{
  int n = (GIT_CONFIG_LEVEL_LOCAL) <= 0;
  *o = (unsigned long long)((GIT_CONFIG_LEVEL_LOCAL) << 0);  /* check that GIT_CONFIG_LEVEL_LOCAL is an integer */
  return n;
}

static int _cffi_const_GIT_CONFIG_LEVEL_APP(unsigned long long *o)
{
  int n = (GIT_CONFIG_LEVEL_APP) <= 0;
  *o = (unsigned long long)((GIT_CONFIG_LEVEL_APP) << 0);  /* check that GIT_CONFIG_LEVEL_APP is an integer */
  return n;
}

static int _cffi_const_GIT_CONFIG_HIGHEST_LEVEL(unsigned long long *o)
{
  int n = (GIT_CONFIG_HIGHEST_LEVEL) <= 0;
  *o = (unsigned long long)((GIT_CONFIG_HIGHEST_LEVEL) << 0);  /* check that GIT_CONFIG_HIGHEST_LEVEL is an integer */
  return n;
}

static int _cffi_const_GIT_CREDTYPE_USERPASS_PLAINTEXT(unsigned long long *o)
{
  int n = (GIT_CREDTYPE_USERPASS_PLAINTEXT) <= 0;
  *o = (unsigned long long)((GIT_CREDTYPE_USERPASS_PLAINTEXT) << 0);  /* check that GIT_CREDTYPE_USERPASS_PLAINTEXT is an integer */
  return n;
}

static int _cffi_const_GIT_CREDTYPE_SSH_KEY(unsigned long long *o)
{
  int n = (GIT_CREDTYPE_SSH_KEY) <= 0;
  *o = (unsigned long long)((GIT_CREDTYPE_SSH_KEY) << 0);  /* check that GIT_CREDTYPE_SSH_KEY is an integer */
  return n;
}

static int _cffi_const_GIT_CREDTYPE_SSH_CUSTOM(unsigned long long *o)
{
  int n = (GIT_CREDTYPE_SSH_CUSTOM) <= 0;
  *o = (unsigned long long)((GIT_CREDTYPE_SSH_CUSTOM) << 0);  /* check that GIT_CREDTYPE_SSH_CUSTOM is an integer */
  return n;
}

static int _cffi_const_GIT_CREDTYPE_DEFAULT(unsigned long long *o)
{
  int n = (GIT_CREDTYPE_DEFAULT) <= 0;
  *o = (unsigned long long)((GIT_CREDTYPE_DEFAULT) << 0);  /* check that GIT_CREDTYPE_DEFAULT is an integer */
  return n;
}

static int _cffi_const_GIT_CREDTYPE_SSH_INTERACTIVE(unsigned long long *o)
{
  int n = (GIT_CREDTYPE_SSH_INTERACTIVE) <= 0;
  *o = (unsigned long long)((GIT_CREDTYPE_SSH_INTERACTIVE) << 0);  /* check that GIT_CREDTYPE_SSH_INTERACTIVE is an integer */
  return n;
}

static int _cffi_const_GIT_CREDTYPE_USERNAME(unsigned long long *o)
{
  int n = (GIT_CREDTYPE_USERNAME) <= 0;
  *o = (unsigned long long)((GIT_CREDTYPE_USERNAME) << 0);  /* check that GIT_CREDTYPE_USERNAME is an integer */
  return n;
}

static int _cffi_const_GIT_DELTA_UNMODIFIED(unsigned long long *o)
{
  int n = (GIT_DELTA_UNMODIFIED) <= 0;
  *o = (unsigned long long)((GIT_DELTA_UNMODIFIED) << 0);  /* check that GIT_DELTA_UNMODIFIED is an integer */
  return n;
}

static int _cffi_const_GIT_DELTA_ADDED(unsigned long long *o)
{
  int n = (GIT_DELTA_ADDED) <= 0;
  *o = (unsigned long long)((GIT_DELTA_ADDED) << 0);  /* check that GIT_DELTA_ADDED is an integer */
  return n;
}

static int _cffi_const_GIT_DELTA_DELETED(unsigned long long *o)
{
  int n = (GIT_DELTA_DELETED) <= 0;
  *o = (unsigned long long)((GIT_DELTA_DELETED) << 0);  /* check that GIT_DELTA_DELETED is an integer */
  return n;
}

static int _cffi_const_GIT_DELTA_MODIFIED(unsigned long long *o)
{
  int n = (GIT_DELTA_MODIFIED) <= 0;
  *o = (unsigned long long)((GIT_DELTA_MODIFIED) << 0);  /* check that GIT_DELTA_MODIFIED is an integer */
  return n;
}

static int _cffi_const_GIT_DELTA_RENAMED(unsigned long long *o)
{
  int n = (GIT_DELTA_RENAMED) <= 0;
  *o = (unsigned long long)((GIT_DELTA_RENAMED) << 0);  /* check that GIT_DELTA_RENAMED is an integer */
  return n;
}

static int _cffi_const_GIT_DELTA_COPIED(unsigned long long *o)
{
  int n = (GIT_DELTA_COPIED) <= 0;
  *o = (unsigned long long)((GIT_DELTA_COPIED) << 0);  /* check that GIT_DELTA_COPIED is an integer */
  return n;
}

static int _cffi_const_GIT_DELTA_IGNORED(unsigned long long *o)
{
  int n = (GIT_DELTA_IGNORED) <= 0;
  *o = (unsigned long long)((GIT_DELTA_IGNORED) << 0);  /* check that GIT_DELTA_IGNORED is an integer */
  return n;
}

static int _cffi_const_GIT_DELTA_UNTRACKED(unsigned long long *o)
{
  int n = (GIT_DELTA_UNTRACKED) <= 0;
  *o = (unsigned long long)((GIT_DELTA_UNTRACKED) << 0);  /* check that GIT_DELTA_UNTRACKED is an integer */
  return n;
}

static int _cffi_const_GIT_DELTA_TYPECHANGE(unsigned long long *o)
{
  int n = (GIT_DELTA_TYPECHANGE) <= 0;
  *o = (unsigned long long)((GIT_DELTA_TYPECHANGE) << 0);  /* check that GIT_DELTA_TYPECHANGE is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_diff_delta(git_diff_delta *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { git_delta_t *tmp = &p->status; (void)tmp; }
  (void)((p->flags) << 1);  /* check that 'git_diff_delta.flags' is an integer */
  (void)((p->similarity) << 1);  /* check that 'git_diff_delta.similarity' is an integer */
  (void)((p->nfiles) << 1);  /* check that 'git_diff_delta.nfiles' is an integer */
  { git_diff_file *tmp = &p->old_file; (void)tmp; }
  { git_diff_file *tmp = &p->new_file; (void)tmp; }
}
struct _cffi_align_typedef_git_diff_delta { char x; git_diff_delta y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_diff_file(git_diff_file *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { git_oid *tmp = &p->id; (void)tmp; }
  { char const * *tmp = &p->path; (void)tmp; }
  (void)((p->size) << 1);  /* check that 'git_diff_file.size' is an integer */
  (void)((p->flags) << 1);  /* check that 'git_diff_file.flags' is an integer */
  (void)((p->mode) << 1);  /* check that 'git_diff_file.mode' is an integer */
}
struct _cffi_align_typedef_git_diff_file { char x; git_diff_file y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_diff_options(git_diff_options *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->version) << 1);  /* check that 'git_diff_options.version' is an integer */
  (void)((p->flags) << 1);  /* check that 'git_diff_options.flags' is an integer */
  { git_submodule_ignore_t *tmp = &p->ignore_submodules; (void)tmp; }
  { git_strarray *tmp = &p->pathspec; (void)tmp; }
  { int(* *tmp)(git_diff const *, git_diff_delta const *, char const *, void *) = &p->notify_cb; (void)tmp; }
  { void * *tmp = &p->notify_payload; (void)tmp; }
  (void)((p->context_lines) << 1);  /* check that 'git_diff_options.context_lines' is an integer */
  (void)((p->interhunk_lines) << 1);  /* check that 'git_diff_options.interhunk_lines' is an integer */
  (void)((p->id_abbrev) << 1);  /* check that 'git_diff_options.id_abbrev' is an integer */
  (void)((p->max_size) << 1);  /* check that 'git_diff_options.max_size' is an integer */
  { char const * *tmp = &p->old_prefix; (void)tmp; }
  { char const * *tmp = &p->new_prefix; (void)tmp; }
}
struct _cffi_align_typedef_git_diff_options { char x; git_diff_options y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_diff_similarity_metric(git_diff_similarity_metric *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { int(* *tmp)(void * *, git_diff_file const *, char const *, void *) = &p->file_signature; (void)tmp; }
  { int(* *tmp)(void * *, git_diff_file const *, char const *, size_t, void *) = &p->buffer_signature; (void)tmp; }
  { void(* *tmp)(void *, void *) = &p->free_signature; (void)tmp; }
  { int(* *tmp)(int *, void *, void *, void *) = &p->similarity; (void)tmp; }
  { void * *tmp = &p->payload; (void)tmp; }
}
struct _cffi_align_typedef_git_diff_similarity_metric { char x; git_diff_similarity_metric y; };

static int _cffi_const_GIT_DIRECTION_FETCH(unsigned long long *o)
{
  int n = (GIT_DIRECTION_FETCH) <= 0;
  *o = (unsigned long long)((GIT_DIRECTION_FETCH) << 0);  /* check that GIT_DIRECTION_FETCH is an integer */
  return n;
}

static int _cffi_const_GIT_DIRECTION_PUSH(unsigned long long *o)
{
  int n = (GIT_DIRECTION_PUSH) <= 0;
  *o = (unsigned long long)((GIT_DIRECTION_PUSH) << 0);  /* check that GIT_DIRECTION_PUSH is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_error(git_error *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char * *tmp = &p->message; (void)tmp; }
  (void)((p->klass) << 1);  /* check that 'git_error.klass' is an integer */
}
struct _cffi_align_typedef_git_error { char x; git_error y; };

static int _cffi_const_GIT_OK(unsigned long long *o)
{
  int n = (GIT_OK) <= 0;
  *o = (unsigned long long)((GIT_OK) << 0);  /* check that GIT_OK is an integer */
  return n;
}

static int _cffi_const_GIT_ERROR(unsigned long long *o)
{
  int n = (GIT_ERROR) <= 0;
  *o = (unsigned long long)((GIT_ERROR) << 0);  /* check that GIT_ERROR is an integer */
  return n;
}

static int _cffi_const_GIT_ENOTFOUND(unsigned long long *o)
{
  int n = (GIT_ENOTFOUND) <= 0;
  *o = (unsigned long long)((GIT_ENOTFOUND) << 0);  /* check that GIT_ENOTFOUND is an integer */
  return n;
}

static int _cffi_const_GIT_EEXISTS(unsigned long long *o)
{
  int n = (GIT_EEXISTS) <= 0;
  *o = (unsigned long long)((GIT_EEXISTS) << 0);  /* check that GIT_EEXISTS is an integer */
  return n;
}

static int _cffi_const_GIT_EAMBIGUOUS(unsigned long long *o)
{
  int n = (GIT_EAMBIGUOUS) <= 0;
  *o = (unsigned long long)((GIT_EAMBIGUOUS) << 0);  /* check that GIT_EAMBIGUOUS is an integer */
  return n;
}

static int _cffi_const_GIT_EBUFS(unsigned long long *o)
{
  int n = (GIT_EBUFS) <= 0;
  *o = (unsigned long long)((GIT_EBUFS) << 0);  /* check that GIT_EBUFS is an integer */
  return n;
}

static int _cffi_const_GIT_EUSER(unsigned long long *o)
{
  int n = (GIT_EUSER) <= 0;
  *o = (unsigned long long)((GIT_EUSER) << 0);  /* check that GIT_EUSER is an integer */
  return n;
}

static int _cffi_const_GIT_EBAREREPO(unsigned long long *o)
{
  int n = (GIT_EBAREREPO) <= 0;
  *o = (unsigned long long)((GIT_EBAREREPO) << 0);  /* check that GIT_EBAREREPO is an integer */
  return n;
}

static int _cffi_const_GIT_EUNBORNBRANCH(unsigned long long *o)
{
  int n = (GIT_EUNBORNBRANCH) <= 0;
  *o = (unsigned long long)((GIT_EUNBORNBRANCH) << 0);  /* check that GIT_EUNBORNBRANCH is an integer */
  return n;
}

static int _cffi_const_GIT_EUNMERGED(unsigned long long *o)
{
  int n = (GIT_EUNMERGED) <= 0;
  *o = (unsigned long long)((GIT_EUNMERGED) << 0);  /* check that GIT_EUNMERGED is an integer */
  return n;
}

static int _cffi_const_GIT_ENONFASTFORWARD(unsigned long long *o)
{
  int n = (GIT_ENONFASTFORWARD) <= 0;
  *o = (unsigned long long)((GIT_ENONFASTFORWARD) << 0);  /* check that GIT_ENONFASTFORWARD is an integer */
  return n;
}

static int _cffi_const_GIT_EINVALIDSPEC(unsigned long long *o)
{
  int n = (GIT_EINVALIDSPEC) <= 0;
  *o = (unsigned long long)((GIT_EINVALIDSPEC) << 0);  /* check that GIT_EINVALIDSPEC is an integer */
  return n;
}

static int _cffi_const_GIT_ECONFLICT(unsigned long long *o)
{
  int n = (GIT_ECONFLICT) <= 0;
  *o = (unsigned long long)((GIT_ECONFLICT) << 0);  /* check that GIT_ECONFLICT is an integer */
  return n;
}

static int _cffi_const_GIT_ELOCKED(unsigned long long *o)
{
  int n = (GIT_ELOCKED) <= 0;
  *o = (unsigned long long)((GIT_ELOCKED) << 0);  /* check that GIT_ELOCKED is an integer */
  return n;
}

static int _cffi_const_GIT_PASSTHROUGH(unsigned long long *o)
{
  int n = (GIT_PASSTHROUGH) <= 0;
  *o = (unsigned long long)((GIT_PASSTHROUGH) << 0);  /* check that GIT_PASSTHROUGH is an integer */
  return n;
}

static int _cffi_const_GIT_ITEROVER(unsigned long long *o)
{
  int n = (GIT_ITEROVER) <= 0;
  *o = (unsigned long long)((GIT_ITEROVER) << 0);  /* check that GIT_ITEROVER is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_fetch_options(git_fetch_options *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->version) << 1);  /* check that 'git_fetch_options.version' is an integer */
  { git_remote_callbacks *tmp = &p->callbacks; (void)tmp; }
  { git_fetch_prune_t *tmp = &p->prune; (void)tmp; }
  (void)((p->update_fetchhead) << 1);  /* check that 'git_fetch_options.update_fetchhead' is an integer */
  { git_remote_autotag_option_t *tmp = &p->download_tags; (void)tmp; }
}
struct _cffi_align_typedef_git_fetch_options { char x; git_fetch_options y; };

static int _cffi_const_GIT_FETCH_PRUNE_UNSPECIFIED(unsigned long long *o)
{
  int n = (GIT_FETCH_PRUNE_UNSPECIFIED) <= 0;
  *o = (unsigned long long)((GIT_FETCH_PRUNE_UNSPECIFIED) << 0);  /* check that GIT_FETCH_PRUNE_UNSPECIFIED is an integer */
  return n;
}

static int _cffi_const_GIT_FETCH_PRUNE(unsigned long long *o)
{
  int n = (GIT_FETCH_PRUNE) <= 0;
  *o = (unsigned long long)((GIT_FETCH_PRUNE) << 0);  /* check that GIT_FETCH_PRUNE is an integer */
  return n;
}

static int _cffi_const_GIT_FETCH_NO_PRUNE(unsigned long long *o)
{
  int n = (GIT_FETCH_NO_PRUNE) <= 0;
  *o = (unsigned long long)((GIT_FETCH_NO_PRUNE) << 0);  /* check that GIT_FETCH_NO_PRUNE is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_index_time(git_index_time *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->seconds) << 1);  /* check that 'git_index_time.seconds' is an integer */
  (void)((p->nanoseconds) << 1);  /* check that 'git_index_time.nanoseconds' is an integer */
}
struct _cffi_align_typedef_git_index_time { char x; git_index_time y; };

static int _cffi_const_GIT_MERGE_FILE_FAVOR_NORMAL(unsigned long long *o)
{
  int n = (GIT_MERGE_FILE_FAVOR_NORMAL) <= 0;
  *o = (unsigned long long)((GIT_MERGE_FILE_FAVOR_NORMAL) << 0);  /* check that GIT_MERGE_FILE_FAVOR_NORMAL is an integer */
  return n;
}

static int _cffi_const_GIT_MERGE_FILE_FAVOR_OURS(unsigned long long *o)
{
  int n = (GIT_MERGE_FILE_FAVOR_OURS) <= 0;
  *o = (unsigned long long)((GIT_MERGE_FILE_FAVOR_OURS) << 0);  /* check that GIT_MERGE_FILE_FAVOR_OURS is an integer */
  return n;
}

static int _cffi_const_GIT_MERGE_FILE_FAVOR_THEIRS(unsigned long long *o)
{
  int n = (GIT_MERGE_FILE_FAVOR_THEIRS) <= 0;
  *o = (unsigned long long)((GIT_MERGE_FILE_FAVOR_THEIRS) << 0);  /* check that GIT_MERGE_FILE_FAVOR_THEIRS is an integer */
  return n;
}

static int _cffi_const_GIT_MERGE_FILE_FAVOR_UNION(unsigned long long *o)
{
  int n = (GIT_MERGE_FILE_FAVOR_UNION) <= 0;
  *o = (unsigned long long)((GIT_MERGE_FILE_FAVOR_UNION) << 0);  /* check that GIT_MERGE_FILE_FAVOR_UNION is an integer */
  return n;
}

static int _cffi_const_GIT_MERGE_FILE_DEFAULT(unsigned long long *o)
{
  int n = (GIT_MERGE_FILE_DEFAULT) <= 0;
  *o = (unsigned long long)((GIT_MERGE_FILE_DEFAULT) << 0);  /* check that GIT_MERGE_FILE_DEFAULT is an integer */
  return n;
}

static int _cffi_const_GIT_MERGE_FILE_STYLE_MERGE(unsigned long long *o)
{
  int n = (GIT_MERGE_FILE_STYLE_MERGE) <= 0;
  *o = (unsigned long long)((GIT_MERGE_FILE_STYLE_MERGE) << 0);  /* check that GIT_MERGE_FILE_STYLE_MERGE is an integer */
  return n;
}

static int _cffi_const_GIT_MERGE_FILE_STYLE_DIFF3(unsigned long long *o)
{
  int n = (GIT_MERGE_FILE_STYLE_DIFF3) <= 0;
  *o = (unsigned long long)((GIT_MERGE_FILE_STYLE_DIFF3) << 0);  /* check that GIT_MERGE_FILE_STYLE_DIFF3 is an integer */
  return n;
}

static int _cffi_const_GIT_MERGE_FILE_SIMPLIFY_ALNUM(unsigned long long *o)
{
  int n = (GIT_MERGE_FILE_SIMPLIFY_ALNUM) <= 0;
  *o = (unsigned long long)((GIT_MERGE_FILE_SIMPLIFY_ALNUM) << 0);  /* check that GIT_MERGE_FILE_SIMPLIFY_ALNUM is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_merge_file_options(git_merge_file_options *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->version) << 1);  /* check that 'git_merge_file_options.version' is an integer */
  { char const * *tmp = &p->ancestor_label; (void)tmp; }
  { char const * *tmp = &p->our_label; (void)tmp; }
  { char const * *tmp = &p->their_label; (void)tmp; }
  { git_merge_file_favor_t *tmp = &p->favor; (void)tmp; }
  { git_merge_file_flags_t *tmp = &p->flags; (void)tmp; }
}
struct _cffi_align_typedef_git_merge_file_options { char x; git_merge_file_options y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_merge_file_result(git_merge_file_result *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->automergeable) << 1);  /* check that 'git_merge_file_result.automergeable' is an integer */
  { char const * *tmp = &p->path; (void)tmp; }
  (void)((p->mode) << 1);  /* check that 'git_merge_file_result.mode' is an integer */
  { char const * *tmp = &p->ptr; (void)tmp; }
  (void)((p->len) << 1);  /* check that 'git_merge_file_result.len' is an integer */
}
struct _cffi_align_typedef_git_merge_file_result { char x; git_merge_file_result y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_merge_options(git_merge_options *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->version) << 1);  /* check that 'git_merge_options.version' is an integer */
  { git_merge_tree_flag_t *tmp = &p->tree_flags; (void)tmp; }
  (void)((p->rename_threshold) << 1);  /* check that 'git_merge_options.rename_threshold' is an integer */
  (void)((p->target_limit) << 1);  /* check that 'git_merge_options.target_limit' is an integer */
  { git_diff_similarity_metric * *tmp = &p->metric; (void)tmp; }
  { git_merge_file_favor_t *tmp = &p->file_favor; (void)tmp; }
  (void)((p->file_flags) << 1);  /* check that 'git_merge_options.file_flags' is an integer */
}
struct _cffi_align_typedef_git_merge_options { char x; git_merge_options y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_push_options(git_push_options *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->version) << 1);  /* check that 'git_push_options.version' is an integer */
  (void)((p->pb_parallelism) << 1);  /* check that 'git_push_options.pb_parallelism' is an integer */
  { git_remote_callbacks *tmp = &p->callbacks; (void)tmp; }
}
struct _cffi_align_typedef_git_push_options { char x; git_push_options y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_push_update(git_push_update *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char * *tmp = &p->src_refname; (void)tmp; }
  { char * *tmp = &p->dst_refname; (void)tmp; }
  { git_oid *tmp = &p->src; (void)tmp; }
  { git_oid *tmp = &p->dst; (void)tmp; }
}
struct _cffi_align_typedef_git_push_update { char x; git_push_update y; };

static int _cffi_const_GIT_REF_INVALID(unsigned long long *o)
{
  int n = (GIT_REF_INVALID) <= 0;
  *o = (unsigned long long)((GIT_REF_INVALID) << 0);  /* check that GIT_REF_INVALID is an integer */
  return n;
}

static int _cffi_const_GIT_REF_OID(unsigned long long *o)
{
  int n = (GIT_REF_OID) <= 0;
  *o = (unsigned long long)((GIT_REF_OID) << 0);  /* check that GIT_REF_OID is an integer */
  return n;
}

static int _cffi_const_GIT_REF_SYMBOLIC(unsigned long long *o)
{
  int n = (GIT_REF_SYMBOLIC) <= 0;
  *o = (unsigned long long)((GIT_REF_SYMBOLIC) << 0);  /* check that GIT_REF_SYMBOLIC is an integer */
  return n;
}

static int _cffi_const_GIT_REF_LISTALL(unsigned long long *o)
{
  int n = (GIT_REF_LISTALL) <= 0;
  *o = (unsigned long long)((GIT_REF_LISTALL) << 0);  /* check that GIT_REF_LISTALL is an integer */
  return n;
}

static int _cffi_const_GIT_REMOTE_DOWNLOAD_TAGS_UNSPECIFIED(unsigned long long *o)
{
  int n = (GIT_REMOTE_DOWNLOAD_TAGS_UNSPECIFIED) <= 0;
  *o = (unsigned long long)((GIT_REMOTE_DOWNLOAD_TAGS_UNSPECIFIED) << 0);  /* check that GIT_REMOTE_DOWNLOAD_TAGS_UNSPECIFIED is an integer */
  return n;
}

static int _cffi_const_GIT_REMOTE_DOWNLOAD_TAGS_AUTO(unsigned long long *o)
{
  int n = (GIT_REMOTE_DOWNLOAD_TAGS_AUTO) <= 0;
  *o = (unsigned long long)((GIT_REMOTE_DOWNLOAD_TAGS_AUTO) << 0);  /* check that GIT_REMOTE_DOWNLOAD_TAGS_AUTO is an integer */
  return n;
}

static int _cffi_const_GIT_REMOTE_DOWNLOAD_TAGS_NONE(unsigned long long *o)
{
  int n = (GIT_REMOTE_DOWNLOAD_TAGS_NONE) <= 0;
  *o = (unsigned long long)((GIT_REMOTE_DOWNLOAD_TAGS_NONE) << 0);  /* check that GIT_REMOTE_DOWNLOAD_TAGS_NONE is an integer */
  return n;
}

static int _cffi_const_GIT_REMOTE_DOWNLOAD_TAGS_ALL(unsigned long long *o)
{
  int n = (GIT_REMOTE_DOWNLOAD_TAGS_ALL) <= 0;
  *o = (unsigned long long)((GIT_REMOTE_DOWNLOAD_TAGS_ALL) << 0);  /* check that GIT_REMOTE_DOWNLOAD_TAGS_ALL is an integer */
  return n;
}

static int _cffi_const_GIT_REPOSITORY_INIT_BARE(unsigned long long *o)
{
  int n = (GIT_REPOSITORY_INIT_BARE) <= 0;
  *o = (unsigned long long)((GIT_REPOSITORY_INIT_BARE) << 0);  /* check that GIT_REPOSITORY_INIT_BARE is an integer */
  return n;
}

static int _cffi_const_GIT_REPOSITORY_INIT_NO_REINIT(unsigned long long *o)
{
  int n = (GIT_REPOSITORY_INIT_NO_REINIT) <= 0;
  *o = (unsigned long long)((GIT_REPOSITORY_INIT_NO_REINIT) << 0);  /* check that GIT_REPOSITORY_INIT_NO_REINIT is an integer */
  return n;
}

static int _cffi_const_GIT_REPOSITORY_INIT_NO_DOTGIT_DIR(unsigned long long *o)
{
  int n = (GIT_REPOSITORY_INIT_NO_DOTGIT_DIR) <= 0;
  *o = (unsigned long long)((GIT_REPOSITORY_INIT_NO_DOTGIT_DIR) << 0);  /* check that GIT_REPOSITORY_INIT_NO_DOTGIT_DIR is an integer */
  return n;
}

static int _cffi_const_GIT_REPOSITORY_INIT_MKDIR(unsigned long long *o)
{
  int n = (GIT_REPOSITORY_INIT_MKDIR) <= 0;
  *o = (unsigned long long)((GIT_REPOSITORY_INIT_MKDIR) << 0);  /* check that GIT_REPOSITORY_INIT_MKDIR is an integer */
  return n;
}

static int _cffi_const_GIT_REPOSITORY_INIT_MKPATH(unsigned long long *o)
{
  int n = (GIT_REPOSITORY_INIT_MKPATH) <= 0;
  *o = (unsigned long long)((GIT_REPOSITORY_INIT_MKPATH) << 0);  /* check that GIT_REPOSITORY_INIT_MKPATH is an integer */
  return n;
}

static int _cffi_const_GIT_REPOSITORY_INIT_EXTERNAL_TEMPLATE(unsigned long long *o)
{
  int n = (GIT_REPOSITORY_INIT_EXTERNAL_TEMPLATE) <= 0;
  *o = (unsigned long long)((GIT_REPOSITORY_INIT_EXTERNAL_TEMPLATE) << 0);  /* check that GIT_REPOSITORY_INIT_EXTERNAL_TEMPLATE is an integer */
  return n;
}

static int _cffi_const_GIT_REPOSITORY_INIT_RELATIVE_GITLINK(unsigned long long *o)
{
  int n = (GIT_REPOSITORY_INIT_RELATIVE_GITLINK) <= 0;
  *o = (unsigned long long)((GIT_REPOSITORY_INIT_RELATIVE_GITLINK) << 0);  /* check that GIT_REPOSITORY_INIT_RELATIVE_GITLINK is an integer */
  return n;
}

static int _cffi_const_GIT_REPOSITORY_INIT_SHARED_UMASK(unsigned long long *o)
{
  int n = (GIT_REPOSITORY_INIT_SHARED_UMASK) <= 0;
  *o = (unsigned long long)((GIT_REPOSITORY_INIT_SHARED_UMASK) << 0);  /* check that GIT_REPOSITORY_INIT_SHARED_UMASK is an integer */
  return n;
}

static int _cffi_const_GIT_REPOSITORY_INIT_SHARED_GROUP(unsigned long long *o)
{
  int n = (GIT_REPOSITORY_INIT_SHARED_GROUP) <= 0;
  *o = (unsigned long long)((GIT_REPOSITORY_INIT_SHARED_GROUP) << 0);  /* check that GIT_REPOSITORY_INIT_SHARED_GROUP is an integer */
  return n;
}

static int _cffi_const_GIT_REPOSITORY_INIT_SHARED_ALL(unsigned long long *o)
{
  int n = (GIT_REPOSITORY_INIT_SHARED_ALL) <= 0;
  *o = (unsigned long long)((GIT_REPOSITORY_INIT_SHARED_ALL) << 0);  /* check that GIT_REPOSITORY_INIT_SHARED_ALL is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_git_repository_init_options(git_repository_init_options *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->version) << 1);  /* check that 'git_repository_init_options.version' is an integer */
  (void)((p->flags) << 1);  /* check that 'git_repository_init_options.flags' is an integer */
  (void)((p->mode) << 1);  /* check that 'git_repository_init_options.mode' is an integer */
  { char const * *tmp = &p->workdir_path; (void)tmp; }
  { char const * *tmp = &p->description; (void)tmp; }
  { char const * *tmp = &p->template_path; (void)tmp; }
  { char const * *tmp = &p->initial_head; (void)tmp; }
  { char const * *tmp = &p->origin_url; (void)tmp; }
}
struct _cffi_align_typedef_git_repository_init_options { char x; git_repository_init_options y; };

static int _cffi_const_GIT_SUBMODULE_IGNORE_UNSPECIFIED(unsigned long long *o)
{
  int n = (GIT_SUBMODULE_IGNORE_UNSPECIFIED) <= 0;
  *o = (unsigned long long)((GIT_SUBMODULE_IGNORE_UNSPECIFIED) << 0);  /* check that GIT_SUBMODULE_IGNORE_UNSPECIFIED is an integer */
  return n;
}

static int _cffi_const_GIT_SUBMODULE_IGNORE_NONE(unsigned long long *o)
{
  int n = (GIT_SUBMODULE_IGNORE_NONE) <= 0;
  *o = (unsigned long long)((GIT_SUBMODULE_IGNORE_NONE) << 0);  /* check that GIT_SUBMODULE_IGNORE_NONE is an integer */
  return n;
}

static int _cffi_const_GIT_SUBMODULE_IGNORE_UNTRACKED(unsigned long long *o)
{
  int n = (GIT_SUBMODULE_IGNORE_UNTRACKED) <= 0;
  *o = (unsigned long long)((GIT_SUBMODULE_IGNORE_UNTRACKED) << 0);  /* check that GIT_SUBMODULE_IGNORE_UNTRACKED is an integer */
  return n;
}

static int _cffi_const_GIT_SUBMODULE_IGNORE_DIRTY(unsigned long long *o)
{
  int n = (GIT_SUBMODULE_IGNORE_DIRTY) <= 0;
  *o = (unsigned long long)((GIT_SUBMODULE_IGNORE_DIRTY) << 0);  /* check that GIT_SUBMODULE_IGNORE_DIRTY is an integer */
  return n;
}

static int _cffi_const_GIT_SUBMODULE_IGNORE_ALL(unsigned long long *o)
{
  int n = (GIT_SUBMODULE_IGNORE_ALL) <= 0;
  *o = (unsigned long long)((GIT_SUBMODULE_IGNORE_ALL) << 0);  /* check that GIT_SUBMODULE_IGNORE_ALL is an integer */
  return n;
}

static int _cffi_const_GIT_CERT_NONE(unsigned long long *o)
{
  int n = (GIT_CERT_NONE) <= 0;
  *o = (unsigned long long)((GIT_CERT_NONE) << 0);  /* check that GIT_CERT_NONE is an integer */
  return n;
}

static int _cffi_const_GIT_CERT_X509(unsigned long long *o)
{
  int n = (GIT_CERT_X509) <= 0;
  *o = (unsigned long long)((GIT_CERT_X509) << 0);  /* check that GIT_CERT_X509 is an integer */
  return n;
}

static int _cffi_const_GIT_CERT_HOSTKEY_LIBSSH2(unsigned long long *o)
{
  int n = (GIT_CERT_HOSTKEY_LIBSSH2) <= 0;
  *o = (unsigned long long)((GIT_CERT_HOSTKEY_LIBSSH2) << 0);  /* check that GIT_CERT_HOSTKEY_LIBSSH2 is an integer */
  return n;
}

static int _cffi_const_GIT_REMOTE_COMPLETION_DOWNLOAD(unsigned long long *o)
{
  int n = (GIT_REMOTE_COMPLETION_DOWNLOAD) <= 0;
  *o = (unsigned long long)((GIT_REMOTE_COMPLETION_DOWNLOAD) << 0);  /* check that GIT_REMOTE_COMPLETION_DOWNLOAD is an integer */
  return n;
}

static int _cffi_const_GIT_REMOTE_COMPLETION_INDEXING(unsigned long long *o)
{
  int n = (GIT_REMOTE_COMPLETION_INDEXING) <= 0;
  *o = (unsigned long long)((GIT_REMOTE_COMPLETION_INDEXING) << 0);  /* check that GIT_REMOTE_COMPLETION_INDEXING is an integer */
  return n;
}

static int _cffi_const_GIT_REMOTE_COMPLETION_ERROR(unsigned long long *o)
{
  int n = (GIT_REMOTE_COMPLETION_ERROR) <= 0;
  *o = (unsigned long long)((GIT_REMOTE_COMPLETION_ERROR) << 0);  /* check that GIT_REMOTE_COMPLETION_ERROR is an integer */
  return n;
}

static int _cffi_d_git_attr_get(char const * * x0, git_repository * x1, uint32_t x2, char const * x3, char const * x4)
{
  return git_attr_get(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_attr_get(PyObject *self, PyObject *args)
{
  char const * * x0;
  git_repository * x1;
  uint32_t x2;
  char const * x3;
  char const * x4;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 5, "git_attr_get");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];
  arg3 = aa[3];
  arg4 = aa[4];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(38), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (char const * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(38), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(49), arg1) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, uint32_t);
  if (x2 == (uint32_t)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (char const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(10), arg3) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg4, (char **)&x4);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x4 = (char const *)alloca((size_t)datasize);
    memset((void *)x4, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x4, _cffi_type(10), arg4) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_attr_get(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_attr_get _cffi_d_git_attr_get
#endif

static git_attr_t _cffi_d_git_attr_value(char const * x0)
{
  return git_attr_value(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_attr_value(PyObject *self, PyObject *arg0)
{
  char const * x0;
  Py_ssize_t datasize;
  git_attr_t result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (char const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(10), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_attr_value(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_deref((char *)&result, _cffi_type(582));
}
#else
#  define _cffi_f_git_attr_value _cffi_d_git_attr_value
#endif

static int _cffi_d_git_blame_file(git_blame * * x0, git_repository * x1, char const * x2, git_blame_options * x3)
{
  return git_blame_file(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_blame_file(PyObject *self, PyObject *args)
{
  git_blame * * x0;
  git_repository * x1;
  char const * x2;
  git_blame_options * x3;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 4, "git_blame_file");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];
  arg3 = aa[3];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(71), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_blame * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(71), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(49), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(74), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (git_blame_options *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(74), arg3) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_blame_file(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_blame_file _cffi_d_git_blame_file
#endif

static void _cffi_d_git_blame_free(git_blame * x0)
{
  git_blame_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_blame_free(PyObject *self, PyObject *arg0)
{
  git_blame * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(13), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_blame *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(13), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { git_blame_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_git_blame_free _cffi_d_git_blame_free
#endif

static git_blame_hunk const * _cffi_d_git_blame_get_hunk_byindex(git_blame * x0, uint32_t x1)
{
  return git_blame_get_hunk_byindex(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_blame_get_hunk_byindex(PyObject *self, PyObject *args)
{
  git_blame * x0;
  uint32_t x1;
  Py_ssize_t datasize;
  git_blame_hunk const * result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_blame_get_hunk_byindex");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(13), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_blame *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(13), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint32_t);
  if (x1 == (uint32_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_blame_get_hunk_byindex(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(584));
}
#else
#  define _cffi_f_git_blame_get_hunk_byindex _cffi_d_git_blame_get_hunk_byindex
#endif

static git_blame_hunk const * _cffi_d_git_blame_get_hunk_byline(git_blame * x0, uint32_t x1)
{
  return git_blame_get_hunk_byline(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_blame_get_hunk_byline(PyObject *self, PyObject *args)
{
  git_blame * x0;
  uint32_t x1;
  Py_ssize_t datasize;
  git_blame_hunk const * result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_blame_get_hunk_byline");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(13), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_blame *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(13), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, uint32_t);
  if (x1 == (uint32_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_blame_get_hunk_byline(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(584));
}
#else
#  define _cffi_f_git_blame_get_hunk_byline _cffi_d_git_blame_get_hunk_byline
#endif

static uint32_t _cffi_d_git_blame_get_hunk_count(git_blame * x0)
{
  return git_blame_get_hunk_count(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_blame_get_hunk_count(PyObject *self, PyObject *arg0)
{
  git_blame * x0;
  Py_ssize_t datasize;
  uint32_t result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(13), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_blame *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(13), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_blame_get_hunk_count(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, uint32_t);
}
#else
#  define _cffi_f_git_blame_get_hunk_count _cffi_d_git_blame_get_hunk_count
#endif

static int _cffi_d_git_blame_init_options(git_blame_options * x0, unsigned int x1)
{
  return git_blame_init_options(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_blame_init_options(PyObject *self, PyObject *args)
{
  git_blame_options * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_blame_init_options");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(74), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_blame_options *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(74), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_blame_init_options(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_blame_init_options _cffi_d_git_blame_init_options
#endif

static void _cffi_d_git_buf_free(git_buf * x0)
{
  git_buf_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_buf_free(PyObject *self, PyObject *arg0)
{
  git_buf * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(81), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_buf *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(81), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { git_buf_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_git_buf_free _cffi_d_git_buf_free
#endif

static int _cffi_d_git_checkout_head(git_repository * x0, git_checkout_options const * x1)
{
  return git_checkout_head(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_checkout_head(PyObject *self, PyObject *args)
{
  git_repository * x0;
  git_checkout_options const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_checkout_head");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(49), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(420), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_checkout_options const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(420), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_checkout_head(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_checkout_head _cffi_d_git_checkout_head
#endif

static int _cffi_d_git_checkout_index(git_repository * x0, git_index * x1, git_checkout_options const * x2)
{
  return git_checkout_index(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_checkout_index(PyObject *self, PyObject *args)
{
  git_repository * x0;
  git_index * x1;
  git_checkout_options const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 3, "git_checkout_index");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(49), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_index *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(22), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(420), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_checkout_options const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(420), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_checkout_index(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_checkout_index _cffi_d_git_checkout_index
#endif

static int _cffi_d_git_checkout_init_options(git_checkout_options * x0, unsigned int x1)
{
  return git_checkout_init_options(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_checkout_init_options(PyObject *self, PyObject *args)
{
  git_checkout_options * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_checkout_init_options");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(103), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_checkout_options *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(103), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_checkout_init_options(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_checkout_init_options _cffi_d_git_checkout_init_options
#endif

static int _cffi_d_git_checkout_tree(git_repository * x0, git_object const * x1, git_checkout_options const * x2)
{
  return git_checkout_tree(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_checkout_tree(PyObject *self, PyObject *args)
{
  git_repository * x0;
  git_object const * x1;
  git_checkout_options const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 3, "git_checkout_tree");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(49), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(429), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_object const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(429), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(420), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_checkout_options const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(420), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_checkout_tree(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_checkout_tree _cffi_d_git_checkout_tree
#endif

static int _cffi_d_git_clone(git_repository * * x0, char const * x1, char const * x2, git_clone_options const * x3)
{
  return git_clone(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_clone(PyObject *self, PyObject *args)
{
  git_repository * * x0;
  char const * x1;
  char const * x2;
  git_clone_options const * x3;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 4, "git_clone");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];
  arg3 = aa[3];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(381), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(381), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(384), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (git_clone_options const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(384), arg3) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_clone(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_clone _cffi_d_git_clone
#endif

static int _cffi_d_git_clone_init_options(git_clone_options * x0, unsigned int x1)
{
  return git_clone_init_options(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_clone_init_options(PyObject *self, PyObject *args)
{
  git_clone_options * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_clone_init_options");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(107), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_clone_options *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(107), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_clone_init_options(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_clone_init_options _cffi_d_git_clone_init_options
#endif

static int _cffi_d_git_config_add_file_ondisk(git_config * x0, char const * x1, git_config_level_t x2, int x3)
{
  return git_config_add_file_ondisk(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_add_file_ondisk(PyObject *self, PyObject *args)
{
  git_config * x0;
  char const * x1;
  git_config_level_t x2;
  int x3;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 4, "git_config_add_file_ondisk");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];
  arg3 = aa[3];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(119), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(119), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x2, _cffi_type(143), arg2) < 0)
    return NULL;

  x3 = _cffi_to_c_int(arg3, int);
  if (x3 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_add_file_ondisk(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_add_file_ondisk _cffi_d_git_config_add_file_ondisk
#endif

static int _cffi_d_git_config_delete_entry(git_config * x0, char const * x1)
{
  return git_config_delete_entry(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_delete_entry(PyObject *self, PyObject *args)
{
  git_config * x0;
  char const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_config_delete_entry");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(119), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(119), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_delete_entry(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_delete_entry _cffi_d_git_config_delete_entry
#endif

static void _cffi_d_git_config_entry_free(git_config_entry * x0)
{
  git_config_entry_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_entry_free(PyObject *self, PyObject *arg0)
{
  git_config_entry * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(550), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config_entry *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(550), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { git_config_entry_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_git_config_entry_free _cffi_d_git_config_entry_free
#endif

static int _cffi_d_git_config_find_global(git_buf * x0)
{
  return git_config_find_global(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_find_global(PyObject *self, PyObject *arg0)
{
  git_buf * x0;
  Py_ssize_t datasize;
  int result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(81), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_buf *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(81), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_find_global(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_find_global _cffi_d_git_config_find_global
#endif

static int _cffi_d_git_config_find_system(git_buf * x0)
{
  return git_config_find_system(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_find_system(PyObject *self, PyObject *arg0)
{
  git_buf * x0;
  Py_ssize_t datasize;
  int result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(81), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_buf *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(81), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_find_system(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_find_system _cffi_d_git_config_find_system
#endif

static int _cffi_d_git_config_find_xdg(git_buf * x0)
{
  return git_config_find_xdg(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_find_xdg(PyObject *self, PyObject *arg0)
{
  git_buf * x0;
  Py_ssize_t datasize;
  int result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(81), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_buf *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(81), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_find_xdg(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_find_xdg _cffi_d_git_config_find_xdg
#endif

static void _cffi_d_git_config_free(git_config * x0)
{
  git_config_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_free(PyObject *self, PyObject *arg0)
{
  git_config * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(119), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(119), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { git_config_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_git_config_free _cffi_d_git_config_free
#endif

static int _cffi_d_git_config_get_entry(git_config_entry * * x0, git_config const * x1, char const * x2)
{
  return git_config_get_entry(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_get_entry(PyObject *self, PyObject *args)
{
  git_config_entry * * x0;
  git_config const * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 3, "git_config_get_entry");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(157), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config_entry * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(157), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(44), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_config const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(44), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_get_entry(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_get_entry _cffi_d_git_config_get_entry
#endif

static int _cffi_d_git_config_get_string(char const * * x0, git_config const * x1, char const * x2)
{
  return git_config_get_string(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_get_string(PyObject *self, PyObject *args)
{
  char const * * x0;
  git_config const * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 3, "git_config_get_string");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(38), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (char const * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(38), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(44), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_config const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(44), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_get_string(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_get_string _cffi_d_git_config_get_string
#endif

static void _cffi_d_git_config_iterator_free(git_config_iterator * x0)
{
  git_config_iterator_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_iterator_free(PyObject *self, PyObject *arg0)
{
  git_config_iterator * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(163), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config_iterator *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(163), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { git_config_iterator_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_git_config_iterator_free _cffi_d_git_config_iterator_free
#endif

static int _cffi_d_git_config_iterator_new(git_config_iterator * * x0, git_config const * x1)
{
  return git_config_iterator_new(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_iterator_new(PyObject *self, PyObject *args)
{
  git_config_iterator * * x0;
  git_config const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_config_iterator_new");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(166), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config_iterator * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(166), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(44), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_config const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(44), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_iterator_new(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_iterator_new _cffi_d_git_config_iterator_new
#endif

static int _cffi_d_git_config_multivar_iterator_new(git_config_iterator * * x0, git_config const * x1, char const * x2, char const * x3)
{
  return git_config_multivar_iterator_new(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_multivar_iterator_new(PyObject *self, PyObject *args)
{
  git_config_iterator * * x0;
  git_config const * x1;
  char const * x2;
  char const * x3;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 4, "git_config_multivar_iterator_new");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];
  arg3 = aa[3];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(166), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config_iterator * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(166), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(44), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_config const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(44), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (char const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(10), arg3) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_multivar_iterator_new(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_multivar_iterator_new _cffi_d_git_config_multivar_iterator_new
#endif

static int _cffi_d_git_config_new(git_config * * x0)
{
  return git_config_new(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_new(PyObject *self, PyObject *arg0)
{
  git_config * * x0;
  Py_ssize_t datasize;
  int result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(111), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(111), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_new(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_new _cffi_d_git_config_new
#endif

static int _cffi_d_git_config_next(git_config_entry * * x0, git_config_iterator * x1)
{
  return git_config_next(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_next(PyObject *self, PyObject *args)
{
  git_config_entry * * x0;
  git_config_iterator * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_config_next");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(157), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config_entry * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(157), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(163), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_config_iterator *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(163), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_next(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_next _cffi_d_git_config_next
#endif

static int _cffi_d_git_config_open_ondisk(git_config * * x0, char const * x1)
{
  return git_config_open_ondisk(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_open_ondisk(PyObject *self, PyObject *args)
{
  git_config * * x0;
  char const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_config_open_ondisk");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(111), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(111), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_open_ondisk(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_open_ondisk _cffi_d_git_config_open_ondisk
#endif

static int _cffi_d_git_config_parse_bool(int * x0, char const * x1)
{
  return git_config_parse_bool(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_parse_bool(PyObject *self, PyObject *args)
{
  int * x0;
  char const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_config_parse_bool");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(469), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (int *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(469), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_parse_bool(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_parse_bool _cffi_d_git_config_parse_bool
#endif

static int _cffi_d_git_config_parse_int64(int64_t * x0, char const * x1)
{
  return git_config_parse_int64(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_parse_int64(PyObject *self, PyObject *args)
{
  int64_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_config_parse_int64");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(485), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (int64_t *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(485), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_parse_int64(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_parse_int64 _cffi_d_git_config_parse_int64
#endif

static int _cffi_d_git_config_set_bool(git_config * x0, char const * x1, int x2)
{
  return git_config_set_bool(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_set_bool(PyObject *self, PyObject *args)
{
  git_config * x0;
  char const * x1;
  int x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 3, "git_config_set_bool");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(119), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(119), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, int);
  if (x2 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_set_bool(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_set_bool _cffi_d_git_config_set_bool
#endif

static int _cffi_d_git_config_set_int64(git_config * x0, char const * x1, int64_t x2)
{
  return git_config_set_int64(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_set_int64(PyObject *self, PyObject *args)
{
  git_config * x0;
  char const * x1;
  int64_t x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 3, "git_config_set_int64");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(119), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(119), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, int64_t);
  if (x2 == (int64_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_set_int64(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_set_int64 _cffi_d_git_config_set_int64
#endif

static int _cffi_d_git_config_set_multivar(git_config * x0, char const * x1, char const * x2, char const * x3)
{
  return git_config_set_multivar(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_set_multivar(PyObject *self, PyObject *args)
{
  git_config * x0;
  char const * x1;
  char const * x2;
  char const * x3;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 4, "git_config_set_multivar");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];
  arg3 = aa[3];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(119), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(119), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (char const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(10), arg3) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_set_multivar(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_set_multivar _cffi_d_git_config_set_multivar
#endif

static int _cffi_d_git_config_set_string(git_config * x0, char const * x1, char const * x2)
{
  return git_config_set_string(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_set_string(PyObject *self, PyObject *args)
{
  git_config * x0;
  char const * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 3, "git_config_set_string");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(119), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(119), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_set_string(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_set_string _cffi_d_git_config_set_string
#endif

static int _cffi_d_git_config_snapshot(git_config * * x0, git_config * x1)
{
  return git_config_snapshot(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_config_snapshot(PyObject *self, PyObject *args)
{
  git_config * * x0;
  git_config * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_config_snapshot");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(111), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(111), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(119), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_config *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(119), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_config_snapshot(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_config_snapshot _cffi_d_git_config_snapshot
#endif

static int _cffi_d_git_cred_ssh_key_from_agent(git_cred * * x0, char const * x1)
{
  return git_cred_ssh_key_from_agent(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_cred_ssh_key_from_agent(PyObject *self, PyObject *args)
{
  git_cred * * x0;
  char const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_cred_ssh_key_from_agent");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(176), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_cred * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(176), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_cred_ssh_key_from_agent(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_cred_ssh_key_from_agent _cffi_d_git_cred_ssh_key_from_agent
#endif

static int _cffi_d_git_cred_ssh_key_new(git_cred * * x0, char const * x1, char const * x2, char const * x3, char const * x4)
{
  return git_cred_ssh_key_new(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_cred_ssh_key_new(PyObject *self, PyObject *args)
{
  git_cred * * x0;
  char const * x1;
  char const * x2;
  char const * x3;
  char const * x4;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 5, "git_cred_ssh_key_new");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];
  arg3 = aa[3];
  arg4 = aa[4];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(176), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_cred * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(176), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (char const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(10), arg3) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg4, (char **)&x4);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x4 = (char const *)alloca((size_t)datasize);
    memset((void *)x4, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x4, _cffi_type(10), arg4) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_cred_ssh_key_new(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_cred_ssh_key_new _cffi_d_git_cred_ssh_key_new
#endif

static int _cffi_d_git_cred_userpass_plaintext_new(git_cred * * x0, char const * x1, char const * x2)
{
  return git_cred_userpass_plaintext_new(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_cred_userpass_plaintext_new(PyObject *self, PyObject *args)
{
  git_cred * * x0;
  char const * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 3, "git_cred_userpass_plaintext_new");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(176), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_cred * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(176), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_cred_userpass_plaintext_new(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_cred_userpass_plaintext_new _cffi_d_git_cred_userpass_plaintext_new
#endif

static int _cffi_d_git_diff_index_to_workdir(git_diff * * x0, git_repository * x1, git_index * x2, git_diff_options const * x3)
{
  return git_diff_index_to_workdir(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_diff_index_to_workdir(PyObject *self, PyObject *args)
{
  git_diff * * x0;
  git_repository * x1;
  git_index * x2;
  git_diff_options const * x3;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 4, "git_diff_index_to_workdir");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];
  arg3 = aa[3];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(199), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_diff * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(199), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(49), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_index *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(22), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(202), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (git_diff_options const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(202), arg3) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_diff_index_to_workdir(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_diff_index_to_workdir _cffi_d_git_diff_index_to_workdir
#endif

static int _cffi_d_git_diff_init_options(git_diff_options * x0, unsigned int x1)
{
  return git_diff_init_options(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_diff_init_options(PyObject *self, PyObject *args)
{
  git_diff_options * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_diff_init_options");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(218), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_diff_options *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(218), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_diff_init_options(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_diff_init_options _cffi_d_git_diff_init_options
#endif

static int _cffi_d_git_diff_tree_to_index(git_diff * * x0, git_repository * x1, git_tree * x2, git_index * x3, git_diff_options const * x4)
{
  return git_diff_tree_to_index(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_diff_tree_to_index(PyObject *self, PyObject *args)
{
  git_diff * * x0;
  git_repository * x1;
  git_tree * x2;
  git_index * x3;
  git_diff_options const * x4;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 5, "git_diff_tree_to_index");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];
  arg3 = aa[3];
  arg4 = aa[4];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(199), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_diff * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(199), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(49), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(207), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_tree *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(207), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (git_index *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(22), arg3) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(202), arg4, (char **)&x4);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x4 = (git_diff_options const *)alloca((size_t)datasize);
    memset((void *)x4, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x4, _cffi_type(202), arg4) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_diff_tree_to_index(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_diff_tree_to_index _cffi_d_git_diff_tree_to_index
#endif

static int _cffi_d_git_fetch_init_options(git_fetch_options * x0, unsigned int x1)
{
  return git_fetch_init_options(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_fetch_init_options(PyObject *self, PyObject *args)
{
  git_fetch_options * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_fetch_init_options");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(222), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_fetch_options *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(222), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_fetch_init_options(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_fetch_init_options _cffi_d_git_fetch_init_options
#endif

static int _cffi_d_git_graph_ahead_behind(size_t * x0, size_t * x1, git_repository * x2, git_oid const * x3, git_oid const * x4)
{
  return git_graph_ahead_behind(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_graph_ahead_behind(PyObject *self, PyObject *args)
{
  size_t * x0;
  size_t * x1;
  git_repository * x2;
  git_oid const * x3;
  git_oid const * x4;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 5, "git_graph_ahead_behind");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];
  arg3 = aa[3];
  arg4 = aa[4];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(489), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (size_t *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(489), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(489), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (size_t *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(489), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(49), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(61), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (git_oid const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(61), arg3) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(61), arg4, (char **)&x4);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x4 = (git_oid const *)alloca((size_t)datasize);
    memset((void *)x4, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x4, _cffi_type(61), arg4) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_graph_ahead_behind(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_graph_ahead_behind _cffi_d_git_graph_ahead_behind
#endif

static int _cffi_d_git_index_add(git_index * x0, git_index_entry const * x1)
{
  return git_index_add(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_add(PyObject *self, PyObject *args)
{
  git_index * x0;
  git_index_entry const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_index_add");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(22), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(262), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_index_entry const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(262), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_add(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_add _cffi_d_git_index_add
#endif

static int _cffi_d_git_index_add_all(git_index * x0, git_strarray const * x1, unsigned int x2, int(* x3)(char const *, char const *, void *), void * x4)
{
  return git_index_add_all(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_add_all(PyObject *self, PyObject *args)
{
  git_index * x0;
  git_strarray const * x1;
  unsigned int x2;
  int(* x3)(char const *, char const *, void *);
  void * x4;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 5, "git_index_add_all");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];
  arg3 = aa[3];
  arg4 = aa[4];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(22), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(266), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_strarray const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(266), arg1) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, unsigned int);
  if (x2 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  x3 = (int(*)(char const *, char const *, void *))_cffi_to_c_pointer(arg3, _cffi_type(268));
  if (x3 == (int(*)(char const *, char const *, void *))NULL && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(57), arg4, (char **)&x4);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x4 = (void *)alloca((size_t)datasize);
    memset((void *)x4, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x4, _cffi_type(57), arg4) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_add_all(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_add_all _cffi_d_git_index_add_all
#endif

static int _cffi_d_git_index_add_bypath(git_index * x0, char const * x1)
{
  return git_index_add_bypath(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_add_bypath(PyObject *self, PyObject *args)
{
  git_index * x0;
  char const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_index_add_bypath");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(22), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_add_bypath(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_add_bypath _cffi_d_git_index_add_bypath
#endif

static int _cffi_d_git_index_clear(git_index * x0)
{
  return git_index_clear(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_clear(PyObject *self, PyObject *arg0)
{
  git_index * x0;
  Py_ssize_t datasize;
  int result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(22), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_clear(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_clear _cffi_d_git_index_clear
#endif

static int _cffi_d_git_index_conflict_get(git_index_entry const * * x0, git_index_entry const * * x1, git_index_entry const * * x2, git_index * x3, char const * x4)
{
  return git_index_conflict_get(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_conflict_get(PyObject *self, PyObject *args)
{
  git_index_entry const * * x0;
  git_index_entry const * * x1;
  git_index_entry const * * x2;
  git_index * x3;
  char const * x4;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 5, "git_index_conflict_get");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];
  arg3 = aa[3];
  arg4 = aa[4];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(287), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index_entry const * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(287), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(287), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_index_entry const * *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(287), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(287), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_index_entry const * *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(287), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (git_index *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(22), arg3) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg4, (char **)&x4);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x4 = (char const *)alloca((size_t)datasize);
    memset((void *)x4, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x4, _cffi_type(10), arg4) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_conflict_get(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_conflict_get _cffi_d_git_index_conflict_get
#endif

static void _cffi_d_git_index_conflict_iterator_free(git_index_conflict_iterator * x0)
{
  git_index_conflict_iterator_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_conflict_iterator_free(PyObject *self, PyObject *arg0)
{
  git_index_conflict_iterator * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(297), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index_conflict_iterator *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(297), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { git_index_conflict_iterator_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_git_index_conflict_iterator_free _cffi_d_git_index_conflict_iterator_free
#endif

static int _cffi_d_git_index_conflict_iterator_new(git_index_conflict_iterator * * x0, git_index * x1)
{
  return git_index_conflict_iterator_new(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_conflict_iterator_new(PyObject *self, PyObject *args)
{
  git_index_conflict_iterator * * x0;
  git_index * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_index_conflict_iterator_new");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(283), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index_conflict_iterator * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(283), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_index *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(22), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_conflict_iterator_new(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_conflict_iterator_new _cffi_d_git_index_conflict_iterator_new
#endif

static int _cffi_d_git_index_conflict_next(git_index_entry const * * x0, git_index_entry const * * x1, git_index_entry const * * x2, git_index_conflict_iterator * x3)
{
  return git_index_conflict_next(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_conflict_next(PyObject *self, PyObject *args)
{
  git_index_entry const * * x0;
  git_index_entry const * * x1;
  git_index_entry const * * x2;
  git_index_conflict_iterator * x3;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 4, "git_index_conflict_next");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];
  arg3 = aa[3];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(287), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index_entry const * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(287), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(287), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_index_entry const * *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(287), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(287), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_index_entry const * *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(287), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(297), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (git_index_conflict_iterator *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(297), arg3) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_conflict_next(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_conflict_next _cffi_d_git_index_conflict_next
#endif

static int _cffi_d_git_index_conflict_remove(git_index * x0, char const * x1)
{
  return git_index_conflict_remove(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_conflict_remove(PyObject *self, PyObject *args)
{
  git_index * x0;
  char const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_index_conflict_remove");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(22), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_conflict_remove(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_conflict_remove _cffi_d_git_index_conflict_remove
#endif

static size_t _cffi_d_git_index_entrycount(git_index const * x0)
{
  return git_index_entrycount(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_entrycount(PyObject *self, PyObject *arg0)
{
  git_index const * x0;
  Py_ssize_t datasize;
  size_t result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(280), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(280), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_entrycount(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, size_t);
}
#else
#  define _cffi_f_git_index_entrycount _cffi_d_git_index_entrycount
#endif

static int _cffi_d_git_index_find(size_t * x0, git_index * x1, char const * x2)
{
  return git_index_find(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_find(PyObject *self, PyObject *args)
{
  size_t * x0;
  git_index * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 3, "git_index_find");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(489), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (size_t *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(489), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_index *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(22), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_find(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_find _cffi_d_git_index_find
#endif

static void _cffi_d_git_index_free(git_index * x0)
{
  git_index_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_free(PyObject *self, PyObject *arg0)
{
  git_index * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(22), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { git_index_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_git_index_free _cffi_d_git_index_free
#endif

static git_index_entry const * _cffi_d_git_index_get_byindex(git_index * x0, size_t x1)
{
  return git_index_get_byindex(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_get_byindex(PyObject *self, PyObject *args)
{
  git_index * x0;
  size_t x1;
  Py_ssize_t datasize;
  git_index_entry const * result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_index_get_byindex");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(22), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, size_t);
  if (x1 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_get_byindex(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(262));
}
#else
#  define _cffi_f_git_index_get_byindex _cffi_d_git_index_get_byindex
#endif

static git_index_entry const * _cffi_d_git_index_get_bypath(git_index * x0, char const * x1, int x2)
{
  return git_index_get_bypath(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_get_bypath(PyObject *self, PyObject *args)
{
  git_index * x0;
  char const * x1;
  int x2;
  Py_ssize_t datasize;
  git_index_entry const * result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 3, "git_index_get_bypath");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(22), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, int);
  if (x2 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_get_bypath(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(262));
}
#else
#  define _cffi_f_git_index_get_bypath _cffi_d_git_index_get_bypath
#endif

static int _cffi_d_git_index_has_conflicts(git_index const * x0)
{
  return git_index_has_conflicts(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_has_conflicts(PyObject *self, PyObject *arg0)
{
  git_index const * x0;
  Py_ssize_t datasize;
  int result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(280), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(280), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_has_conflicts(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_has_conflicts _cffi_d_git_index_has_conflicts
#endif

static int _cffi_d_git_index_open(git_index * * x0, char const * x1)
{
  return git_index_open(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_open(PyObject *self, PyObject *args)
{
  git_index * * x0;
  char const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_index_open");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(226), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(226), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_open(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_open _cffi_d_git_index_open
#endif

static int _cffi_d_git_index_read(git_index * x0, int x1)
{
  return git_index_read(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_read(PyObject *self, PyObject *args)
{
  git_index * x0;
  int x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_index_read");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(22), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_read(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_read _cffi_d_git_index_read
#endif

static int _cffi_d_git_index_read_tree(git_index * x0, git_tree const * x1)
{
  return git_index_read_tree(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_read_tree(PyObject *self, PyObject *args)
{
  git_index * x0;
  git_tree const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_index_read_tree");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(22), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(243), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_tree const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(243), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_read_tree(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_read_tree _cffi_d_git_index_read_tree
#endif

static int _cffi_d_git_index_remove(git_index * x0, char const * x1, int x2)
{
  return git_index_remove(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_remove(PyObject *self, PyObject *args)
{
  git_index * x0;
  char const * x1;
  int x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 3, "git_index_remove");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(22), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, int);
  if (x2 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_remove(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_remove _cffi_d_git_index_remove
#endif

static int _cffi_d_git_index_write(git_index * x0)
{
  return git_index_write(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_write(PyObject *self, PyObject *arg0)
{
  git_index * x0;
  Py_ssize_t datasize;
  int result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(22), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_write(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_write _cffi_d_git_index_write
#endif

static int _cffi_d_git_index_write_tree(git_oid * x0, git_index * x1)
{
  return git_index_write_tree(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_write_tree(PyObject *self, PyObject *args)
{
  git_oid * x0;
  git_index * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_index_write_tree");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(312), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_oid *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(312), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_index *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(22), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_write_tree(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_write_tree _cffi_d_git_index_write_tree
#endif

static int _cffi_d_git_index_write_tree_to(git_oid * x0, git_index * x1, git_repository * x2)
{
  return git_index_write_tree_to(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_index_write_tree_to(PyObject *self, PyObject *args)
{
  git_oid * x0;
  git_index * x1;
  git_repository * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 3, "git_index_write_tree_to");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(312), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_oid *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(312), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(22), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_index *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(22), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(49), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_index_write_tree_to(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_index_write_tree_to _cffi_d_git_index_write_tree_to
#endif

static int _cffi_d_git_libgit2_features(void)
{
  return git_libgit2_features();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_libgit2_features(PyObject *self, PyObject *noarg)
{
  int result;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_libgit2_features(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_libgit2_features _cffi_d_git_libgit2_features
#endif

static int _cffi_d_git_merge_commits(git_index * * x0, git_repository * x1, git_commit const * x2, git_commit const * x3, git_merge_options const * x4)
{
  return git_merge_commits(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_merge_commits(PyObject *self, PyObject *args)
{
  git_index * * x0;
  git_repository * x1;
  git_commit const * x2;
  git_commit const * x3;
  git_merge_options const * x4;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 5, "git_merge_commits");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];
  arg3 = aa[3];
  arg4 = aa[4];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(226), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(226), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(49), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(236), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_commit const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(236), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(236), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (git_commit const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(236), arg3) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(238), arg4, (char **)&x4);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x4 = (git_merge_options const *)alloca((size_t)datasize);
    memset((void *)x4, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x4, _cffi_type(238), arg4) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_merge_commits(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_merge_commits _cffi_d_git_merge_commits
#endif

static int _cffi_d_git_merge_file_from_index(git_merge_file_result * x0, git_repository * x1, git_index_entry const * x2, git_index_entry const * x3, git_index_entry const * x4, git_merge_file_options const * x5)
{
  return git_merge_file_from_index(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_merge_file_from_index(PyObject *self, PyObject *args)
{
  git_merge_file_result * x0;
  git_repository * x1;
  git_index_entry const * x2;
  git_index_entry const * x3;
  git_index_entry const * x4;
  git_merge_file_options const * x5;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 6, "git_merge_file_from_index");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];
  arg3 = aa[3];
  arg4 = aa[4];
  arg5 = aa[5];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(300), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_merge_file_result *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(300), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(49), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(262), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_index_entry const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(262), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(262), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (git_index_entry const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(262), arg3) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(262), arg4, (char **)&x4);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x4 = (git_index_entry const *)alloca((size_t)datasize);
    memset((void *)x4, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x4, _cffi_type(262), arg4) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(305), arg5, (char **)&x5);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x5 = (git_merge_file_options const *)alloca((size_t)datasize);
    memset((void *)x5, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x5, _cffi_type(305), arg5) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_merge_file_from_index(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_merge_file_from_index _cffi_d_git_merge_file_from_index
#endif

static void _cffi_d_git_merge_file_result_free(git_merge_file_result * x0)
{
  git_merge_file_result_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_merge_file_result_free(PyObject *self, PyObject *arg0)
{
  git_merge_file_result * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(300), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_merge_file_result *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(300), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { git_merge_file_result_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_git_merge_file_result_free _cffi_d_git_merge_file_result_free
#endif

static int _cffi_d_git_merge_init_options(git_merge_options * x0, unsigned int x1)
{
  return git_merge_init_options(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_merge_init_options(PyObject *self, PyObject *args)
{
  git_merge_options * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_merge_init_options");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(308), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_merge_options *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(308), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_merge_init_options(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_merge_init_options _cffi_d_git_merge_init_options
#endif

static int _cffi_d_git_merge_trees(git_index * * x0, git_repository * x1, git_tree const * x2, git_tree const * x3, git_tree const * x4, git_merge_options const * x5)
{
  return git_merge_trees(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_merge_trees(PyObject *self, PyObject *args)
{
  git_index * * x0;
  git_repository * x1;
  git_tree const * x2;
  git_tree const * x3;
  git_tree const * x4;
  git_merge_options const * x5;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 6, "git_merge_trees");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];
  arg3 = aa[3];
  arg4 = aa[4];
  arg5 = aa[5];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(226), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(226), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(49), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(243), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_tree const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(243), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(243), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (git_tree const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(243), arg3) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(243), arg4, (char **)&x4);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x4 = (git_tree const *)alloca((size_t)datasize);
    memset((void *)x4, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x4, _cffi_type(243), arg4) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(238), arg5, (char **)&x5);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x5 = (git_merge_options const *)alloca((size_t)datasize);
    memset((void *)x5, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x5, _cffi_type(238), arg5) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_merge_trees(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_merge_trees _cffi_d_git_merge_trees
#endif

static int _cffi_d_git_push_init_options(git_push_options * x0, unsigned int x1)
{
  return git_push_init_options(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_push_init_options(PyObject *self, PyObject *args)
{
  git_push_options * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_push_init_options");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(321), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_push_options *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(321), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_push_init_options(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_push_init_options _cffi_d_git_push_init_options
#endif

static git_direction _cffi_d_git_refspec_direction(git_refspec const * x0)
{
  return git_refspec_direction(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_refspec_direction(PyObject *self, PyObject *arg0)
{
  git_refspec const * x0;
  Py_ssize_t datasize;
  git_direction result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_refspec const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(1), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_refspec_direction(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_deref((char *)&result, _cffi_type(612));
}
#else
#  define _cffi_f_git_refspec_direction _cffi_d_git_refspec_direction
#endif

static char const * _cffi_d_git_refspec_dst(git_refspec const * x0)
{
  return git_refspec_dst(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_refspec_dst(PyObject *self, PyObject *arg0)
{
  git_refspec const * x0;
  Py_ssize_t datasize;
  char const * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_refspec const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(1), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_refspec_dst(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(10));
}
#else
#  define _cffi_f_git_refspec_dst _cffi_d_git_refspec_dst
#endif

static int _cffi_d_git_refspec_dst_matches(git_refspec const * x0, char const * x1)
{
  return git_refspec_dst_matches(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_refspec_dst_matches(PyObject *self, PyObject *args)
{
  git_refspec const * x0;
  char const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_refspec_dst_matches");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_refspec const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(1), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_refspec_dst_matches(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_refspec_dst_matches _cffi_d_git_refspec_dst_matches
#endif

static int _cffi_d_git_refspec_force(git_refspec const * x0)
{
  return git_refspec_force(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_refspec_force(PyObject *self, PyObject *arg0)
{
  git_refspec const * x0;
  Py_ssize_t datasize;
  int result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_refspec const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(1), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_refspec_force(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_refspec_force _cffi_d_git_refspec_force
#endif

static int _cffi_d_git_refspec_rtransform(git_buf * x0, git_refspec const * x1, char const * x2)
{
  return git_refspec_rtransform(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_refspec_rtransform(PyObject *self, PyObject *args)
{
  git_buf * x0;
  git_refspec const * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 3, "git_refspec_rtransform");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(81), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_buf *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(81), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_refspec const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(1), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_refspec_rtransform(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_refspec_rtransform _cffi_d_git_refspec_rtransform
#endif

static char const * _cffi_d_git_refspec_src(git_refspec const * x0)
{
  return git_refspec_src(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_refspec_src(PyObject *self, PyObject *arg0)
{
  git_refspec const * x0;
  Py_ssize_t datasize;
  char const * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_refspec const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(1), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_refspec_src(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(10));
}
#else
#  define _cffi_f_git_refspec_src _cffi_d_git_refspec_src
#endif

static int _cffi_d_git_refspec_src_matches(git_refspec const * x0, char const * x1)
{
  return git_refspec_src_matches(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_refspec_src_matches(PyObject *self, PyObject *args)
{
  git_refspec const * x0;
  char const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_refspec_src_matches");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_refspec const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(1), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_refspec_src_matches(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_refspec_src_matches _cffi_d_git_refspec_src_matches
#endif

static char const * _cffi_d_git_refspec_string(git_refspec const * x0)
{
  return git_refspec_string(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_refspec_string(PyObject *self, PyObject *arg0)
{
  git_refspec const * x0;
  Py_ssize_t datasize;
  char const * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_refspec const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(1), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_refspec_string(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(10));
}
#else
#  define _cffi_f_git_refspec_string _cffi_d_git_refspec_string
#endif

static int _cffi_d_git_refspec_transform(git_buf * x0, git_refspec const * x1, char const * x2)
{
  return git_refspec_transform(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_refspec_transform(PyObject *self, PyObject *args)
{
  git_buf * x0;
  git_refspec const * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 3, "git_refspec_transform");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(81), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_buf *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(81), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_refspec const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(1), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_refspec_transform(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_refspec_transform _cffi_d_git_refspec_transform
#endif

static int _cffi_d_git_remote_add_fetch(git_repository * x0, char const * x1, char const * x2)
{
  return git_remote_add_fetch(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_add_fetch(PyObject *self, PyObject *args)
{
  git_repository * x0;
  char const * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 3, "git_remote_add_fetch");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(49), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_add_fetch(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_add_fetch _cffi_d_git_remote_add_fetch
#endif

static int _cffi_d_git_remote_add_push(git_repository * x0, char const * x1, char const * x2)
{
  return git_remote_add_push(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_add_push(PyObject *self, PyObject *args)
{
  git_repository * x0;
  char const * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 3, "git_remote_add_push");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(49), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_add_push(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_add_push _cffi_d_git_remote_add_push
#endif

static int _cffi_d_git_remote_create(git_remote * * x0, git_repository * x1, char const * x2, char const * x3)
{
  return git_remote_create(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_create(PyObject *self, PyObject *args)
{
  git_remote * * x0;
  git_repository * x1;
  char const * x2;
  char const * x3;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 4, "git_remote_create");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];
  arg3 = aa[3];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(337), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(337), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(49), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (char const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(10), arg3) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_create(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_create _cffi_d_git_remote_create
#endif

static int _cffi_d_git_remote_create_with_fetchspec(git_remote * * x0, git_repository * x1, char const * x2, char const * x3, char const * x4)
{
  return git_remote_create_with_fetchspec(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_create_with_fetchspec(PyObject *self, PyObject *args)
{
  git_remote * * x0;
  git_repository * x1;
  char const * x2;
  char const * x3;
  char const * x4;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 5, "git_remote_create_with_fetchspec");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];
  arg3 = aa[3];
  arg4 = aa[4];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(337), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(337), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(49), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (char const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(10), arg3) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg4, (char **)&x4);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x4 = (char const *)alloca((size_t)datasize);
    memset((void *)x4, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x4, _cffi_type(10), arg4) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_create_with_fetchspec(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_create_with_fetchspec _cffi_d_git_remote_create_with_fetchspec
#endif

static int _cffi_d_git_remote_delete(git_repository * x0, char const * x1)
{
  return git_remote_delete(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_delete(PyObject *self, PyObject *args)
{
  git_repository * x0;
  char const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_remote_delete");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(49), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_delete(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_delete _cffi_d_git_remote_delete
#endif

static int _cffi_d_git_remote_fetch(git_remote * x0, git_strarray const * x1, git_fetch_options const * x2, char const * x3)
{
  return git_remote_fetch(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_fetch(PyObject *self, PyObject *args)
{
  git_remote * x0;
  git_strarray const * x1;
  git_fetch_options const * x2;
  char const * x3;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 4, "git_remote_fetch");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];
  arg3 = aa[3];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(31), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(31), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(266), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_strarray const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(266), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(364), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_fetch_options const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(364), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (char const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(10), arg3) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_fetch(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_fetch _cffi_d_git_remote_fetch
#endif

static void _cffi_d_git_remote_free(git_remote * x0)
{
  git_remote_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_free(PyObject *self, PyObject *arg0)
{
  git_remote * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(31), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(31), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { git_remote_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_git_remote_free _cffi_d_git_remote_free
#endif

static int _cffi_d_git_remote_get_fetch_refspecs(git_strarray * x0, git_remote * x1)
{
  return git_remote_get_fetch_refspecs(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_get_fetch_refspecs(PyObject *self, PyObject *args)
{
  git_strarray * x0;
  git_remote * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_remote_get_fetch_refspecs");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(441), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_strarray *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(441), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(31), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_remote *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(31), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_get_fetch_refspecs(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_get_fetch_refspecs _cffi_d_git_remote_get_fetch_refspecs
#endif

static int _cffi_d_git_remote_get_push_refspecs(git_strarray * x0, git_remote * x1)
{
  return git_remote_get_push_refspecs(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_get_push_refspecs(PyObject *self, PyObject *args)
{
  git_strarray * x0;
  git_remote * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_remote_get_push_refspecs");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(441), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_strarray *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(441), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(31), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_remote *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(31), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_get_push_refspecs(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_get_push_refspecs _cffi_d_git_remote_get_push_refspecs
#endif

static git_refspec const * _cffi_d_git_remote_get_refspec(git_remote * x0, size_t x1)
{
  return git_remote_get_refspec(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_get_refspec(PyObject *self, PyObject *args)
{
  git_remote * x0;
  size_t x1;
  Py_ssize_t datasize;
  git_refspec const * result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_remote_get_refspec");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(31), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(31), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, size_t);
  if (x1 == (size_t)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_get_refspec(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(1));
}
#else
#  define _cffi_f_git_remote_get_refspec _cffi_d_git_remote_get_refspec
#endif

static int _cffi_d_git_remote_init_callbacks(git_remote_callbacks * x0, unsigned int x1)
{
  return git_remote_init_callbacks(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_init_callbacks(PyObject *self, PyObject *args)
{
  git_remote_callbacks * x0;
  unsigned int x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_remote_init_callbacks");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(373), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote_callbacks *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(373), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_init_callbacks(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_init_callbacks _cffi_d_git_remote_init_callbacks
#endif

static int _cffi_d_git_remote_list(git_strarray * x0, git_repository * x1)
{
  return git_remote_list(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_list(PyObject *self, PyObject *args)
{
  git_strarray * x0;
  git_repository * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_remote_list");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(441), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_strarray *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(441), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(49), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_list(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_list _cffi_d_git_remote_list
#endif

static int _cffi_d_git_remote_lookup(git_remote * * x0, git_repository * x1, char const * x2)
{
  return git_remote_lookup(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_lookup(PyObject *self, PyObject *args)
{
  git_remote * * x0;
  git_repository * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 3, "git_remote_lookup");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(337), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(337), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(49), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_lookup(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_lookup _cffi_d_git_remote_lookup
#endif

static char const * _cffi_d_git_remote_name(git_remote const * x0)
{
  return git_remote_name(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_name(PyObject *self, PyObject *arg0)
{
  git_remote const * x0;
  Py_ssize_t datasize;
  char const * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(4), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_name(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(10));
}
#else
#  define _cffi_f_git_remote_name _cffi_d_git_remote_name
#endif

static int _cffi_d_git_remote_push(git_remote * x0, git_strarray const * x1, git_push_options const * x2)
{
  return git_remote_push(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_push(PyObject *self, PyObject *args)
{
  git_remote * x0;
  git_strarray const * x1;
  git_push_options const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 3, "git_remote_push");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(31), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(31), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(266), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_strarray const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(266), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(370), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_push_options const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(370), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_push(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_push _cffi_d_git_remote_push
#endif

static char const * _cffi_d_git_remote_pushurl(git_remote const * x0)
{
  return git_remote_pushurl(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_pushurl(PyObject *self, PyObject *arg0)
{
  git_remote const * x0;
  Py_ssize_t datasize;
  char const * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(4), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_pushurl(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(10));
}
#else
#  define _cffi_f_git_remote_pushurl _cffi_d_git_remote_pushurl
#endif

static size_t _cffi_d_git_remote_refspec_count(git_remote * x0)
{
  return git_remote_refspec_count(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_refspec_count(PyObject *self, PyObject *arg0)
{
  git_remote * x0;
  Py_ssize_t datasize;
  size_t result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(31), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(31), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_refspec_count(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, size_t);
}
#else
#  define _cffi_f_git_remote_refspec_count _cffi_d_git_remote_refspec_count
#endif

static int _cffi_d_git_remote_rename(git_strarray * x0, git_repository * x1, char const * x2, char const * x3)
{
  return git_remote_rename(x0, x1, x2, x3);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_rename(PyObject *self, PyObject *args)
{
  git_strarray * x0;
  git_repository * x1;
  char const * x2;
  char const * x3;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 4, "git_remote_rename");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];
  arg3 = aa[3];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(441), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_strarray *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(441), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(49), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg3, (char **)&x3);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x3 = (char const *)alloca((size_t)datasize);
    memset((void *)x3, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x3, _cffi_type(10), arg3) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_rename(x0, x1, x2, x3); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_rename _cffi_d_git_remote_rename
#endif

static int _cffi_d_git_remote_set_pushurl(git_repository * x0, char const * x1, char const * x2)
{
  return git_remote_set_pushurl(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_set_pushurl(PyObject *self, PyObject *args)
{
  git_repository * x0;
  char const * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 3, "git_remote_set_pushurl");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(49), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_set_pushurl(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_set_pushurl _cffi_d_git_remote_set_pushurl
#endif

static int _cffi_d_git_remote_set_url(git_repository * x0, char const * x1, char const * x2)
{
  return git_remote_set_url(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_set_url(PyObject *self, PyObject *args)
{
  git_repository * x0;
  char const * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 3, "git_remote_set_url");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(49), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_set_url(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_remote_set_url _cffi_d_git_remote_set_url
#endif

static git_transfer_progress const * _cffi_d_git_remote_stats(git_remote * x0)
{
  return git_remote_stats(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_stats(PyObject *self, PyObject *arg0)
{
  git_remote * x0;
  Py_ssize_t datasize;
  git_transfer_progress const * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(31), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(31), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_stats(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(460));
}
#else
#  define _cffi_f_git_remote_stats _cffi_d_git_remote_stats
#endif

static char const * _cffi_d_git_remote_url(git_remote const * x0)
{
  return git_remote_url(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_remote_url(PyObject *self, PyObject *arg0)
{
  git_remote const * x0;
  Py_ssize_t datasize;
  char const * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(4), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_remote const *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(4), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_remote_url(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(10));
}
#else
#  define _cffi_f_git_remote_url _cffi_d_git_remote_url
#endif

static int _cffi_d_git_repository_config(git_config * * x0, git_repository * x1)
{
  return git_repository_config(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_repository_config(PyObject *self, PyObject *args)
{
  git_config * * x0;
  git_repository * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_repository_config");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(111), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(111), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(49), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_repository_config(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_repository_config _cffi_d_git_repository_config
#endif

static int _cffi_d_git_repository_config_snapshot(git_config * * x0, git_repository * x1)
{
  return git_repository_config_snapshot(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_repository_config_snapshot(PyObject *self, PyObject *args)
{
  git_config * * x0;
  git_repository * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_repository_config_snapshot");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(111), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_config * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(111), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(49), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_repository_config_snapshot(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_repository_config_snapshot _cffi_d_git_repository_config_snapshot
#endif

static void _cffi_d_git_repository_free(git_repository * x0)
{
  git_repository_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_repository_free(PyObject *self, PyObject *arg0)
{
  git_repository * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(49), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { git_repository_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_git_repository_free _cffi_d_git_repository_free
#endif

static int _cffi_d_git_repository_ident(char const * * x0, char const * * x1, git_repository const * x2)
{
  return git_repository_ident(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_repository_ident(PyObject *self, PyObject *args)
{
  char const * * x0;
  char const * * x1;
  git_repository const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 3, "git_repository_ident");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(38), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (char const * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(38), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(38), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const * *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(38), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(40), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_repository const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(40), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_repository_ident(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_repository_ident _cffi_d_git_repository_ident
#endif

static int _cffi_d_git_repository_index(git_index * * x0, git_repository * x1)
{
  return git_repository_index(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_repository_index(PyObject *self, PyObject *args)
{
  git_index * * x0;
  git_repository * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_repository_index");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(226), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_index * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(226), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(49), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_repository_index(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_repository_index _cffi_d_git_repository_index
#endif

static int _cffi_d_git_repository_init(git_repository * * x0, char const * x1, unsigned int x2)
{
  return git_repository_init(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_repository_init(PyObject *self, PyObject *args)
{
  git_repository * * x0;
  char const * x1;
  unsigned int x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 3, "git_repository_init");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(381), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(381), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, unsigned int);
  if (x2 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_repository_init(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_repository_init _cffi_d_git_repository_init
#endif

static int _cffi_d_git_repository_init_ext(git_repository * * x0, char const * x1, git_repository_init_options * x2)
{
  return git_repository_init_ext(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_repository_init_ext(PyObject *self, PyObject *args)
{
  git_repository * * x0;
  char const * x1;
  git_repository_init_options * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 3, "git_repository_init_ext");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(381), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(381), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(389), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (git_repository_init_options *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(389), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_repository_init_ext(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_repository_init_ext _cffi_d_git_repository_init_ext
#endif

static int _cffi_d_git_repository_init_init_options(git_repository_init_options * x0, int x1)
{
  return git_repository_init_init_options(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_repository_init_init_options(PyObject *self, PyObject *args)
{
  git_repository_init_options * x0;
  int x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_repository_init_init_options");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(389), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository_init_options *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(389), arg0) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_repository_init_init_options(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_repository_init_init_options _cffi_d_git_repository_init_init_options
#endif

static int _cffi_d_git_repository_set_head(git_repository * x0, char const * x1)
{
  return git_repository_set_head(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_repository_set_head(PyObject *self, PyObject *args)
{
  git_repository * x0;
  char const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_repository_set_head");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(49), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_repository_set_head(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_repository_set_head _cffi_d_git_repository_set_head
#endif

static int _cffi_d_git_repository_set_head_detached(git_repository * x0, git_oid const * x1)
{
  return git_repository_set_head_detached(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_repository_set_head_detached(PyObject *self, PyObject *args)
{
  git_repository * x0;
  git_oid const * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_repository_set_head_detached");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(49), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(61), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_oid const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(61), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_repository_set_head_detached(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_repository_set_head_detached _cffi_d_git_repository_set_head_detached
#endif

static int _cffi_d_git_repository_set_ident(git_repository * x0, char const * x1, char const * x2)
{
  return git_repository_set_ident(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_repository_set_ident(PyObject *self, PyObject *args)
{
  git_repository * x0;
  char const * x1;
  char const * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 3, "git_repository_set_ident");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(49), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (char const *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(10), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(10), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char const *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(10), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_repository_set_ident(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_repository_set_ident _cffi_d_git_repository_set_ident
#endif

static int _cffi_d_git_repository_state_cleanup(git_repository * x0)
{
  return git_repository_state_cleanup(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_repository_state_cleanup(PyObject *self, PyObject *arg0)
{
  git_repository * x0;
  Py_ssize_t datasize;
  int result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(49), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_repository_state_cleanup(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_repository_state_cleanup _cffi_d_git_repository_state_cleanup
#endif

static void _cffi_d_git_strarray_free(git_strarray * x0)
{
  git_strarray_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_strarray_free(PyObject *self, PyObject *arg0)
{
  git_strarray * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(441), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_strarray *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(441), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { git_strarray_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_git_strarray_free _cffi_d_git_strarray_free
#endif

static char const * _cffi_d_git_submodule_branch(git_submodule * x0)
{
  return git_submodule_branch(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_submodule_branch(PyObject *self, PyObject *arg0)
{
  git_submodule * x0;
  Py_ssize_t datasize;
  char const * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_submodule *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(7), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_submodule_branch(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(10));
}
#else
#  define _cffi_f_git_submodule_branch _cffi_d_git_submodule_branch
#endif

static void _cffi_d_git_submodule_free(git_submodule * x0)
{
  git_submodule_free(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_submodule_free(PyObject *self, PyObject *arg0)
{
  git_submodule * x0;
  Py_ssize_t datasize;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_submodule *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(7), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { git_submodule_free(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_git_submodule_free _cffi_d_git_submodule_free
#endif

static int _cffi_d_git_submodule_lookup(git_submodule * * x0, git_repository * x1, char * x2)
{
  return git_submodule_lookup(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_submodule_lookup(PyObject *self, PyObject *args)
{
  git_submodule * * x0;
  git_repository * x1;
  char * x2;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 3, "git_submodule_lookup");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];
  arg2 = aa[2];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(455), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_submodule * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(455), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_repository *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(49), arg1) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(457), arg2, (char **)&x2);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x2 = (char *)alloca((size_t)datasize);
    memset((void *)x2, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x2, _cffi_type(457), arg2) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_submodule_lookup(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_submodule_lookup _cffi_d_git_submodule_lookup
#endif

static char const * _cffi_d_git_submodule_name(git_submodule * x0)
{
  return git_submodule_name(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_submodule_name(PyObject *self, PyObject *arg0)
{
  git_submodule * x0;
  Py_ssize_t datasize;
  char const * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_submodule *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(7), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_submodule_name(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(10));
}
#else
#  define _cffi_f_git_submodule_name _cffi_d_git_submodule_name
#endif

static int _cffi_d_git_submodule_open(git_repository * * x0, git_submodule * x1)
{
  return git_submodule_open(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_submodule_open(PyObject *self, PyObject *args)
{
  git_repository * * x0;
  git_submodule * x1;
  Py_ssize_t datasize;
  int result;
  PyObject *arg0;
  PyObject *arg1;
  PyObject **aa;

  aa = _cffi_unpack_args(args, 2, "git_submodule_open");
  if (aa == NULL)
    return NULL;
  arg0 = aa[0];
  arg1 = aa[1];

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(381), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_repository * *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(381), arg0) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg1, (char **)&x1);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x1 = (git_submodule *)alloca((size_t)datasize);
    memset((void *)x1, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x1, _cffi_type(7), arg1) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_submodule_open(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_int(result, int);
}
#else
#  define _cffi_f_git_submodule_open _cffi_d_git_submodule_open
#endif

static char const * _cffi_d_git_submodule_path(git_submodule * x0)
{
  return git_submodule_path(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_submodule_path(PyObject *self, PyObject *arg0)
{
  git_submodule * x0;
  Py_ssize_t datasize;
  char const * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_submodule *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(7), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_submodule_path(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(10));
}
#else
#  define _cffi_f_git_submodule_path _cffi_d_git_submodule_path
#endif

static char const * _cffi_d_git_submodule_url(git_submodule * x0)
{
  return git_submodule_url(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_git_submodule_url(PyObject *self, PyObject *arg0)
{
  git_submodule * x0;
  Py_ssize_t datasize;
  char const * result;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(7), arg0, (char **)&x0);
  if (datasize != 0) {
    if (datasize < 0)
      return NULL;
    x0 = (git_submodule *)alloca((size_t)datasize);
    memset((void *)x0, 0, (size_t)datasize);
    if (_cffi_convert_array_from_object((char *)x0, _cffi_type(7), arg0) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = git_submodule_url(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(10));
}
#else
#  define _cffi_f_git_submodule_url _cffi_d_git_submodule_url
#endif

static git_error const * _cffi_d_giterr_last(void)
{
  return giterr_last();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_giterr_last(PyObject *self, PyObject *noarg)
{
  git_error const * result;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = giterr_last(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  return _cffi_from_c_pointer((char *)result, _cffi_type(613));
}
#else
#  define _cffi_f_giterr_last _cffi_d_giterr_last
#endif

static int _cffi_const_GIT_ATTR_CHECK_FILE_THEN_INDEX(unsigned long long *o)
{
  int n = (GIT_ATTR_CHECK_FILE_THEN_INDEX) <= 0;
  *o = (unsigned long long)((GIT_ATTR_CHECK_FILE_THEN_INDEX) << 0);  /* check that GIT_ATTR_CHECK_FILE_THEN_INDEX is an integer */
  return n;
}

static int _cffi_const_GIT_ATTR_CHECK_INDEX_ONLY(unsigned long long *o)
{
  int n = (GIT_ATTR_CHECK_INDEX_ONLY) <= 0;
  *o = (unsigned long long)((GIT_ATTR_CHECK_INDEX_ONLY) << 0);  /* check that GIT_ATTR_CHECK_INDEX_ONLY is an integer */
  return n;
}

static int _cffi_const_GIT_ATTR_CHECK_INDEX_THEN_FILE(unsigned long long *o)
{
  int n = (GIT_ATTR_CHECK_INDEX_THEN_FILE) <= 0;
  *o = (unsigned long long)((GIT_ATTR_CHECK_INDEX_THEN_FILE) << 0);  /* check that GIT_ATTR_CHECK_INDEX_THEN_FILE is an integer */
  return n;
}

static int _cffi_const_GIT_ATTR_CHECK_NO_SYSTEM(unsigned long long *o)
{
  int n = (GIT_ATTR_CHECK_NO_SYSTEM) <= 0;
  *o = (unsigned long long)((GIT_ATTR_CHECK_NO_SYSTEM) << 0);  /* check that GIT_ATTR_CHECK_NO_SYSTEM is an integer */
  return n;
}

static int _cffi_const_GIT_BLAME_OPTIONS_VERSION(unsigned long long *o)
{
  int n = (GIT_BLAME_OPTIONS_VERSION) <= 0;
  *o = (unsigned long long)((GIT_BLAME_OPTIONS_VERSION) << 0);  /* check that GIT_BLAME_OPTIONS_VERSION is an integer */
  return n;
}

static int _cffi_const_GIT_CLONE_OPTIONS_VERSION(unsigned long long *o)
{
  int n = (GIT_CLONE_OPTIONS_VERSION) <= 0;
  *o = (unsigned long long)((GIT_CLONE_OPTIONS_VERSION) << 0);  /* check that GIT_CLONE_OPTIONS_VERSION is an integer */
  return n;
}

static int _cffi_const_GIT_FEATURE_HTTPS(unsigned long long *o)
{
  int n = (GIT_FEATURE_HTTPS) <= 0;
  *o = (unsigned long long)((GIT_FEATURE_HTTPS) << 0);  /* check that GIT_FEATURE_HTTPS is an integer */
  return n;
}

static int _cffi_const_GIT_FEATURE_SSH(unsigned long long *o)
{
  int n = (GIT_FEATURE_SSH) <= 0;
  *o = (unsigned long long)((GIT_FEATURE_SSH) << 0);  /* check that GIT_FEATURE_SSH is an integer */
  return n;
}

static int _cffi_const_GIT_FEATURE_THREADS(unsigned long long *o)
{
  int n = (GIT_FEATURE_THREADS) <= 0;
  *o = (unsigned long long)((GIT_FEATURE_THREADS) << 0);  /* check that GIT_FEATURE_THREADS is an integer */
  return n;
}

static int _cffi_const_GIT_FETCH_OPTIONS_VERSION(unsigned long long *o)
{
  int n = (GIT_FETCH_OPTIONS_VERSION) <= 0;
  *o = (unsigned long long)((GIT_FETCH_OPTIONS_VERSION) << 0);  /* check that GIT_FETCH_OPTIONS_VERSION is an integer */
  return n;
}

static int _cffi_const_GIT_MERGE_OPTIONS_VERSION(unsigned long long *o)
{
  int n = (GIT_MERGE_OPTIONS_VERSION) <= 0;
  *o = (unsigned long long)((GIT_MERGE_OPTIONS_VERSION) << 0);  /* check that GIT_MERGE_OPTIONS_VERSION is an integer */
  return n;
}

static int _cffi_const_GIT_OID_RAWSZ(unsigned long long *o)
{
  int n = (GIT_OID_RAWSZ) <= 0;
  *o = (unsigned long long)((GIT_OID_RAWSZ) << 0);  /* check that GIT_OID_RAWSZ is an integer */
  return n;
}

static int _cffi_const_GIT_PATH_MAX(unsigned long long *o)
{
  int n = (GIT_PATH_MAX) <= 0;
  *o = (unsigned long long)((GIT_PATH_MAX) << 0);  /* check that GIT_PATH_MAX is an integer */
  return n;
}

static int _cffi_const_GIT_PUSH_OPTIONS_VERSION(unsigned long long *o)
{
  int n = (GIT_PUSH_OPTIONS_VERSION) <= 0;
  *o = (unsigned long long)((GIT_PUSH_OPTIONS_VERSION) << 0);  /* check that GIT_PUSH_OPTIONS_VERSION is an integer */
  return n;
}

static int _cffi_const_GIT_REMOTE_CALLBACKS_VERSION(unsigned long long *o)
{
  int n = (GIT_REMOTE_CALLBACKS_VERSION) <= 0;
  *o = (unsigned long long)((GIT_REMOTE_CALLBACKS_VERSION) << 0);  /* check that GIT_REMOTE_CALLBACKS_VERSION is an integer */
  return n;
}

static int _cffi_const_GIT_REPOSITORY_INIT_OPTIONS_VERSION(unsigned long long *o)
{
  int n = (GIT_REPOSITORY_INIT_OPTIONS_VERSION) <= 0;
  *o = (unsigned long long)((GIT_REPOSITORY_INIT_OPTIONS_VERSION) << 0);  /* check that GIT_REPOSITORY_INIT_OPTIONS_VERSION is an integer */
  return n;
}

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_blame_hunk(git_blame_hunk *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->lines_in_hunk) << 1);  /* check that 'git_blame_hunk.lines_in_hunk' is an integer */
  { git_oid *tmp = &p->final_commit_id; (void)tmp; }
  (void)((p->final_start_line_number) << 1);  /* check that 'git_blame_hunk.final_start_line_number' is an integer */
  { git_signature * *tmp = &p->final_signature; (void)tmp; }
  { git_oid *tmp = &p->orig_commit_id; (void)tmp; }
  { char const * *tmp = &p->orig_path; (void)tmp; }
  (void)((p->orig_start_line_number) << 1);  /* check that 'git_blame_hunk.orig_start_line_number' is an integer */
  { git_signature * *tmp = &p->orig_signature; (void)tmp; }
  { char *tmp = &p->boundary; (void)tmp; }
}
struct _cffi_align__git_blame_hunk { char x; git_blame_hunk y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_blame_options(git_blame_options *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->version) << 1);  /* check that 'git_blame_options.version' is an integer */
  (void)((p->flags) << 1);  /* check that 'git_blame_options.flags' is an integer */
  (void)((p->min_match_characters) << 1);  /* check that 'git_blame_options.min_match_characters' is an integer */
  { git_oid *tmp = &p->newest_commit; (void)tmp; }
  { git_oid *tmp = &p->oldest_commit; (void)tmp; }
  (void)((p->min_line) << 1);  /* check that 'git_blame_options.min_line' is an integer */
  (void)((p->max_line) << 1);  /* check that 'git_blame_options.max_line' is an integer */
}
struct _cffi_align__git_blame_options { char x; git_blame_options y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_checkout_options(git_checkout_options *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->version) << 1);  /* check that 'git_checkout_options.version' is an integer */
  (void)((p->checkout_strategy) << 1);  /* check that 'git_checkout_options.checkout_strategy' is an integer */
  (void)((p->disable_filters) << 1);  /* check that 'git_checkout_options.disable_filters' is an integer */
  (void)((p->dir_mode) << 1);  /* check that 'git_checkout_options.dir_mode' is an integer */
  (void)((p->file_mode) << 1);  /* check that 'git_checkout_options.file_mode' is an integer */
  (void)((p->file_open_flags) << 1);  /* check that 'git_checkout_options.file_open_flags' is an integer */
  (void)((p->notify_flags) << 1);  /* check that 'git_checkout_options.notify_flags' is an integer */
  { int(* *tmp)(git_checkout_notify_t, char const *, git_diff_file const *, git_diff_file const *, git_diff_file const *, void *) = &p->notify_cb; (void)tmp; }
  { void * *tmp = &p->notify_payload; (void)tmp; }
  { void(* *tmp)(char const *, size_t, size_t, void *) = &p->progress_cb; (void)tmp; }
  { void * *tmp = &p->progress_payload; (void)tmp; }
  { git_strarray *tmp = &p->paths; (void)tmp; }
  { git_tree * *tmp = &p->baseline; (void)tmp; }
  { git_index * *tmp = &p->baseline_index; (void)tmp; }
  { char const * *tmp = &p->target_directory; (void)tmp; }
  { char const * *tmp = &p->ancestor_label; (void)tmp; }
  { char const * *tmp = &p->our_label; (void)tmp; }
  { char const * *tmp = &p->their_label; (void)tmp; }
  { void(* *tmp)(git_checkout_perfdata const *, void *) = &p->perfdata_cb; (void)tmp; }
  { void * *tmp = &p->perfdata_payload; (void)tmp; }
}
struct _cffi_align__git_checkout_options { char x; git_checkout_options y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_clone_options(git_clone_options *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->version) << 1);  /* check that 'git_clone_options.version' is an integer */
  { git_checkout_options *tmp = &p->checkout_opts; (void)tmp; }
  { git_fetch_options *tmp = &p->fetch_opts; (void)tmp; }
  (void)((p->bare) << 1);  /* check that 'git_clone_options.bare' is an integer */
  { git_clone_local_t *tmp = &p->local; (void)tmp; }
  { char const * *tmp = &p->checkout_branch; (void)tmp; }
  { int(* *tmp)(git_repository * *, char const *, int, void *) = &p->repository_cb; (void)tmp; }
  { void * *tmp = &p->repository_cb_payload; (void)tmp; }
  { int(* *tmp)(git_remote * *, git_repository *, char const *, char const *, void *) = &p->remote_cb; (void)tmp; }
  { void * *tmp = &p->remote_cb_payload; (void)tmp; }
}
struct _cffi_align__git_clone_options { char x; git_clone_options y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_config_entry(git_config_entry *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char const * *tmp = &p->name; (void)tmp; }
  { char const * *tmp = &p->value; (void)tmp; }
  { git_config_level_t *tmp = &p->level; (void)tmp; }
  { void(* *tmp)(git_config_entry *) = &p->free; (void)tmp; }
  { void * *tmp = &p->payload; (void)tmp; }
}
struct _cffi_align__git_config_entry { char x; git_config_entry y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_index_entry(git_index_entry *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { git_index_time *tmp = &p->ctime; (void)tmp; }
  { git_index_time *tmp = &p->mtime; (void)tmp; }
  (void)((p->dev) << 1);  /* check that 'git_index_entry.dev' is an integer */
  (void)((p->ino) << 1);  /* check that 'git_index_entry.ino' is an integer */
  (void)((p->mode) << 1);  /* check that 'git_index_entry.mode' is an integer */
  (void)((p->uid) << 1);  /* check that 'git_index_entry.uid' is an integer */
  (void)((p->gid) << 1);  /* check that 'git_index_entry.gid' is an integer */
  (void)((p->file_size) << 1);  /* check that 'git_index_entry.file_size' is an integer */
  { git_oid *tmp = &p->id; (void)tmp; }
  (void)((p->flags) << 1);  /* check that 'git_index_entry.flags' is an integer */
  (void)((p->flags_extended) << 1);  /* check that 'git_index_entry.flags_extended' is an integer */
  { char const * *tmp = &p->path; (void)tmp; }
}
struct _cffi_align__git_index_entry { char x; git_index_entry y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_oid(git_oid *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { unsigned char(*tmp)[20] = &p->id; (void)tmp; }
}
struct _cffi_align__git_oid { char x; git_oid y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_remote_callbacks(git_remote_callbacks *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->version) << 1);  /* check that 'git_remote_callbacks.version' is an integer */
  { int(* *tmp)(char const *, int, void *) = &p->sideband_progress; (void)tmp; }
  { int(* *tmp)(git_remote_completion_type, void *) = &p->completion; (void)tmp; }
  { int(* *tmp)(git_cred * *, char const *, char const *, unsigned int, void *) = &p->credentials; (void)tmp; }
  { int(* *tmp)(git_cert *, int, char const *, void *) = &p->certificate_check; (void)tmp; }
  { int(* *tmp)(git_transfer_progress const *, void *) = &p->transfer_progress; (void)tmp; }
  { int(* *tmp)(char const *, git_oid const *, git_oid const *, void *) = &p->update_tips; (void)tmp; }
  { int(* *tmp)(int, unsigned int, unsigned int, void *) = &p->pack_progress; (void)tmp; }
  { int(* *tmp)(unsigned int, unsigned int, size_t, void *) = &p->push_transfer_progress; (void)tmp; }
  { int(* *tmp)(char const *, char const *, void *) = &p->push_update_reference; (void)tmp; }
  { int(* *tmp)(git_push_update const * *, size_t, void *) = &p->push_negotiation; (void)tmp; }
  { int(* *tmp)(git_transport * *, git_remote *, void *) = &p->transport; (void)tmp; }
  { void * *tmp = &p->payload; (void)tmp; }
}
struct _cffi_align__git_remote_callbacks { char x; git_remote_callbacks y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_signature(git_signature *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char * *tmp = &p->name; (void)tmp; }
  { char * *tmp = &p->email; (void)tmp; }
  { git_time *tmp = &p->when; (void)tmp; }
}
struct _cffi_align__git_signature { char x; git_signature y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_strarray(git_strarray *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { char * * *tmp = &p->strings; (void)tmp; }
  (void)((p->count) << 1);  /* check that 'git_strarray.count' is an integer */
}
struct _cffi_align__git_strarray { char x; git_strarray y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_time(git_time *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->time) << 1);  /* check that 'git_time.time' is an integer */
  (void)((p->offset) << 1);  /* check that 'git_time.offset' is an integer */
}
struct _cffi_align__git_time { char x; git_time y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld__git_transfer_progress(git_transfer_progress *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->total_objects) << 1);  /* check that 'git_transfer_progress.total_objects' is an integer */
  (void)((p->indexed_objects) << 1);  /* check that 'git_transfer_progress.indexed_objects' is an integer */
  (void)((p->received_objects) << 1);  /* check that 'git_transfer_progress.received_objects' is an integer */
  (void)((p->local_objects) << 1);  /* check that 'git_transfer_progress.local_objects' is an integer */
  (void)((p->total_deltas) << 1);  /* check that 'git_transfer_progress.total_deltas' is an integer */
  (void)((p->indexed_deltas) << 1);  /* check that 'git_transfer_progress.indexed_deltas' is an integer */
  (void)((p->received_bytes) << 1);  /* check that 'git_transfer_progress.received_bytes' is an integer */
}
struct _cffi_align__git_transfer_progress { char x; git_transfer_progress y; };

static const struct _cffi_global_s _cffi_globals[] = {
  { "GIT_ATTR_CHECK_FILE_THEN_INDEX", (void *)_cffi_const_GIT_ATTR_CHECK_FILE_THEN_INDEX, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_ATTR_CHECK_INDEX_ONLY", (void *)_cffi_const_GIT_ATTR_CHECK_INDEX_ONLY, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_ATTR_CHECK_INDEX_THEN_FILE", (void *)_cffi_const_GIT_ATTR_CHECK_INDEX_THEN_FILE, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_ATTR_CHECK_NO_SYSTEM", (void *)_cffi_const_GIT_ATTR_CHECK_NO_SYSTEM, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_ATTR_FALSE_T", (void *)_cffi_const_GIT_ATTR_FALSE_T, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_ATTR_TRUE_T", (void *)_cffi_const_GIT_ATTR_TRUE_T, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_ATTR_UNSPECIFIED_T", (void *)_cffi_const_GIT_ATTR_UNSPECIFIED_T, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_ATTR_VALUE_T", (void *)_cffi_const_GIT_ATTR_VALUE_T, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_BLAME_OPTIONS_VERSION", (void *)_cffi_const_GIT_BLAME_OPTIONS_VERSION, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_CERT_HOSTKEY_LIBSSH2", (void *)_cffi_const_GIT_CERT_HOSTKEY_LIBSSH2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CERT_NONE", (void *)_cffi_const_GIT_CERT_NONE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CERT_SSH_MD5", (void *)_cffi_const_GIT_CERT_SSH_MD5, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CERT_SSH_SHA1", (void *)_cffi_const_GIT_CERT_SSH_SHA1, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CERT_X509", (void *)_cffi_const_GIT_CERT_X509, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CLONE_LOCAL", (void *)_cffi_const_GIT_CLONE_LOCAL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CLONE_LOCAL_AUTO", (void *)_cffi_const_GIT_CLONE_LOCAL_AUTO, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CLONE_LOCAL_NO_LINKS", (void *)_cffi_const_GIT_CLONE_LOCAL_NO_LINKS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CLONE_NO_LOCAL", (void *)_cffi_const_GIT_CLONE_NO_LOCAL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CLONE_OPTIONS_VERSION", (void *)_cffi_const_GIT_CLONE_OPTIONS_VERSION, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_CONFIG_HIGHEST_LEVEL", (void *)_cffi_const_GIT_CONFIG_HIGHEST_LEVEL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CONFIG_LEVEL_APP", (void *)_cffi_const_GIT_CONFIG_LEVEL_APP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CONFIG_LEVEL_GLOBAL", (void *)_cffi_const_GIT_CONFIG_LEVEL_GLOBAL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CONFIG_LEVEL_LOCAL", (void *)_cffi_const_GIT_CONFIG_LEVEL_LOCAL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CONFIG_LEVEL_SYSTEM", (void *)_cffi_const_GIT_CONFIG_LEVEL_SYSTEM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CONFIG_LEVEL_XDG", (void *)_cffi_const_GIT_CONFIG_LEVEL_XDG, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CREDTYPE_DEFAULT", (void *)_cffi_const_GIT_CREDTYPE_DEFAULT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CREDTYPE_SSH_CUSTOM", (void *)_cffi_const_GIT_CREDTYPE_SSH_CUSTOM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CREDTYPE_SSH_INTERACTIVE", (void *)_cffi_const_GIT_CREDTYPE_SSH_INTERACTIVE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CREDTYPE_SSH_KEY", (void *)_cffi_const_GIT_CREDTYPE_SSH_KEY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CREDTYPE_USERNAME", (void *)_cffi_const_GIT_CREDTYPE_USERNAME, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_CREDTYPE_USERPASS_PLAINTEXT", (void *)_cffi_const_GIT_CREDTYPE_USERPASS_PLAINTEXT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DELTA_ADDED", (void *)_cffi_const_GIT_DELTA_ADDED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DELTA_COPIED", (void *)_cffi_const_GIT_DELTA_COPIED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DELTA_DELETED", (void *)_cffi_const_GIT_DELTA_DELETED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DELTA_IGNORED", (void *)_cffi_const_GIT_DELTA_IGNORED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DELTA_MODIFIED", (void *)_cffi_const_GIT_DELTA_MODIFIED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DELTA_RENAMED", (void *)_cffi_const_GIT_DELTA_RENAMED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DELTA_TYPECHANGE", (void *)_cffi_const_GIT_DELTA_TYPECHANGE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DELTA_UNMODIFIED", (void *)_cffi_const_GIT_DELTA_UNMODIFIED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DELTA_UNTRACKED", (void *)_cffi_const_GIT_DELTA_UNTRACKED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DIRECTION_FETCH", (void *)_cffi_const_GIT_DIRECTION_FETCH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_DIRECTION_PUSH", (void *)_cffi_const_GIT_DIRECTION_PUSH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EAMBIGUOUS", (void *)_cffi_const_GIT_EAMBIGUOUS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EBAREREPO", (void *)_cffi_const_GIT_EBAREREPO, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EBUFS", (void *)_cffi_const_GIT_EBUFS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_ECONFLICT", (void *)_cffi_const_GIT_ECONFLICT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EEXISTS", (void *)_cffi_const_GIT_EEXISTS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EINVALIDSPEC", (void *)_cffi_const_GIT_EINVALIDSPEC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_ELOCKED", (void *)_cffi_const_GIT_ELOCKED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_ENONFASTFORWARD", (void *)_cffi_const_GIT_ENONFASTFORWARD, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_ENOTFOUND", (void *)_cffi_const_GIT_ENOTFOUND, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_ERROR", (void *)_cffi_const_GIT_ERROR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EUNBORNBRANCH", (void *)_cffi_const_GIT_EUNBORNBRANCH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EUNMERGED", (void *)_cffi_const_GIT_EUNMERGED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_EUSER", (void *)_cffi_const_GIT_EUSER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_FEATURE_HTTPS", (void *)_cffi_const_GIT_FEATURE_HTTPS, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_FEATURE_SSH", (void *)_cffi_const_GIT_FEATURE_SSH, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_FEATURE_THREADS", (void *)_cffi_const_GIT_FEATURE_THREADS, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_FETCH_NO_PRUNE", (void *)_cffi_const_GIT_FETCH_NO_PRUNE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_FETCH_OPTIONS_VERSION", (void *)_cffi_const_GIT_FETCH_OPTIONS_VERSION, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_FETCH_PRUNE", (void *)_cffi_const_GIT_FETCH_PRUNE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_FETCH_PRUNE_UNSPECIFIED", (void *)_cffi_const_GIT_FETCH_PRUNE_UNSPECIFIED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_ITEROVER", (void *)_cffi_const_GIT_ITEROVER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_FILE_DEFAULT", (void *)_cffi_const_GIT_MERGE_FILE_DEFAULT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_FILE_FAVOR_NORMAL", (void *)_cffi_const_GIT_MERGE_FILE_FAVOR_NORMAL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_FILE_FAVOR_OURS", (void *)_cffi_const_GIT_MERGE_FILE_FAVOR_OURS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_FILE_FAVOR_THEIRS", (void *)_cffi_const_GIT_MERGE_FILE_FAVOR_THEIRS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_FILE_FAVOR_UNION", (void *)_cffi_const_GIT_MERGE_FILE_FAVOR_UNION, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_FILE_SIMPLIFY_ALNUM", (void *)_cffi_const_GIT_MERGE_FILE_SIMPLIFY_ALNUM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_FILE_STYLE_DIFF3", (void *)_cffi_const_GIT_MERGE_FILE_STYLE_DIFF3, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_FILE_STYLE_MERGE", (void *)_cffi_const_GIT_MERGE_FILE_STYLE_MERGE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_MERGE_OPTIONS_VERSION", (void *)_cffi_const_GIT_MERGE_OPTIONS_VERSION, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_OID_RAWSZ", (void *)_cffi_const_GIT_OID_RAWSZ, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_OK", (void *)_cffi_const_GIT_OK, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_PASSTHROUGH", (void *)_cffi_const_GIT_PASSTHROUGH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_PATH_MAX", (void *)_cffi_const_GIT_PATH_MAX, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_PUSH_OPTIONS_VERSION", (void *)_cffi_const_GIT_PUSH_OPTIONS_VERSION, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_REF_INVALID", (void *)_cffi_const_GIT_REF_INVALID, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REF_LISTALL", (void *)_cffi_const_GIT_REF_LISTALL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REF_OID", (void *)_cffi_const_GIT_REF_OID, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REF_SYMBOLIC", (void *)_cffi_const_GIT_REF_SYMBOLIC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REMOTE_CALLBACKS_VERSION", (void *)_cffi_const_GIT_REMOTE_CALLBACKS_VERSION, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_REMOTE_COMPLETION_DOWNLOAD", (void *)_cffi_const_GIT_REMOTE_COMPLETION_DOWNLOAD, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REMOTE_COMPLETION_ERROR", (void *)_cffi_const_GIT_REMOTE_COMPLETION_ERROR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REMOTE_COMPLETION_INDEXING", (void *)_cffi_const_GIT_REMOTE_COMPLETION_INDEXING, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REMOTE_DOWNLOAD_TAGS_ALL", (void *)_cffi_const_GIT_REMOTE_DOWNLOAD_TAGS_ALL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REMOTE_DOWNLOAD_TAGS_AUTO", (void *)_cffi_const_GIT_REMOTE_DOWNLOAD_TAGS_AUTO, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REMOTE_DOWNLOAD_TAGS_NONE", (void *)_cffi_const_GIT_REMOTE_DOWNLOAD_TAGS_NONE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REMOTE_DOWNLOAD_TAGS_UNSPECIFIED", (void *)_cffi_const_GIT_REMOTE_DOWNLOAD_TAGS_UNSPECIFIED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REPOSITORY_INIT_BARE", (void *)_cffi_const_GIT_REPOSITORY_INIT_BARE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REPOSITORY_INIT_EXTERNAL_TEMPLATE", (void *)_cffi_const_GIT_REPOSITORY_INIT_EXTERNAL_TEMPLATE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REPOSITORY_INIT_MKDIR", (void *)_cffi_const_GIT_REPOSITORY_INIT_MKDIR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REPOSITORY_INIT_MKPATH", (void *)_cffi_const_GIT_REPOSITORY_INIT_MKPATH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REPOSITORY_INIT_NO_DOTGIT_DIR", (void *)_cffi_const_GIT_REPOSITORY_INIT_NO_DOTGIT_DIR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REPOSITORY_INIT_NO_REINIT", (void *)_cffi_const_GIT_REPOSITORY_INIT_NO_REINIT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REPOSITORY_INIT_OPTIONS_VERSION", (void *)_cffi_const_GIT_REPOSITORY_INIT_OPTIONS_VERSION, _CFFI_OP(_CFFI_OP_CONSTANT_INT, -1), (void *)0 },
  { "GIT_REPOSITORY_INIT_RELATIVE_GITLINK", (void *)_cffi_const_GIT_REPOSITORY_INIT_RELATIVE_GITLINK, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REPOSITORY_INIT_SHARED_ALL", (void *)_cffi_const_GIT_REPOSITORY_INIT_SHARED_ALL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REPOSITORY_INIT_SHARED_GROUP", (void *)_cffi_const_GIT_REPOSITORY_INIT_SHARED_GROUP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_REPOSITORY_INIT_SHARED_UMASK", (void *)_cffi_const_GIT_REPOSITORY_INIT_SHARED_UMASK, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_SUBMODULE_IGNORE_ALL", (void *)_cffi_const_GIT_SUBMODULE_IGNORE_ALL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_SUBMODULE_IGNORE_DIRTY", (void *)_cffi_const_GIT_SUBMODULE_IGNORE_DIRTY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_SUBMODULE_IGNORE_NONE", (void *)_cffi_const_GIT_SUBMODULE_IGNORE_NONE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_SUBMODULE_IGNORE_UNSPECIFIED", (void *)_cffi_const_GIT_SUBMODULE_IGNORE_UNSPECIFIED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "GIT_SUBMODULE_IGNORE_UNTRACKED", (void *)_cffi_const_GIT_SUBMODULE_IGNORE_UNTRACKED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "git_attr_get", (void *)_cffi_f_git_attr_get, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 47), (void *)_cffi_d_git_attr_get },
  { "git_attr_value", (void *)_cffi_f_git_attr_value, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 9), (void *)_cffi_d_git_attr_value },
  { "git_blame_file", (void *)_cffi_f_git_blame_file, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 70), (void *)_cffi_d_git_blame_file },
  { "git_blame_free", (void *)_cffi_f_git_blame_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 536), (void *)_cffi_d_git_blame_free },
  { "git_blame_get_hunk_byindex", (void *)_cffi_f_git_blame_get_hunk_byindex, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 12), (void *)_cffi_d_git_blame_get_hunk_byindex },
  { "git_blame_get_hunk_byline", (void *)_cffi_f_git_blame_get_hunk_byline, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 12), (void *)_cffi_d_git_blame_get_hunk_byline },
  { "git_blame_get_hunk_count", (void *)_cffi_f_git_blame_get_hunk_count, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 527), (void *)_cffi_d_git_blame_get_hunk_count },
  { "git_blame_init_options", (void *)_cffi_f_git_blame_init_options, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 76), (void *)_cffi_d_git_blame_init_options },
  { "git_buf_free", (void *)_cffi_f_git_buf_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 539), (void *)_cffi_d_git_buf_free },
  { "git_checkout_head", (void *)_cffi_f_git_checkout_head, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 418), (void *)_cffi_d_git_checkout_head },
  { "git_checkout_index", (void *)_cffi_f_git_checkout_index, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 422), (void *)_cffi_d_git_checkout_index },
  { "git_checkout_init_options", (void *)_cffi_f_git_checkout_init_options, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 102), (void *)_cffi_d_git_checkout_init_options },
  { "git_checkout_tree", (void *)_cffi_f_git_checkout_tree, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 427), (void *)_cffi_d_git_checkout_tree },
  { "git_clone", (void *)_cffi_f_git_clone, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 380), (void *)_cffi_d_git_clone },
  { "git_clone_init_options", (void *)_cffi_f_git_clone_init_options, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 106), (void *)_cffi_d_git_clone_init_options },
  { "git_config_add_file_ondisk", (void *)_cffi_f_git_config_add_file_ondisk, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 140), (void *)_cffi_d_git_config_add_file_ondisk },
  { "git_config_delete_entry", (void *)_cffi_f_git_config_delete_entry, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 125), (void *)_cffi_d_git_config_delete_entry },
  { "git_config_entry_free", (void *)_cffi_f_git_config_entry_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 549), (void *)_cffi_d_git_config_entry_free },
  { "git_config_find_global", (void *)_cffi_f_git_config_find_global, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 80), (void *)_cffi_d_git_config_find_global },
  { "git_config_find_system", (void *)_cffi_f_git_config_find_system, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 80), (void *)_cffi_d_git_config_find_system },
  { "git_config_find_xdg", (void *)_cffi_f_git_config_find_xdg, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 80), (void *)_cffi_d_git_config_find_xdg },
  { "git_config_free", (void *)_cffi_f_git_config_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 546), (void *)_cffi_d_git_config_free },
  { "git_config_get_entry", (void *)_cffi_f_git_config_get_entry, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 156), (void *)_cffi_d_git_config_get_entry },
  { "git_config_get_string", (void *)_cffi_f_git_config_get_string, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 42), (void *)_cffi_d_git_config_get_string },
  { "git_config_iterator_free", (void *)_cffi_f_git_config_iterator_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 552), (void *)_cffi_d_git_config_iterator_free },
  { "git_config_iterator_new", (void *)_cffi_f_git_config_iterator_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 165), (void *)_cffi_d_git_config_iterator_new },
  { "git_config_multivar_iterator_new", (void *)_cffi_f_git_config_multivar_iterator_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 169), (void *)_cffi_d_git_config_multivar_iterator_new },
  { "git_config_new", (void *)_cffi_f_git_config_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 110), (void *)_cffi_d_git_config_new },
  { "git_config_next", (void *)_cffi_f_git_config_next, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 161), (void *)_cffi_d_git_config_next },
  { "git_config_open_ondisk", (void *)_cffi_f_git_config_open_ondisk, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 113), (void *)_cffi_d_git_config_open_ondisk },
  { "git_config_parse_bool", (void *)_cffi_f_git_config_parse_bool, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 468), (void *)_cffi_d_git_config_parse_bool },
  { "git_config_parse_int64", (void *)_cffi_f_git_config_parse_int64, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 484), (void *)_cffi_d_git_config_parse_int64 },
  { "git_config_set_bool", (void *)_cffi_f_git_config_set_bool, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 146), (void *)_cffi_d_git_config_set_bool },
  { "git_config_set_int64", (void *)_cffi_f_git_config_set_int64, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 151), (void *)_cffi_d_git_config_set_int64 },
  { "git_config_set_multivar", (void *)_cffi_f_git_config_set_multivar, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 134), (void *)_cffi_d_git_config_set_multivar },
  { "git_config_set_string", (void *)_cffi_f_git_config_set_string, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 129), (void *)_cffi_d_git_config_set_string },
  { "git_config_snapshot", (void *)_cffi_f_git_config_snapshot, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 117), (void *)_cffi_d_git_config_snapshot },
  { "git_cred_ssh_key_from_agent", (void *)_cffi_f_git_cred_ssh_key_from_agent, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 175), (void *)_cffi_d_git_cred_ssh_key_from_agent },
  { "git_cred_ssh_key_new", (void *)_cffi_f_git_cred_ssh_key_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 184), (void *)_cffi_d_git_cred_ssh_key_new },
  { "git_cred_userpass_plaintext_new", (void *)_cffi_f_git_cred_userpass_plaintext_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 179), (void *)_cffi_d_git_cred_userpass_plaintext_new },
  { "git_diff_index_to_workdir", (void *)_cffi_f_git_diff_index_to_workdir, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 198), (void *)_cffi_d_git_diff_index_to_workdir },
  { "git_diff_init_options", (void *)_cffi_f_git_diff_init_options, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 217), (void *)_cffi_d_git_diff_init_options },
  { "git_diff_tree_to_index", (void *)_cffi_f_git_diff_tree_to_index, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 204), (void *)_cffi_d_git_diff_tree_to_index },
  { "git_fetch_init_options", (void *)_cffi_f_git_fetch_init_options, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 221), (void *)_cffi_d_git_fetch_init_options },
  { "git_graph_ahead_behind", (void *)_cffi_f_git_graph_ahead_behind, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 493), (void *)_cffi_d_git_graph_ahead_behind },
  { "git_index_add", (void *)_cffi_f_git_index_add, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 260), (void *)_cffi_d_git_index_add },
  { "git_index_add_all", (void *)_cffi_f_git_index_add_all, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 264), (void *)_cffi_d_git_index_add_all },
  { "git_index_add_bypath", (void *)_cffi_f_git_index_add_bypath, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 251), (void *)_cffi_d_git_index_add_bypath },
  { "git_index_clear", (void *)_cffi_f_git_index_clear, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 248), (void *)_cffi_d_git_index_clear },
  { "git_index_conflict_get", (void *)_cffi_f_git_index_conflict_get, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 286), (void *)_cffi_d_git_index_conflict_get },
  { "git_index_conflict_iterator_free", (void *)_cffi_f_git_index_conflict_iterator_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 558), (void *)_cffi_d_git_index_conflict_iterator_free },
  { "git_index_conflict_iterator_new", (void *)_cffi_f_git_index_conflict_iterator_new, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 282), (void *)_cffi_d_git_index_conflict_iterator_new },
  { "git_index_conflict_next", (void *)_cffi_f_git_index_conflict_next, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 293), (void *)_cffi_d_git_index_conflict_next },
  { "git_index_conflict_remove", (void *)_cffi_f_git_index_conflict_remove, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 251), (void *)_cffi_d_git_index_conflict_remove },
  { "git_index_entrycount", (void *)_cffi_f_git_index_entrycount, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 521), (void *)_cffi_d_git_index_entrycount },
  { "git_index_find", (void *)_cffi_f_git_index_find, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 488), (void *)_cffi_d_git_index_find },
  { "git_index_free", (void *)_cffi_f_git_index_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 555), (void *)_cffi_d_git_index_free },
  { "git_index_get_byindex", (void *)_cffi_f_git_index_get_byindex, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 26), (void *)_cffi_d_git_index_get_byindex },
  { "git_index_get_bypath", (void *)_cffi_f_git_index_get_bypath, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 21), (void *)_cffi_d_git_index_get_bypath },
  { "git_index_has_conflicts", (void *)_cffi_f_git_index_has_conflicts, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 279), (void *)_cffi_d_git_index_has_conflicts },
  { "git_index_open", (void *)_cffi_f_git_index_open, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 225), (void *)_cffi_d_git_index_open },
  { "git_index_read", (void *)_cffi_f_git_index_read, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 275), (void *)_cffi_d_git_index_read },
  { "git_index_read_tree", (void *)_cffi_f_git_index_read_tree, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 271), (void *)_cffi_d_git_index_read_tree },
  { "git_index_remove", (void *)_cffi_f_git_index_remove, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 255), (void *)_cffi_d_git_index_remove },
  { "git_index_write", (void *)_cffi_f_git_index_write, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 248), (void *)_cffi_d_git_index_write },
  { "git_index_write_tree", (void *)_cffi_f_git_index_write_tree, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 311), (void *)_cffi_d_git_index_write_tree },
  { "git_index_write_tree_to", (void *)_cffi_f_git_index_write_tree_to, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 315), (void *)_cffi_d_git_index_write_tree_to },
  { "git_libgit2_features", (void *)_cffi_f_git_libgit2_features, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 519), (void *)_cffi_d_git_libgit2_features },
  { "git_merge_commits", (void *)_cffi_f_git_merge_commits, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 233), (void *)_cffi_d_git_merge_commits },
  { "git_merge_file_from_index", (void *)_cffi_f_git_merge_file_from_index, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 299), (void *)_cffi_d_git_merge_file_from_index },
  { "git_merge_file_result_free", (void *)_cffi_f_git_merge_file_result_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 561), (void *)_cffi_d_git_merge_file_result_free },
  { "git_merge_init_options", (void *)_cffi_f_git_merge_init_options, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 307), (void *)_cffi_d_git_merge_init_options },
  { "git_merge_trees", (void *)_cffi_f_git_merge_trees, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 240), (void *)_cffi_d_git_merge_trees },
  { "git_push_init_options", (void *)_cffi_f_git_push_init_options, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 320), (void *)_cffi_d_git_push_init_options },
  { "git_refspec_direction", (void *)_cffi_f_git_refspec_direction, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 16), (void *)_cffi_d_git_refspec_direction },
  { "git_refspec_dst", (void *)_cffi_f_git_refspec_dst, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 0), (void *)_cffi_d_git_refspec_dst },
  { "git_refspec_dst_matches", (void *)_cffi_f_git_refspec_dst_matches, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 332), (void *)_cffi_d_git_refspec_dst_matches },
  { "git_refspec_force", (void *)_cffi_f_git_refspec_force, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 329), (void *)_cffi_d_git_refspec_force },
  { "git_refspec_rtransform", (void *)_cffi_f_git_refspec_rtransform, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 83), (void *)_cffi_d_git_refspec_rtransform },
  { "git_refspec_src", (void *)_cffi_f_git_refspec_src, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 0), (void *)_cffi_d_git_refspec_src },
  { "git_refspec_src_matches", (void *)_cffi_f_git_refspec_src_matches, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 332), (void *)_cffi_d_git_refspec_src_matches },
  { "git_refspec_string", (void *)_cffi_f_git_refspec_string, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 0), (void *)_cffi_d_git_refspec_string },
  { "git_refspec_transform", (void *)_cffi_f_git_refspec_transform, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 83), (void *)_cffi_d_git_refspec_transform },
  { "git_remote_add_fetch", (void *)_cffi_f_git_remote_add_fetch, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 413), (void *)_cffi_d_git_remote_add_fetch },
  { "git_remote_add_push", (void *)_cffi_f_git_remote_add_push, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 413), (void *)_cffi_d_git_remote_add_push },
  { "git_remote_create", (void *)_cffi_f_git_remote_create, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 341), (void *)_cffi_d_git_remote_create },
  { "git_remote_create_with_fetchspec", (void *)_cffi_f_git_remote_create_with_fetchspec, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 347), (void *)_cffi_d_git_remote_create_with_fetchspec },
  { "git_remote_delete", (void *)_cffi_f_git_remote_delete, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 409), (void *)_cffi_d_git_remote_delete },
  { "git_remote_fetch", (void *)_cffi_f_git_remote_fetch, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 361), (void *)_cffi_d_git_remote_fetch },
  { "git_remote_free", (void *)_cffi_f_git_remote_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 564), (void *)_cffi_d_git_remote_free },
  { "git_remote_get_fetch_refspecs", (void *)_cffi_f_git_remote_get_fetch_refspecs, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 440), (void *)_cffi_d_git_remote_get_fetch_refspecs },
  { "git_remote_get_push_refspecs", (void *)_cffi_f_git_remote_get_push_refspecs, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 440), (void *)_cffi_d_git_remote_get_push_refspecs },
  { "git_remote_get_refspec", (void *)_cffi_f_git_remote_get_refspec, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 30), (void *)_cffi_d_git_remote_get_refspec },
  { "git_remote_init_callbacks", (void *)_cffi_f_git_remote_init_callbacks, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 372), (void *)_cffi_d_git_remote_init_callbacks },
  { "git_remote_list", (void *)_cffi_f_git_remote_list, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 444), (void *)_cffi_d_git_remote_list },
  { "git_remote_lookup", (void *)_cffi_f_git_remote_lookup, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 336), (void *)_cffi_d_git_remote_lookup },
  { "git_remote_name", (void *)_cffi_f_git_remote_name, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 3), (void *)_cffi_d_git_remote_name },
  { "git_remote_push", (void *)_cffi_f_git_remote_push, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 367), (void *)_cffi_d_git_remote_push },
  { "git_remote_pushurl", (void *)_cffi_f_git_remote_pushurl, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 3), (void *)_cffi_d_git_remote_pushurl },
  { "git_remote_refspec_count", (void *)_cffi_f_git_remote_refspec_count, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 524), (void *)_cffi_d_git_remote_refspec_count },
  { "git_remote_rename", (void *)_cffi_f_git_remote_rename, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 448), (void *)_cffi_d_git_remote_rename },
  { "git_remote_set_pushurl", (void *)_cffi_f_git_remote_set_pushurl, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 413), (void *)_cffi_d_git_remote_set_pushurl },
  { "git_remote_set_url", (void *)_cffi_f_git_remote_set_url, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 413), (void *)_cffi_d_git_remote_set_url },
  { "git_remote_stats", (void *)_cffi_f_git_remote_stats, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 34), (void *)_cffi_d_git_remote_stats },
  { "git_remote_url", (void *)_cffi_f_git_remote_url, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 3), (void *)_cffi_d_git_remote_url },
  { "git_repository_config", (void *)_cffi_f_git_repository_config, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 121), (void *)_cffi_d_git_repository_config },
  { "git_repository_config_snapshot", (void *)_cffi_f_git_repository_config_snapshot, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 121), (void *)_cffi_d_git_repository_config_snapshot },
  { "git_repository_free", (void *)_cffi_f_git_repository_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 567), (void *)_cffi_d_git_repository_free },
  { "git_repository_ident", (void *)_cffi_f_git_repository_ident, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 37), (void *)_cffi_d_git_repository_ident },
  { "git_repository_index", (void *)_cffi_f_git_repository_index, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 229), (void *)_cffi_d_git_repository_index },
  { "git_repository_init", (void *)_cffi_f_git_repository_init, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 397), (void *)_cffi_d_git_repository_init },
  { "git_repository_init_ext", (void *)_cffi_f_git_repository_init_ext, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 386), (void *)_cffi_d_git_repository_init_ext },
  { "git_repository_init_init_options", (void *)_cffi_f_git_repository_init_init_options, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 436), (void *)_cffi_d_git_repository_init_init_options },
  { "git_repository_set_head", (void *)_cffi_f_git_repository_set_head, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 409), (void *)_cffi_d_git_repository_set_head },
  { "git_repository_set_head_detached", (void *)_cffi_f_git_repository_set_head_detached, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 432), (void *)_cffi_d_git_repository_set_head_detached },
  { "git_repository_set_ident", (void *)_cffi_f_git_repository_set_ident, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 413), (void *)_cffi_d_git_repository_set_ident },
  { "git_repository_state_cleanup", (void *)_cffi_f_git_repository_state_cleanup, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 406), (void *)_cffi_d_git_repository_state_cleanup },
  { "git_strarray_free", (void *)_cffi_f_git_strarray_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 570), (void *)_cffi_d_git_strarray_free },
  { "git_submodule_branch", (void *)_cffi_f_git_submodule_branch, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 6), (void *)_cffi_d_git_submodule_branch },
  { "git_submodule_free", (void *)_cffi_f_git_submodule_free, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 573), (void *)_cffi_d_git_submodule_free },
  { "git_submodule_lookup", (void *)_cffi_f_git_submodule_lookup, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 454), (void *)_cffi_d_git_submodule_lookup },
  { "git_submodule_name", (void *)_cffi_f_git_submodule_name, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 6), (void *)_cffi_d_git_submodule_name },
  { "git_submodule_open", (void *)_cffi_f_git_submodule_open, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 402), (void *)_cffi_d_git_submodule_open },
  { "git_submodule_path", (void *)_cffi_f_git_submodule_path, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 6), (void *)_cffi_d_git_submodule_path },
  { "git_submodule_url", (void *)_cffi_f_git_submodule_url, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 6), (void *)_cffi_d_git_submodule_url },
  { "giterr_last", (void *)_cffi_f_giterr_last, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 19), (void *)_cffi_d_giterr_last },
};

static const struct _cffi_field_s _cffi_fields[] = {
  { "ptr", offsetof(git_buf, ptr),
           sizeof(((git_buf *)0)->ptr),
           _CFFI_OP(_CFFI_OP_NOOP, 457) },
  { "asize", offsetof(git_buf, asize),
             sizeof(((git_buf *)0)->asize),
             _CFFI_OP(_CFFI_OP_NOOP, 28) },
  { "size", offsetof(git_buf, size),
            sizeof(((git_buf *)0)->size),
            _CFFI_OP(_CFFI_OP_NOOP, 28) },
  { "cert_type", offsetof(git_cert, cert_type),
                 sizeof(((git_cert *)0)->cert_type),
                 _CFFI_OP(_CFFI_OP_NOOP, 591) },
  { "cert_type", offsetof(git_cert_hostkey, cert_type),
                 sizeof(((git_cert_hostkey *)0)->cert_type),
                 _CFFI_OP(_CFFI_OP_NOOP, 591) },
  { "type", offsetof(git_cert_hostkey, type),
            sizeof(((git_cert_hostkey *)0)->type),
            _CFFI_OP(_CFFI_OP_NOOP, 590) },
  { "hash_md5", offsetof(git_cert_hostkey, hash_md5),
                sizeof(((git_cert_hostkey *)0)->hash_md5),
                _CFFI_OP(_CFFI_OP_NOOP, 672) },
  { "hash_sha1", offsetof(git_cert_hostkey, hash_sha1),
                 sizeof(((git_cert_hostkey *)0)->hash_sha1),
                 _CFFI_OP(_CFFI_OP_NOOP, 674) },
  { "cert_type", offsetof(git_cert_x509, cert_type),
                 sizeof(((git_cert_x509 *)0)->cert_type),
                 _CFFI_OP(_CFFI_OP_NOOP, 591) },
  { "data", offsetof(git_cert_x509, data),
            sizeof(((git_cert_x509 *)0)->data),
            _CFFI_OP(_CFFI_OP_NOOP, 57) },
  { "len", offsetof(git_cert_x509, len),
           sizeof(((git_cert_x509 *)0)->len),
           _CFFI_OP(_CFFI_OP_NOOP, 28) },
  { "mkdir_calls", offsetof(git_checkout_perfdata, mkdir_calls),
                   sizeof(((git_checkout_perfdata *)0)->mkdir_calls),
                   _CFFI_OP(_CFFI_OP_NOOP, 28) },
  { "stat_calls", offsetof(git_checkout_perfdata, stat_calls),
                  sizeof(((git_checkout_perfdata *)0)->stat_calls),
                  _CFFI_OP(_CFFI_OP_NOOP, 28) },
  { "chmod_calls", offsetof(git_checkout_perfdata, chmod_calls),
                   sizeof(((git_checkout_perfdata *)0)->chmod_calls),
                   _CFFI_OP(_CFFI_OP_NOOP, 28) },
  { "status", offsetof(git_diff_delta, status),
              sizeof(((git_diff_delta *)0)->status),
              _CFFI_OP(_CFFI_OP_NOOP, 604) },
  { "flags", offsetof(git_diff_delta, flags),
             sizeof(((git_diff_delta *)0)->flags),
             _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "similarity", offsetof(git_diff_delta, similarity),
                  sizeof(((git_diff_delta *)0)->similarity),
                  _CFFI_OP(_CFFI_OP_NOOP, 670) },
  { "nfiles", offsetof(git_diff_delta, nfiles),
              sizeof(((git_diff_delta *)0)->nfiles),
              _CFFI_OP(_CFFI_OP_NOOP, 670) },
  { "old_file", offsetof(git_diff_delta, old_file),
                sizeof(((git_diff_delta *)0)->old_file),
                _CFFI_OP(_CFFI_OP_NOOP, 608) },
  { "new_file", offsetof(git_diff_delta, new_file),
                sizeof(((git_diff_delta *)0)->new_file),
                _CFFI_OP(_CFFI_OP_NOOP, 608) },
  { "id", offsetof(git_diff_file, id),
          sizeof(((git_diff_file *)0)->id),
          _CFFI_OP(_CFFI_OP_NOOP, 629) },
  { "path", offsetof(git_diff_file, path),
            sizeof(((git_diff_file *)0)->path),
            _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "size", offsetof(git_diff_file, size),
            sizeof(((git_diff_file *)0)->size),
            _CFFI_OP(_CFFI_OP_NOOP, 154) },
  { "flags", offsetof(git_diff_file, flags),
             sizeof(((git_diff_file *)0)->flags),
             _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "mode", offsetof(git_diff_file, mode),
            sizeof(((git_diff_file *)0)->mode),
            _CFFI_OP(_CFFI_OP_NOOP, 670) },
  { "version", offsetof(git_diff_options, version),
               sizeof(((git_diff_options *)0)->version),
               _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "flags", offsetof(git_diff_options, flags),
             sizeof(((git_diff_options *)0)->flags),
             _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "ignore_submodules", offsetof(git_diff_options, ignore_submodules),
                         sizeof(((git_diff_options *)0)->ignore_submodules),
                         _CFFI_OP(_CFFI_OP_NOOP, 646) },
  { "pathspec", offsetof(git_diff_options, pathspec),
                sizeof(((git_diff_options *)0)->pathspec),
                _CFFI_OP(_CFFI_OP_NOOP, 644) },
  { "notify_cb", offsetof(git_diff_options, notify_cb),
                 sizeof(((git_diff_options *)0)->notify_cb),
                 _CFFI_OP(_CFFI_OP_NOOP, 657) },
  { "notify_payload", offsetof(git_diff_options, notify_payload),
                      sizeof(((git_diff_options *)0)->notify_payload),
                      _CFFI_OP(_CFFI_OP_NOOP, 57) },
  { "context_lines", offsetof(git_diff_options, context_lines),
                     sizeof(((git_diff_options *)0)->context_lines),
                     _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "interhunk_lines", offsetof(git_diff_options, interhunk_lines),
                       sizeof(((git_diff_options *)0)->interhunk_lines),
                       _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "id_abbrev", offsetof(git_diff_options, id_abbrev),
                 sizeof(((git_diff_options *)0)->id_abbrev),
                 _CFFI_OP(_CFFI_OP_NOOP, 670) },
  { "max_size", offsetof(git_diff_options, max_size),
                sizeof(((git_diff_options *)0)->max_size),
                _CFFI_OP(_CFFI_OP_NOOP, 154) },
  { "old_prefix", offsetof(git_diff_options, old_prefix),
                  sizeof(((git_diff_options *)0)->old_prefix),
                  _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "new_prefix", offsetof(git_diff_options, new_prefix),
                  sizeof(((git_diff_options *)0)->new_prefix),
                  _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "file_signature", offsetof(git_diff_similarity_metric, file_signature),
                      sizeof(((git_diff_similarity_metric *)0)->file_signature),
                      _CFFI_OP(_CFFI_OP_NOOP, 668) },
  { "buffer_signature", offsetof(git_diff_similarity_metric, buffer_signature),
                        sizeof(((git_diff_similarity_metric *)0)->buffer_signature),
                        _CFFI_OP(_CFFI_OP_NOOP, 667) },
  { "free_signature", offsetof(git_diff_similarity_metric, free_signature),
                      sizeof(((git_diff_similarity_metric *)0)->free_signature),
                      _CFFI_OP(_CFFI_OP_NOOP, 679) },
  { "similarity", offsetof(git_diff_similarity_metric, similarity),
                  sizeof(((git_diff_similarity_metric *)0)->similarity),
                  _CFFI_OP(_CFFI_OP_NOOP, 664) },
  { "payload", offsetof(git_diff_similarity_metric, payload),
               sizeof(((git_diff_similarity_metric *)0)->payload),
               _CFFI_OP(_CFFI_OP_NOOP, 57) },
  { "message", offsetof(git_error, message),
               sizeof(((git_error *)0)->message),
               _CFFI_OP(_CFFI_OP_NOOP, 457) },
  { "klass", offsetof(git_error, klass),
             sizeof(((git_error *)0)->klass),
             _CFFI_OP(_CFFI_OP_NOOP, 24) },
  { "version", offsetof(git_fetch_options, version),
               sizeof(((git_fetch_options *)0)->version),
               _CFFI_OP(_CFFI_OP_NOOP, 24) },
  { "callbacks", offsetof(git_fetch_options, callbacks),
                 sizeof(((git_fetch_options *)0)->callbacks),
                 _CFFI_OP(_CFFI_OP_NOOP, 637) },
  { "prune", offsetof(git_fetch_options, prune),
             sizeof(((git_fetch_options *)0)->prune),
             _CFFI_OP(_CFFI_OP_NOOP, 617) },
  { "update_fetchhead", offsetof(git_fetch_options, update_fetchhead),
                        sizeof(((git_fetch_options *)0)->update_fetchhead),
                        _CFFI_OP(_CFFI_OP_NOOP, 24) },
  { "download_tags", offsetof(git_fetch_options, download_tags),
                     sizeof(((git_fetch_options *)0)->download_tags),
                     _CFFI_OP(_CFFI_OP_NOOP, 636) },
  { "seconds", offsetof(git_index_time, seconds),
               sizeof(((git_index_time *)0)->seconds),
               _CFFI_OP(_CFFI_OP_NOOP, 669) },
  { "nanoseconds", offsetof(git_index_time, nanoseconds),
                   sizeof(((git_index_time *)0)->nanoseconds),
                   _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "version", offsetof(git_merge_file_options, version),
               sizeof(((git_merge_file_options *)0)->version),
               _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "ancestor_label", offsetof(git_merge_file_options, ancestor_label),
                      sizeof(((git_merge_file_options *)0)->ancestor_label),
                      _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "our_label", offsetof(git_merge_file_options, our_label),
                 sizeof(((git_merge_file_options *)0)->our_label),
                 _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "their_label", offsetof(git_merge_file_options, their_label),
                   sizeof(((git_merge_file_options *)0)->their_label),
                   _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "favor", offsetof(git_merge_file_options, favor),
             sizeof(((git_merge_file_options *)0)->favor),
             _CFFI_OP(_CFFI_OP_NOOP, 622) },
  { "flags", offsetof(git_merge_file_options, flags),
             sizeof(((git_merge_file_options *)0)->flags),
             _CFFI_OP(_CFFI_OP_NOOP, 623) },
  { "automergeable", offsetof(git_merge_file_result, automergeable),
                     sizeof(((git_merge_file_result *)0)->automergeable),
                     _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "path", offsetof(git_merge_file_result, path),
            sizeof(((git_merge_file_result *)0)->path),
            _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "mode", offsetof(git_merge_file_result, mode),
            sizeof(((git_merge_file_result *)0)->mode),
            _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "ptr", offsetof(git_merge_file_result, ptr),
           sizeof(((git_merge_file_result *)0)->ptr),
           _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "len", offsetof(git_merge_file_result, len),
           sizeof(((git_merge_file_result *)0)->len),
           _CFFI_OP(_CFFI_OP_NOOP, 28) },
  { "version", offsetof(git_merge_options, version),
               sizeof(((git_merge_options *)0)->version),
               _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "tree_flags", offsetof(git_merge_options, tree_flags),
                  sizeof(((git_merge_options *)0)->tree_flags),
                  _CFFI_OP(_CFFI_OP_NOOP, 627) },
  { "rename_threshold", offsetof(git_merge_options, rename_threshold),
                        sizeof(((git_merge_options *)0)->rename_threshold),
                        _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "target_limit", offsetof(git_merge_options, target_limit),
                    sizeof(((git_merge_options *)0)->target_limit),
                    _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "metric", offsetof(git_merge_options, metric),
              sizeof(((git_merge_options *)0)->metric),
              _CFFI_OP(_CFFI_OP_NOOP, 610) },
  { "file_favor", offsetof(git_merge_options, file_favor),
                  sizeof(((git_merge_options *)0)->file_favor),
                  _CFFI_OP(_CFFI_OP_NOOP, 622) },
  { "file_flags", offsetof(git_merge_options, file_flags),
                  sizeof(((git_merge_options *)0)->file_flags),
                  _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "version", offsetof(git_push_options, version),
               sizeof(((git_push_options *)0)->version),
               _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "pb_parallelism", offsetof(git_push_options, pb_parallelism),
                      sizeof(((git_push_options *)0)->pb_parallelism),
                      _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "callbacks", offsetof(git_push_options, callbacks),
                 sizeof(((git_push_options *)0)->callbacks),
                 _CFFI_OP(_CFFI_OP_NOOP, 637) },
  { "src_refname", offsetof(git_push_update, src_refname),
                   sizeof(((git_push_update *)0)->src_refname),
                   _CFFI_OP(_CFFI_OP_NOOP, 457) },
  { "dst_refname", offsetof(git_push_update, dst_refname),
                   sizeof(((git_push_update *)0)->dst_refname),
                   _CFFI_OP(_CFFI_OP_NOOP, 457) },
  { "src", offsetof(git_push_update, src),
           sizeof(((git_push_update *)0)->src),
           _CFFI_OP(_CFFI_OP_NOOP, 629) },
  { "dst", offsetof(git_push_update, dst),
           sizeof(((git_push_update *)0)->dst),
           _CFFI_OP(_CFFI_OP_NOOP, 629) },
  { "version", offsetof(git_repository_init_options, version),
               sizeof(((git_repository_init_options *)0)->version),
               _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "flags", offsetof(git_repository_init_options, flags),
             sizeof(((git_repository_init_options *)0)->flags),
             _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "mode", offsetof(git_repository_init_options, mode),
            sizeof(((git_repository_init_options *)0)->mode),
            _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "workdir_path", offsetof(git_repository_init_options, workdir_path),
                    sizeof(((git_repository_init_options *)0)->workdir_path),
                    _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "description", offsetof(git_repository_init_options, description),
                   sizeof(((git_repository_init_options *)0)->description),
                   _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "template_path", offsetof(git_repository_init_options, template_path),
                     sizeof(((git_repository_init_options *)0)->template_path),
                     _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "initial_head", offsetof(git_repository_init_options, initial_head),
                    sizeof(((git_repository_init_options *)0)->initial_head),
                    _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "origin_url", offsetof(git_repository_init_options, origin_url),
                  sizeof(((git_repository_init_options *)0)->origin_url),
                  _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "lines_in_hunk", offsetof(git_blame_hunk, lines_in_hunk),
                     sizeof(((git_blame_hunk *)0)->lines_in_hunk),
                     _CFFI_OP(_CFFI_OP_NOOP, 670) },
  { "final_commit_id", offsetof(git_blame_hunk, final_commit_id),
                       sizeof(((git_blame_hunk *)0)->final_commit_id),
                       _CFFI_OP(_CFFI_OP_NOOP, 629) },
  { "final_start_line_number", offsetof(git_blame_hunk, final_start_line_number),
                               sizeof(((git_blame_hunk *)0)->final_start_line_number),
                               _CFFI_OP(_CFFI_OP_NOOP, 670) },
  { "final_signature", offsetof(git_blame_hunk, final_signature),
                       sizeof(((git_blame_hunk *)0)->final_signature),
                       _CFFI_OP(_CFFI_OP_NOOP, 642) },
  { "orig_commit_id", offsetof(git_blame_hunk, orig_commit_id),
                      sizeof(((git_blame_hunk *)0)->orig_commit_id),
                      _CFFI_OP(_CFFI_OP_NOOP, 629) },
  { "orig_path", offsetof(git_blame_hunk, orig_path),
                 sizeof(((git_blame_hunk *)0)->orig_path),
                 _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "orig_start_line_number", offsetof(git_blame_hunk, orig_start_line_number),
                              sizeof(((git_blame_hunk *)0)->orig_start_line_number),
                              _CFFI_OP(_CFFI_OP_NOOP, 670) },
  { "orig_signature", offsetof(git_blame_hunk, orig_signature),
                      sizeof(((git_blame_hunk *)0)->orig_signature),
                      _CFFI_OP(_CFFI_OP_NOOP, 642) },
  { "boundary", offsetof(git_blame_hunk, boundary),
                sizeof(((git_blame_hunk *)0)->boundary),
                _CFFI_OP(_CFFI_OP_NOOP, 581) },
  { "version", offsetof(git_blame_options, version),
               sizeof(((git_blame_options *)0)->version),
               _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "flags", offsetof(git_blame_options, flags),
             sizeof(((git_blame_options *)0)->flags),
             _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "min_match_characters", offsetof(git_blame_options, min_match_characters),
                            sizeof(((git_blame_options *)0)->min_match_characters),
                            _CFFI_OP(_CFFI_OP_NOOP, 670) },
  { "newest_commit", offsetof(git_blame_options, newest_commit),
                     sizeof(((git_blame_options *)0)->newest_commit),
                     _CFFI_OP(_CFFI_OP_NOOP, 629) },
  { "oldest_commit", offsetof(git_blame_options, oldest_commit),
                     sizeof(((git_blame_options *)0)->oldest_commit),
                     _CFFI_OP(_CFFI_OP_NOOP, 629) },
  { "min_line", offsetof(git_blame_options, min_line),
                sizeof(((git_blame_options *)0)->min_line),
                _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "max_line", offsetof(git_blame_options, max_line),
                sizeof(((git_blame_options *)0)->max_line),
                _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "version", offsetof(git_checkout_options, version),
               sizeof(((git_checkout_options *)0)->version),
               _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "checkout_strategy", offsetof(git_checkout_options, checkout_strategy),
                         sizeof(((git_checkout_options *)0)->checkout_strategy),
                         _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "disable_filters", offsetof(git_checkout_options, disable_filters),
                       sizeof(((git_checkout_options *)0)->disable_filters),
                       _CFFI_OP(_CFFI_OP_NOOP, 24) },
  { "dir_mode", offsetof(git_checkout_options, dir_mode),
                sizeof(((git_checkout_options *)0)->dir_mode),
                _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "file_mode", offsetof(git_checkout_options, file_mode),
                 sizeof(((git_checkout_options *)0)->file_mode),
                 _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "file_open_flags", offsetof(git_checkout_options, file_open_flags),
                       sizeof(((git_checkout_options *)0)->file_open_flags),
                       _CFFI_OP(_CFFI_OP_NOOP, 24) },
  { "notify_flags", offsetof(git_checkout_options, notify_flags),
                    sizeof(((git_checkout_options *)0)->notify_flags),
                    _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "notify_cb", offsetof(git_checkout_options, notify_cb),
                 sizeof(((git_checkout_options *)0)->notify_cb),
                 _CFFI_OP(_CFFI_OP_NOOP, 655) },
  { "notify_payload", offsetof(git_checkout_options, notify_payload),
                      sizeof(((git_checkout_options *)0)->notify_payload),
                      _CFFI_OP(_CFFI_OP_NOOP, 57) },
  { "progress_cb", offsetof(git_checkout_options, progress_cb),
                   sizeof(((git_checkout_options *)0)->progress_cb),
                   _CFFI_OP(_CFFI_OP_NOOP, 676) },
  { "progress_payload", offsetof(git_checkout_options, progress_payload),
                        sizeof(((git_checkout_options *)0)->progress_payload),
                        _CFFI_OP(_CFFI_OP_NOOP, 57) },
  { "paths", offsetof(git_checkout_options, paths),
             sizeof(((git_checkout_options *)0)->paths),
             _CFFI_OP(_CFFI_OP_NOOP, 644) },
  { "baseline", offsetof(git_checkout_options, baseline),
                sizeof(((git_checkout_options *)0)->baseline),
                _CFFI_OP(_CFFI_OP_NOOP, 207) },
  { "baseline_index", offsetof(git_checkout_options, baseline_index),
                      sizeof(((git_checkout_options *)0)->baseline_index),
                      _CFFI_OP(_CFFI_OP_NOOP, 22) },
  { "target_directory", offsetof(git_checkout_options, target_directory),
                        sizeof(((git_checkout_options *)0)->target_directory),
                        _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "ancestor_label", offsetof(git_checkout_options, ancestor_label),
                      sizeof(((git_checkout_options *)0)->ancestor_label),
                      _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "our_label", offsetof(git_checkout_options, our_label),
                 sizeof(((git_checkout_options *)0)->our_label),
                 _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "their_label", offsetof(git_checkout_options, their_label),
                   sizeof(((git_checkout_options *)0)->their_label),
                   _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "perfdata_cb", offsetof(git_checkout_options, perfdata_cb),
                   sizeof(((git_checkout_options *)0)->perfdata_cb),
                   _CFFI_OP(_CFFI_OP_NOOP, 677) },
  { "perfdata_payload", offsetof(git_checkout_options, perfdata_payload),
                        sizeof(((git_checkout_options *)0)->perfdata_payload),
                        _CFFI_OP(_CFFI_OP_NOOP, 57) },
  { "version", offsetof(git_clone_options, version),
               sizeof(((git_clone_options *)0)->version),
               _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "checkout_opts", offsetof(git_clone_options, checkout_opts),
                     sizeof(((git_clone_options *)0)->checkout_opts),
                     _CFFI_OP(_CFFI_OP_NOOP, 593) },
  { "fetch_opts", offsetof(git_clone_options, fetch_opts),
                  sizeof(((git_clone_options *)0)->fetch_opts),
                  _CFFI_OP(_CFFI_OP_NOOP, 616) },
  { "bare", offsetof(git_clone_options, bare),
            sizeof(((git_clone_options *)0)->bare),
            _CFFI_OP(_CFFI_OP_NOOP, 24) },
  { "local", offsetof(git_clone_options, local),
             sizeof(((git_clone_options *)0)->local),
             _CFFI_OP(_CFFI_OP_NOOP, 595) },
  { "checkout_branch", offsetof(git_clone_options, checkout_branch),
                       sizeof(((git_clone_options *)0)->checkout_branch),
                       _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "repository_cb", offsetof(git_clone_options, repository_cb),
                     sizeof(((git_clone_options *)0)->repository_cb),
                     _CFFI_OP(_CFFI_OP_NOOP, 661) },
  { "repository_cb_payload", offsetof(git_clone_options, repository_cb_payload),
                             sizeof(((git_clone_options *)0)->repository_cb_payload),
                             _CFFI_OP(_CFFI_OP_NOOP, 57) },
  { "remote_cb", offsetof(git_clone_options, remote_cb),
                 sizeof(((git_clone_options *)0)->remote_cb),
                 _CFFI_OP(_CFFI_OP_NOOP, 659) },
  { "remote_cb_payload", offsetof(git_clone_options, remote_cb_payload),
                         sizeof(((git_clone_options *)0)->remote_cb_payload),
                         _CFFI_OP(_CFFI_OP_NOOP, 57) },
  { "name", offsetof(git_config_entry, name),
            sizeof(((git_config_entry *)0)->name),
            _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "value", offsetof(git_config_entry, value),
             sizeof(((git_config_entry *)0)->value),
             _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "level", offsetof(git_config_entry, level),
             sizeof(((git_config_entry *)0)->level),
             _CFFI_OP(_CFFI_OP_NOOP, 143) },
  { "free", offsetof(git_config_entry, free),
            sizeof(((git_config_entry *)0)->free),
            _CFFI_OP(_CFFI_OP_NOOP, 678) },
  { "payload", offsetof(git_config_entry, payload),
               sizeof(((git_config_entry *)0)->payload),
               _CFFI_OP(_CFFI_OP_NOOP, 57) },
  { "ctime", offsetof(git_index_entry, ctime),
             sizeof(((git_index_entry *)0)->ctime),
             _CFFI_OP(_CFFI_OP_NOOP, 621) },
  { "mtime", offsetof(git_index_entry, mtime),
             sizeof(((git_index_entry *)0)->mtime),
             _CFFI_OP(_CFFI_OP_NOOP, 621) },
  { "dev", offsetof(git_index_entry, dev),
           sizeof(((git_index_entry *)0)->dev),
           _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "ino", offsetof(git_index_entry, ino),
           sizeof(((git_index_entry *)0)->ino),
           _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "mode", offsetof(git_index_entry, mode),
            sizeof(((git_index_entry *)0)->mode),
            _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "uid", offsetof(git_index_entry, uid),
           sizeof(((git_index_entry *)0)->uid),
           _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "gid", offsetof(git_index_entry, gid),
           sizeof(((git_index_entry *)0)->gid),
           _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "file_size", offsetof(git_index_entry, file_size),
                 sizeof(((git_index_entry *)0)->file_size),
                 _CFFI_OP(_CFFI_OP_NOOP, 14) },
  { "id", offsetof(git_index_entry, id),
          sizeof(((git_index_entry *)0)->id),
          _CFFI_OP(_CFFI_OP_NOOP, 629) },
  { "flags", offsetof(git_index_entry, flags),
             sizeof(((git_index_entry *)0)->flags),
             _CFFI_OP(_CFFI_OP_NOOP, 670) },
  { "flags_extended", offsetof(git_index_entry, flags_extended),
                      sizeof(((git_index_entry *)0)->flags_extended),
                      _CFFI_OP(_CFFI_OP_NOOP, 670) },
  { "path", offsetof(git_index_entry, path),
            sizeof(((git_index_entry *)0)->path),
            _CFFI_OP(_CFFI_OP_NOOP, 10) },
  { "id", offsetof(git_oid, id),
          sizeof(((git_oid *)0)->id),
          _CFFI_OP(_CFFI_OP_NOOP, 674) },
  { "version", offsetof(git_remote_callbacks, version),
               sizeof(((git_remote_callbacks *)0)->version),
               _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "sideband_progress", offsetof(git_remote_callbacks, sideband_progress),
                         sizeof(((git_remote_callbacks *)0)->sideband_progress),
                         _CFFI_OP(_CFFI_OP_NOOP, 653) },
  { "completion", offsetof(git_remote_callbacks, completion),
                  sizeof(((git_remote_callbacks *)0)->completion),
                  _CFFI_OP(_CFFI_OP_NOOP, 660) },
  { "credentials", offsetof(git_remote_callbacks, credentials),
                   sizeof(((git_remote_callbacks *)0)->credentials),
                   _CFFI_OP(_CFFI_OP_NOOP, 656) },
  { "certificate_check", offsetof(git_remote_callbacks, certificate_check),
                         sizeof(((git_remote_callbacks *)0)->certificate_check),
                         _CFFI_OP(_CFFI_OP_NOOP, 654) },
  { "transfer_progress", offsetof(git_remote_callbacks, transfer_progress),
                         sizeof(((git_remote_callbacks *)0)->transfer_progress),
                         _CFFI_OP(_CFFI_OP_NOOP, 662) },
  { "update_tips", offsetof(git_remote_callbacks, update_tips),
                   sizeof(((git_remote_callbacks *)0)->update_tips),
                   _CFFI_OP(_CFFI_OP_NOOP, 652) },
  { "pack_progress", offsetof(git_remote_callbacks, pack_progress),
                     sizeof(((git_remote_callbacks *)0)->pack_progress),
                     _CFFI_OP(_CFFI_OP_NOOP, 665) },
  { "push_transfer_progress", offsetof(git_remote_callbacks, push_transfer_progress),
                              sizeof(((git_remote_callbacks *)0)->push_transfer_progress),
                              _CFFI_OP(_CFFI_OP_NOOP, 666) },
  { "push_update_reference", offsetof(git_remote_callbacks, push_update_reference),
                             sizeof(((git_remote_callbacks *)0)->push_update_reference),
                             _CFFI_OP(_CFFI_OP_NOOP, 268) },
  { "push_negotiation", offsetof(git_remote_callbacks, push_negotiation),
                        sizeof(((git_remote_callbacks *)0)->push_negotiation),
                        _CFFI_OP(_CFFI_OP_NOOP, 658) },
  { "transport", offsetof(git_remote_callbacks, transport),
                 sizeof(((git_remote_callbacks *)0)->transport),
                 _CFFI_OP(_CFFI_OP_NOOP, 663) },
  { "payload", offsetof(git_remote_callbacks, payload),
               sizeof(((git_remote_callbacks *)0)->payload),
               _CFFI_OP(_CFFI_OP_NOOP, 57) },
  { "name", offsetof(git_signature, name),
            sizeof(((git_signature *)0)->name),
            _CFFI_OP(_CFFI_OP_NOOP, 457) },
  { "email", offsetof(git_signature, email),
             sizeof(((git_signature *)0)->email),
             _CFFI_OP(_CFFI_OP_NOOP, 457) },
  { "when", offsetof(git_signature, when),
            sizeof(((git_signature *)0)->when),
            _CFFI_OP(_CFFI_OP_NOOP, 647) },
  { "strings", offsetof(git_strarray, strings),
               sizeof(((git_strarray *)0)->strings),
               _CFFI_OP(_CFFI_OP_NOOP, 580) },
  { "count", offsetof(git_strarray, count),
             sizeof(((git_strarray *)0)->count),
             _CFFI_OP(_CFFI_OP_NOOP, 28) },
  { "time", offsetof(git_time, time),
            sizeof(((git_time *)0)->time),
            _CFFI_OP(_CFFI_OP_NOOP, 154) },
  { "offset", offsetof(git_time, offset),
              sizeof(((git_time *)0)->offset),
              _CFFI_OP(_CFFI_OP_NOOP, 24) },
  { "total_objects", offsetof(git_transfer_progress, total_objects),
                     sizeof(((git_transfer_progress *)0)->total_objects),
                     _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "indexed_objects", offsetof(git_transfer_progress, indexed_objects),
                       sizeof(((git_transfer_progress *)0)->indexed_objects),
                       _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "received_objects", offsetof(git_transfer_progress, received_objects),
                        sizeof(((git_transfer_progress *)0)->received_objects),
                        _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "local_objects", offsetof(git_transfer_progress, local_objects),
                     sizeof(((git_transfer_progress *)0)->local_objects),
                     _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "total_deltas", offsetof(git_transfer_progress, total_deltas),
                    sizeof(((git_transfer_progress *)0)->total_deltas),
                    _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "indexed_deltas", offsetof(git_transfer_progress, indexed_deltas),
                      sizeof(((git_transfer_progress *)0)->indexed_deltas),
                      _CFFI_OP(_CFFI_OP_NOOP, 78) },
  { "received_bytes", offsetof(git_transfer_progress, received_bytes),
                      sizeof(((git_transfer_progress *)0)->received_bytes),
                      _CFFI_OP(_CFFI_OP_NOOP, 28) },
};

static const struct _cffi_struct_union_s _cffi_struct_unions[] = {
  { "$git_blame", 583, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "$git_buf", 587, _CFFI_F_CHECK_FIELDS,
    sizeof(git_buf), offsetof(struct _cffi_align_typedef_git_buf, y), 0, 3 },
  { "$git_cert", 588, _CFFI_F_CHECK_FIELDS,
    sizeof(git_cert), offsetof(struct _cffi_align_typedef_git_cert, y), 3, 1 },
  { "$git_cert_hostkey", 589, _CFFI_F_CHECK_FIELDS,
    sizeof(git_cert_hostkey), offsetof(struct _cffi_align_typedef_git_cert_hostkey, y), 4, 4 },
  { "$git_cert_x509", 592, _CFFI_F_CHECK_FIELDS,
    sizeof(git_cert_x509), offsetof(struct _cffi_align_typedef_git_cert_x509, y), 8, 3 },
  { "$git_checkout_perfdata", 594, _CFFI_F_CHECK_FIELDS,
    sizeof(git_checkout_perfdata), offsetof(struct _cffi_align_typedef_git_checkout_perfdata, y), 11, 3 },
  { "$git_commit", 597, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "$git_config", 598, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "$git_config_iterator", 600, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "$git_cred", 602, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "$git_diff", 606, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "$git_diff_delta", 607, _CFFI_F_CHECK_FIELDS,
    sizeof(git_diff_delta), offsetof(struct _cffi_align_typedef_git_diff_delta, y), 14, 6 },
  { "$git_diff_file", 608, _CFFI_F_CHECK_FIELDS,
    sizeof(git_diff_file), offsetof(struct _cffi_align_typedef_git_diff_file, y), 20, 5 },
  { "$git_diff_options", 609, _CFFI_F_CHECK_FIELDS,
    sizeof(git_diff_options), offsetof(struct _cffi_align_typedef_git_diff_options, y), 25, 12 },
  { "$git_diff_similarity_metric", 611, _CFFI_F_CHECK_FIELDS,
    sizeof(git_diff_similarity_metric), offsetof(struct _cffi_align_typedef_git_diff_similarity_metric, y), 37, 5 },
  { "$git_error", 614, _CFFI_F_CHECK_FIELDS,
    sizeof(git_error), offsetof(struct _cffi_align_typedef_git_error, y), 42, 2 },
  { "$git_fetch_options", 616, _CFFI_F_CHECK_FIELDS,
    sizeof(git_fetch_options), offsetof(struct _cffi_align_typedef_git_fetch_options, y), 44, 5 },
  { "$git_index", 618, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "$git_index_conflict_iterator", 619, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "$git_index_time", 621, _CFFI_F_CHECK_FIELDS,
    sizeof(git_index_time), offsetof(struct _cffi_align_typedef_git_index_time, y), 49, 2 },
  { "$git_merge_file_options", 624, _CFFI_F_CHECK_FIELDS,
    sizeof(git_merge_file_options), offsetof(struct _cffi_align_typedef_git_merge_file_options, y), 51, 6 },
  { "$git_merge_file_result", 625, _CFFI_F_CHECK_FIELDS,
    sizeof(git_merge_file_result), offsetof(struct _cffi_align_typedef_git_merge_file_result, y), 57, 5 },
  { "$git_merge_options", 626, _CFFI_F_CHECK_FIELDS,
    sizeof(git_merge_options), offsetof(struct _cffi_align_typedef_git_merge_options, y), 62, 7 },
  { "$git_object", 628, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "$git_push_options", 630, _CFFI_F_CHECK_FIELDS,
    sizeof(git_push_options), offsetof(struct _cffi_align_typedef_git_push_options, y), 69, 3 },
  { "$git_push_update", 632, _CFFI_F_CHECK_FIELDS,
    sizeof(git_push_update), offsetof(struct _cffi_align_typedef_git_push_update, y), 72, 4 },
  { "$git_refspec", 634, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "$git_remote", 635, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "$git_repository", 638, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "$git_repository_init_options", 641, _CFFI_F_CHECK_FIELDS,
    sizeof(git_repository_init_options), offsetof(struct _cffi_align_typedef_git_repository_init_options, y), 76, 8 },
  { "$git_submodule", 645, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "$git_transport", 650, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "$git_tree", 651, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "git_blame_hunk", 585, _CFFI_F_CHECK_FIELDS,
    sizeof(git_blame_hunk), offsetof(struct _cffi_align__git_blame_hunk, y), 84, 9 },
  { "git_blame_options", 586, _CFFI_F_CHECK_FIELDS,
    sizeof(git_blame_options), offsetof(struct _cffi_align__git_blame_options, y), 93, 7 },
  { "git_checkout_options", 593, _CFFI_F_CHECK_FIELDS,
    sizeof(git_checkout_options), offsetof(struct _cffi_align__git_checkout_options, y), 100, 20 },
  { "git_clone_options", 596, _CFFI_F_CHECK_FIELDS,
    sizeof(git_clone_options), offsetof(struct _cffi_align__git_clone_options, y), 120, 10 },
  { "git_config_entry", 599, _CFFI_F_CHECK_FIELDS,
    sizeof(git_config_entry), offsetof(struct _cffi_align__git_config_entry, y), 130, 5 },
  { "git_index_entry", 620, _CFFI_F_CHECK_FIELDS,
    sizeof(git_index_entry), offsetof(struct _cffi_align__git_index_entry, y), 135, 12 },
  { "git_oid", 629, _CFFI_F_CHECK_FIELDS,
    sizeof(git_oid), offsetof(struct _cffi_align__git_oid, y), 147, 1 },
  { "git_remote_callbacks", 637, _CFFI_F_CHECK_FIELDS,
    sizeof(git_remote_callbacks), offsetof(struct _cffi_align__git_remote_callbacks, y), 148, 13 },
  { "git_signature", 643, _CFFI_F_CHECK_FIELDS,
    sizeof(git_signature), offsetof(struct _cffi_align__git_signature, y), 161, 3 },
  { "git_strarray", 644, _CFFI_F_CHECK_FIELDS,
    sizeof(git_strarray), offsetof(struct _cffi_align__git_strarray, y), 164, 2 },
  { "git_time", 647, _CFFI_F_CHECK_FIELDS,
    sizeof(git_time), offsetof(struct _cffi_align__git_time, y), 166, 2 },
  { "git_transfer_progress", 648, _CFFI_F_CHECK_FIELDS,
    sizeof(git_transfer_progress), offsetof(struct _cffi_align__git_transfer_progress, y), 168, 7 },
};

static const struct _cffi_enum_s _cffi_enums[] = {
  { "$git_attr_t", 582, _cffi_prim_int(sizeof(git_attr_t), ((git_attr_t)-1) <= 0),
    "GIT_ATTR_UNSPECIFIED_T,GIT_ATTR_TRUE_T,GIT_ATTR_FALSE_T,GIT_ATTR_VALUE_T" },
  { "$git_cert_ssh_t", 590, _cffi_prim_int(sizeof(git_cert_ssh_t), ((git_cert_ssh_t)-1) <= 0),
    "GIT_CERT_SSH_MD5,GIT_CERT_SSH_SHA1" },
  { "$git_checkout_notify_t", 95, _cffi_prim_int(sizeof(git_checkout_notify_t), ((git_checkout_notify_t)-1) <= 0),
    "" },
  { "$git_clone_local_t", 595, _cffi_prim_int(sizeof(git_clone_local_t), ((git_clone_local_t)-1) <= 0),
    "GIT_CLONE_LOCAL_AUTO,GIT_CLONE_LOCAL,GIT_CLONE_NO_LOCAL,GIT_CLONE_LOCAL_NO_LINKS" },
  { "$git_config_level_t", 143, _cffi_prim_int(sizeof(git_config_level_t), ((git_config_level_t)-1) <= 0),
    "GIT_CONFIG_LEVEL_SYSTEM,GIT_CONFIG_LEVEL_XDG,GIT_CONFIG_LEVEL_GLOBAL,GIT_CONFIG_LEVEL_LOCAL,GIT_CONFIG_LEVEL_APP,GIT_CONFIG_HIGHEST_LEVEL" },
  { "$git_credtype_t", 603, _cffi_prim_int(sizeof(git_credtype_t), ((git_credtype_t)-1) <= 0),
    "GIT_CREDTYPE_USERPASS_PLAINTEXT,GIT_CREDTYPE_SSH_KEY,GIT_CREDTYPE_SSH_CUSTOM,GIT_CREDTYPE_DEFAULT,GIT_CREDTYPE_SSH_INTERACTIVE,GIT_CREDTYPE_USERNAME" },
  { "$git_delta_t", 604, _cffi_prim_int(sizeof(git_delta_t), ((git_delta_t)-1) <= 0),
    "GIT_DELTA_UNMODIFIED,GIT_DELTA_ADDED,GIT_DELTA_DELETED,GIT_DELTA_MODIFIED,GIT_DELTA_RENAMED,GIT_DELTA_COPIED,GIT_DELTA_IGNORED,GIT_DELTA_UNTRACKED,GIT_DELTA_TYPECHANGE" },
  { "$git_direction", 612, _cffi_prim_int(sizeof(git_direction), ((git_direction)-1) <= 0),
    "GIT_DIRECTION_FETCH,GIT_DIRECTION_PUSH" },
  { "$git_error_code", 615, _cffi_prim_int(sizeof(git_error_code), ((git_error_code)-1) <= 0),
    "GIT_OK,GIT_ERROR,GIT_ENOTFOUND,GIT_EEXISTS,GIT_EAMBIGUOUS,GIT_EBUFS,GIT_EUSER,GIT_EBAREREPO,GIT_EUNBORNBRANCH,GIT_EUNMERGED,GIT_ENONFASTFORWARD,GIT_EINVALIDSPEC,GIT_ECONFLICT,GIT_ELOCKED,GIT_PASSTHROUGH,GIT_ITEROVER" },
  { "$git_fetch_prune_t", 617, _cffi_prim_int(sizeof(git_fetch_prune_t), ((git_fetch_prune_t)-1) <= 0),
    "GIT_FETCH_PRUNE_UNSPECIFIED,GIT_FETCH_PRUNE,GIT_FETCH_NO_PRUNE" },
  { "$git_merge_file_favor_t", 622, _cffi_prim_int(sizeof(git_merge_file_favor_t), ((git_merge_file_favor_t)-1) <= 0),
    "GIT_MERGE_FILE_FAVOR_NORMAL,GIT_MERGE_FILE_FAVOR_OURS,GIT_MERGE_FILE_FAVOR_THEIRS,GIT_MERGE_FILE_FAVOR_UNION" },
  { "$git_merge_file_flags_t", 623, _cffi_prim_int(sizeof(git_merge_file_flags_t), ((git_merge_file_flags_t)-1) <= 0),
    "GIT_MERGE_FILE_DEFAULT,GIT_MERGE_FILE_STYLE_MERGE,GIT_MERGE_FILE_STYLE_DIFF3,GIT_MERGE_FILE_SIMPLIFY_ALNUM" },
  { "$git_merge_tree_flag_t", 627, _cffi_prim_int(sizeof(git_merge_tree_flag_t), ((git_merge_tree_flag_t)-1) <= 0),
    "" },
  { "$git_ref_t", 633, _cffi_prim_int(sizeof(git_ref_t), ((git_ref_t)-1) <= 0),
    "GIT_REF_INVALID,GIT_REF_OID,GIT_REF_SYMBOLIC,GIT_REF_LISTALL" },
  { "$git_remote_autotag_option_t", 636, _cffi_prim_int(sizeof(git_remote_autotag_option_t), ((git_remote_autotag_option_t)-1) <= 0),
    "GIT_REMOTE_DOWNLOAD_TAGS_UNSPECIFIED,GIT_REMOTE_DOWNLOAD_TAGS_AUTO,GIT_REMOTE_DOWNLOAD_TAGS_NONE,GIT_REMOTE_DOWNLOAD_TAGS_ALL" },
  { "$git_repository_init_flag_t", 639, _cffi_prim_int(sizeof(git_repository_init_flag_t), ((git_repository_init_flag_t)-1) <= 0),
    "GIT_REPOSITORY_INIT_BARE,GIT_REPOSITORY_INIT_NO_REINIT,GIT_REPOSITORY_INIT_NO_DOTGIT_DIR,GIT_REPOSITORY_INIT_MKDIR,GIT_REPOSITORY_INIT_MKPATH,GIT_REPOSITORY_INIT_EXTERNAL_TEMPLATE,GIT_REPOSITORY_INIT_RELATIVE_GITLINK" },
  { "$git_repository_init_mode_t", 640, _cffi_prim_int(sizeof(git_repository_init_mode_t), ((git_repository_init_mode_t)-1) <= 0),
    "GIT_REPOSITORY_INIT_SHARED_UMASK,GIT_REPOSITORY_INIT_SHARED_GROUP,GIT_REPOSITORY_INIT_SHARED_ALL" },
  { "$git_submodule_ignore_t", 646, _cffi_prim_int(sizeof(git_submodule_ignore_t), ((git_submodule_ignore_t)-1) <= 0),
    "GIT_SUBMODULE_IGNORE_UNSPECIFIED,GIT_SUBMODULE_IGNORE_NONE,GIT_SUBMODULE_IGNORE_UNTRACKED,GIT_SUBMODULE_IGNORE_DIRTY,GIT_SUBMODULE_IGNORE_ALL" },
  { "git_cert_t", 591, _cffi_prim_int(sizeof(git_cert_t), ((git_cert_t)-1) <= 0),
    "GIT_CERT_NONE,GIT_CERT_X509,GIT_CERT_HOSTKEY_LIBSSH2" },
  { "git_remote_completion_type", 377, _cffi_prim_int(sizeof(git_remote_completion_type), ((git_remote_completion_type)-1) <= 0),
    "GIT_REMOTE_COMPLETION_DOWNLOAD,GIT_REMOTE_COMPLETION_INDEXING,GIT_REMOTE_COMPLETION_ERROR" },
};

static const struct _cffi_typename_s _cffi_typenames[] = {
  { "git_attr_t", 582 },
  { "git_blame", 583 },
  { "git_blame_hunk", 585 },
  { "git_blame_options", 586 },
  { "git_buf", 587 },
  { "git_cert", 588 },
  { "git_cert_hostkey", 589 },
  { "git_cert_ssh_t", 590 },
  { "git_cert_t", 591 },
  { "git_cert_x509", 592 },
  { "git_checkout_notify_cb", 655 },
  { "git_checkout_notify_t", 95 },
  { "git_checkout_options", 593 },
  { "git_checkout_perfdata", 594 },
  { "git_checkout_perfdata_cb", 677 },
  { "git_checkout_progress_cb", 676 },
  { "git_clone_local_t", 595 },
  { "git_clone_options", 596 },
  { "git_commit", 597 },
  { "git_config", 598 },
  { "git_config_entry", 599 },
  { "git_config_iterator", 600 },
  { "git_config_level_t", 143 },
  { "git_cred", 602 },
  { "git_cred_acquire_cb", 656 },
  { "git_credtype_t", 603 },
  { "git_delta_t", 604 },
  { "git_diff", 606 },
  { "git_diff_delta", 607 },
  { "git_diff_file", 608 },
  { "git_diff_notify_cb", 657 },
  { "git_diff_options", 609 },
  { "git_diff_similarity_metric", 611 },
  { "git_direction", 612 },
  { "git_error", 614 },
  { "git_error_code", 615 },
  { "git_fetch_options", 616 },
  { "git_fetch_prune_t", 617 },
  { "git_index", 618 },
  { "git_index_conflict_iterator", 619 },
  { "git_index_entry", 620 },
  { "git_index_matched_path_cb", 268 },
  { "git_index_time", 621 },
  { "git_merge_file_favor_t", 622 },
  { "git_merge_file_flags_t", 623 },
  { "git_merge_file_options", 624 },
  { "git_merge_file_result", 625 },
  { "git_merge_options", 626 },
  { "git_merge_tree_flag_t", 627 },
  { "git_object", 628 },
  { "git_off_t", 154 },
  { "git_oid", 629 },
  { "git_packbuilder_progress", 665 },
  { "git_push_negotiation", 658 },
  { "git_push_options", 630 },
  { "git_push_transfer_progress", 666 },
  { "git_push_update", 632 },
  { "git_ref_t", 633 },
  { "git_refspec", 634 },
  { "git_remote", 635 },
  { "git_remote_autotag_option_t", 636 },
  { "git_remote_callbacks", 637 },
  { "git_remote_completion_type", 377 },
  { "git_remote_create_cb", 659 },
  { "git_repository", 638 },
  { "git_repository_create_cb", 661 },
  { "git_repository_init_flag_t", 639 },
  { "git_repository_init_mode_t", 640 },
  { "git_repository_init_options", 641 },
  { "git_signature", 643 },
  { "git_strarray", 644 },
  { "git_submodule", 645 },
  { "git_submodule_ignore_t", 646 },
  { "git_time", 647 },
  { "git_time_t", 154 },
  { "git_transfer_progress", 648 },
  { "git_transfer_progress_cb", 662 },
  { "git_transport", 650 },
  { "git_transport_cb", 663 },
  { "git_transport_certificate_check_cb", 654 },
  { "git_transport_message_cb", 653 },
  { "git_tree", 651 },
};

static const struct _cffi_type_context_s _cffi_type_context = {
  _cffi_types,
  _cffi_globals,
  _cffi_fields,
  _cffi_struct_unions,
  _cffi_enums,
  _cffi_typenames,
  231,  /* num_globals */
  45,  /* num_struct_unions */
  20,  /* num_enums */
  82,  /* num_typenames */
  NULL,  /* no includes */
  681,  /* num_types */
  0,  /* flags */
};

#ifdef PYPY_VERSION
PyMODINIT_FUNC
_cffi_pypyinit__libgit2(const void *p[])
{
    p[0] = (const void *)0x2601;
    p[1] = &_cffi_type_context;
}
#  ifdef _MSC_VER
     PyMODINIT_FUNC
#  if PY_MAJOR_VERSION >= 3
     PyInit__libgit2(void) { return NULL; }
#  else
     init_libgit2(void) { }
#  endif
#  endif
#elif PY_MAJOR_VERSION >= 3
PyMODINIT_FUNC
PyInit__libgit2(void)
{
  return _cffi_init("pygit2._libgit2", 0x2601, &_cffi_type_context);
}
#else
PyMODINIT_FUNC
init_libgit2(void)
{
  _cffi_init("pygit2._libgit2", 0x2601, &_cffi_type_context);
}
#endif
